@@ -5,14 +5,12 @@
 """Command line wrapper for the multiple alignment programme MAFFT.
 """
 
-__docformat__ = "epytext en" #Don't just use plain text in epydoc API pages!
-
-#TODO - Remove file exist checks? Other wrappers don't do this, and
-#it prevent things like preparing commands to run on a cluster.
+__docformat__ = "epytext en"  # Don't just use plain text in epydoc API pages!
 
 import os
 from Bio.Application import _Option, _Switch, _Argument, AbstractCommandline
 
+
 class MafftCommandline(AbstractCommandline):
     """Command line wrapper for the multiple alignment program MAFFT.
 
@@ -194,6 +192,18 @@ class MafftCommandline(AbstractCommandline):
             _Switch(["--groupsize", "groupsize"],
                     "Do not make alignment larger than number sequences. "
                     "Default: the number of input sequences"),
+            #Adjust direction according to the first sequence
+            #Mafft V6 beta function
+            _Switch(["--adjustdirection", "adjustdirection"],
+                    "Adjust direction according to the first sequence. "
+                    "Default off."),
+            #Adjust direction according to the first sequence
+            #for highly diverged data; very slow
+            #Mafft V6 beta function
+            _Switch(["--adjustdirectionaccurately", "adjustdirectionaccurately"],
+                    "Adjust direction according to the first sequence,"
+                    "for highly diverged data; very slow"
+                    "Default off."),
             #**** Parameter ****
             #Gap opening penalty at group-to-group alignment. Default: 1.53
             _Option(["--op", "op"],
@@ -261,7 +271,6 @@ class MafftCommandline(AbstractCommandline):
             _Option(["--tm", "tm"],
                     "Transmembrane PAM number (Jones et al. 1994) "
                     "matrix is used. number>0. Default: BLOSUM62",
-                    checker_function=os.path.exists,
                     filename=True,
                     equate=False),
             #Use a user-defined AA scoring matrix. The format of matrixfile is
@@ -270,7 +279,6 @@ class MafftCommandline(AbstractCommandline):
             _Option(["--aamatrix", "aamatrix"],
                     "Use a user-defined AA scoring matrix. "
                     "Default: BLOSUM62",
-                    checker_function=os.path.exists,
                     filename=True,
                     equate=False),
             #Incorporate the AA/nuc composition information into the scoring
@@ -315,12 +323,11 @@ class MafftCommandline(AbstractCommandline):
             _Option(["--seed", "seed"],
                     "Seed alignments given in alignment_n (fasta format) "
                     "are aligned with sequences in input.",
-                    checker_function=os.path.exists,
                     filename=True,
                     equate=False),
             #The old solution of also defining extra parameters with
             #["--seed", "seed1"] etc worked, but clashes with the recent
-            #code in the base class to look for duplicate paramters and raise
+            #code in the base class to look for duplicate parameters and raise
             #an error.  Perhaps that check should be ignored here, or maybe
             #we can handle this more elegantly...
             #TODO - Create an _OptionList parameter which allows a list to be
@@ -329,7 +336,6 @@ class MafftCommandline(AbstractCommandline):
             #The input (must be FASTA format)
             _Argument(["input"],
                       "Input file name",
-                      checker_function=os.path.exists,
                       filename=True,
                       is_required=True),
             ###################################################################
@@ -337,36 +343,11 @@ class MafftCommandline(AbstractCommandline):
             #mafft-profile align1 align2
             _Argument(["input1"],
                       "Second input file name for the mafft-profile command",
-                      checker_function=os.path.exists,
                       filename=True),
             ]
         AbstractCommandline.__init__(self, cmd, **kwargs)
 
-def _test():
-    """Run the module's doctests (PRIVATE).
-
-    This will try and locate the unit tests directory, and run the doctests
-    from there in order that the relative paths used in the examples work.
-    """
-    #TODO - Remove os.path checks on input filenames?
-    import doctest
-    import os
-    if os.path.isdir(os.path.join("..","Tests")):
-        print "Runing doctests..."
-        cur_dir = os.path.abspath(os.curdir)
-        os.chdir(os.path.join("..","Tests"))
-        doctest.testmod()
-        os.chdir(cur_dir)
-        del cur_dir
-        print "Done"
-    elif os.path.isdir(os.path.join("Tests")) :
-        print "Runing doctests..."
-        cur_dir = os.path.abspath(os.curdir)
-        os.chdir(os.path.join("Tests"))
-        doctest.testmod()
-        os.chdir(cur_dir)
-        del cur_dir
-        print "Done"
 
 if __name__ == "__main__":
-    _test()
+    from Bio._utils import run_doctest
+    run_doctest()
