@@ -5,13 +5,16 @@
 """Command line wrapper for the multiple alignment program TCOFFEE.
 """
 
-from Bio.Application import _Option, _Switch, _Argument, AbstractCommandline
+__docformat__ = "epytext en"  # Don't just use plain text in epydoc API pages!
+
+from Bio.Application import _Option, _Switch, AbstractCommandline
+
 
 class TCoffeeCommandline(AbstractCommandline):
     """Commandline object for the TCoffee alignment program.
 
     http://www.tcoffee.org/Projects_home_page/t_coffee_home_page.html
-    
+
     The T-Coffee command line tool has a lot of switches and options.
     This wrapper implements a VERY limited number of options - if you
     would like to help improve it please get in touch.
@@ -30,7 +33,7 @@ class TCoffeeCommandline(AbstractCommandline):
 
     You would typically run the command line with tcoffee_cline() or via
     the Python subprocess module, as described in the Biopython tutorial.
-    
+
     Citation:
 
     T-Coffee: A novel method for multiple sequence alignments.
@@ -50,7 +53,7 @@ class TCoffeeCommandline(AbstractCommandline):
 
                    Note that of these Biopython's AlignIO module will only
                    read clustalw, pir, and fasta.
-                   """, #TODO - Can we read the PHYLIP output?
+                   """,  # TODO - Can we read the PHYLIP output?
                    equate=False),
            _Option(["-infile", "infile"],
                    "Specify the input file.",
@@ -94,11 +97,12 @@ class TCoffeeCommandline(AbstractCommandline):
                    "Specifies a special mode: genome, quickaln, dali, 3dcoffee",
                    equate=False),
            ]
-        AbstractCommandline.__init__(self, cmd, **kwargs)           
+        AbstractCommandline.__init__(self, cmd, **kwargs)
+
 
 def _test():
     """Run the module's doctests (PRIVATE)."""
-    print "Runing modules doctests..."
+    print "Running modules doctests..."
     import doctest
     doctest.testmod()
     print "Done"
