@@ -9,16 +9,18 @@
 Contains classes to deal with generic sequence alignment stuff not
 specific to a particular program or format.
 
-classes:
-o Alignment
+Classes:
+ - Alignment
 """
+__docformat__ = "epytext en"  # Don't just use plain text in epydoc API pages!
 
 # biopython
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
 from Bio import Alphabet
 
-class Alignment:
+
+class Alignment(object):
     """Represent a set of alignments (DEPRECATED).
 
     This is a base class to represent alignments, which can be subclassed
@@ -32,10 +34,11 @@ class Alignment:
         """Initialize a new Alignment object.
 
         Arguments:
-        o alphabet - The alphabet to use for the sequence objects that are
-        created. This alphabet must be a gapped type.
+         - alphabet - The alphabet to use for the sequence objects that are
+                      created. This alphabet must be a gapped type.
 
         e.g.
+
         >>> from Bio.Alphabet import IUPAC, Gapped
         >>> align = Alignment(Gapped(IUPAC.unambiguous_dna, "-"))
         >>> align.add_sequence("Alpha", "ACTGCTAGCTAG")
@@ -50,7 +53,7 @@ class Alignment:
         import warnings
         import Bio
         warnings.warn("With the introduction of the MultipleSeqAlignment class in Bio.Align, this base class is deprecated and is likely to be removed in a future release of Biopython.", Bio.BiopythonDeprecationWarning)
-        if not (isinstance(alphabet, Alphabet.Alphabet) \
+        if not (isinstance(alphabet, Alphabet.Alphabet)
         or isinstance(alphabet, Alphabet.AlphabetEncoder)):
             raise ValueError("Invalid alphabet argument")
         self._alphabet = alphabet
@@ -90,7 +93,7 @@ class Alignment:
         See also the alignment's format method.
         """
         rows = len(self._records)
-        lines = ["%s alignment with %i rows and %i columns" \
+        lines = ["%s alignment with %i rows and %i columns"
                  % (str(self._alphabet), rows, self.get_alignment_length())]
         if rows <= 20:
             lines.extend([self._str_line(rec) for rec in self._records])
@@ -132,6 +135,7 @@ class Alignment:
         string.
 
         e.g.
+
         >>> from Bio.Alphabet import IUPAC, Gapped
         >>> align = Alignment(Gapped(IUPAC.unambiguous_dna, "-"))
         >>> align.add_sequence("Alpha", "ACTGCTAGCTAG")
@@ -158,7 +162,6 @@ class Alignment:
         #See also the SeqRecord class and its format() method using Bio.SeqIO
         return self.__format__(format)
 
-
     def __format__(self, format_spec):
         """Returns the alignment as a string in the specified file format.
 
@@ -174,7 +177,7 @@ class Alignment:
             return handle.getvalue()
         else:
             #Follow python convention and default to using __str__
-            return str(self)    
+            return str(self)
 
     def get_all_seqs(self):
         """Return all of the sequences involved in the alignment (DEPRECATED).
@@ -198,6 +201,7 @@ class Alignment:
         """Iterate over alignment rows as SeqRecord objects.
 
         e.g.
+
         >>> from Bio.Alphabet import IUPAC, Gapped
         >>> align = Alignment(Gapped(IUPAC.unambiguous_dna, "-"))
         >>> align.add_sequence("Alpha", "ACTGCTAGCTAG")
@@ -213,26 +217,20 @@ class Alignment:
         Gamma
         ACTGCTAGATAG
         """
-        return iter(self._records) 
+        return iter(self._records)
 
     def get_seq_by_num(self, number):
         """Retrieve a sequence by row number (DEPRECATED).
 
         Returns:
-        o A Seq object for the requested sequence.
+         - A Seq object for the requested sequence.
 
         Raises:
-        o IndexError - If the specified number is out of range.
+         - IndexError - If the specified number is out of range.
 
         NOTE: This is a legacy method.  In new code where you need to access
         the rows of the alignment (i.e. the sequences) consider iterating
-        over them or accessing them as SeqRecord objects.  e.g.
-
-        for record in alignment:
-            print record.id
-            print record.seq
-        first_record = alignment[0]
-        last_record = alignment[-1]
+        over them or accessing them as SeqRecord objects.
         """
         import warnings
         import Bio
@@ -250,7 +248,7 @@ class Alignment:
         list of SeqRecord objects.
         """
         return len(self._records)
-    
+
     def get_alignment_length(self):
         """Return the maximum length of the alignment.
 
@@ -271,7 +269,7 @@ class Alignment:
 
         >>> len(align)
         3
-        
+
         """
         max_length = 0
 
@@ -290,19 +288,19 @@ class Alignment:
         sequences.
 
         Arguments:
-        o descriptor - The descriptive id of the sequence being added.
+         - descriptor - The descriptive id of the sequence being added.
                        This will be used as the resulting SeqRecord's
                        .id property (and, for historical compatibility,
                        also the .description property)
-        o sequence - A string with sequence info.
-        o start - You can explicitly set the start point of the sequence.
-        This is useful (at least) for BLAST alignments, which can just
-        be partial alignments of sequences.
-        o end - Specify the end of the sequence, which is important
-        for the same reason as the start.
-        o weight - The weight to place on the sequence in the alignment.
-        By default, all sequences have the same weight. (0.0 => no weight,
-        1.0 => highest weight)
+         - sequence - A string with sequence info.
+         - start - You can explicitly set the start point of the sequence.
+                   This is useful (at least) for BLAST alignments, which can
+                   just be partial alignments of sequences.
+         - end - Specify the end of the sequence, which is important
+                 for the same reason as the start.
+         - weight - The weight to place on the sequence in the alignment.
+                    By default, all sequences have the same weight. (0.0 =>
+                    no weight, 1.0 => highest weight)
         """
         new_seq = Seq(sequence, self._alphabet)
 
@@ -331,11 +329,12 @@ class Alignment:
         new_record.annotations['weight'] = weight
 
         self._records.append(new_record)
-        
+
     def get_column(self,col):
         """Returns a string containing a given column.
 
         e.g.
+
         >>> from Bio.Alphabet import IUPAC, Gapped
         >>> align = Alignment(Gapped(IUPAC.unambiguous_dna, "-"))
         >>> align.add_sequence("Alpha", "ACTGCTAGCTAG")
@@ -365,7 +364,7 @@ class Alignment:
         >>> align.add_sequence("Gamma",  "ACTGCTAGATAG")
         >>> align.add_sequence("Delta",  "ACTGCTTGCTAG")
         >>> align.add_sequence("Epsilon","ACTGCTTGATAG")
-        
+
         You can access a row of the alignment as a SeqRecord using an integer
         index (think of the alignment as a list of SeqRecord objects here):
 
@@ -423,11 +422,12 @@ class Alignment:
             sub_align._records = self._records[index]
             return sub_align
         elif len(index)==2:
-            raise TypeError("Row and Column indexing is not currently supported,"\
+            raise TypeError("Row and Column indexing is not currently supported,"
                             +"but may be in future.")
         else:
             raise TypeError("Invalid index type.")
 
+
 def _test():
     """Run the Bio.Align.Generic module's doctests."""
     print "Running doctests..."
