@@ -32,8 +32,11 @@ Camacho et al. BLAST+: architecture and applications
 BMC Bioinformatics 2009, 10:421
 doi:10.1186/1471-2105-10-421
 """
+from Bio import BiopythonDeprecationWarning
+
 from Bio.Application import _Option, AbstractCommandline, _Switch
 
+
 class FastacmdCommandline(AbstractCommandline):
     """Create a commandline for the fasta program from NCBI (OBSOLETE).
 
@@ -72,52 +75,52 @@ class _BlastCommandLine(AbstractCommandline):
                    filename=True,
                    is_required=True,
                    equate=False),
-           _Option(["-e", "expectation"], 
+           _Option(["-e", "expectation"],
                    "Expectation value cutoff.",
                    equate=False),
-           _Option(["-m", "align_view"], 
+           _Option(["-m", "align_view"],
                    "Alignment view.  Integer 0-11.  Use 7 for XML output.",
                    equate=False),
            _Option(["-o", "align_outfile", "outfile"],
                    "Output file for alignment.",
                    filename=True,
                    equate=False),
-           _Option(["-y", "xdrop_extension"], 
+           _Option(["-y", "xdrop_extension"],
                    "Dropoff for blast extensions.",
                    equate=False),
            _Option(["-F", "filter"],
                    "Filter query sequence with SEG?  T/F",
                    equate=False),
-           _Option(["-X", "xdrop"], 
+           _Option(["-X", "xdrop"],
                    "Dropoff value (bits) for gapped alignments.",
                    equate=False),
-           _Option(["-I", "show_gi"], 
+           _Option(["-I", "show_gi"],
                    "Show GI's in deflines?  T/F",
                    equate=False),
-           _Option(["-J", "believe_query"], 
+           _Option(["-J", "believe_query"],
                    "Believe the query defline?  T/F",
                    equate=False),
-           _Option(["-Z", "xdrop_final"], 
+           _Option(["-Z", "xdrop_final"],
                    "X dropoff for final gapped alignment.",
                    equate=False),
-           _Option(["-z", "db_length"], 
+           _Option(["-z", "db_length"],
                    "Effective database length.",
                    equate=False),
            _Option(["-O", "seqalign_file"],
                    "seqalign file to output.",
                    filename=True,
                    equate=False),
-           _Option(["-v", "descriptions"], 
+           _Option(["-v", "descriptions"],
                    "Number of one-line descriptions.",
                    equate=False),
-           _Option(["-b", "alignments"], 
+           _Option(["-b", "alignments"],
                    "Number of alignments.",
                    equate=False),
-           _Option(["-Y", "search_length"], 
+           _Option(["-Y", "search_length"],
                    "Effective length of search space (use zero for the "
                    "real size).",
                    equate=False),
-           _Option(["-T", "html"], 
+           _Option(["-T", "html"],
                    "Produce HTML output?  T/F",
                    equate=False),
            _Option(["-U", "case_filter"],
@@ -126,7 +129,7 @@ class _BlastCommandLine(AbstractCommandline):
            _Option(["-a", "nprocessors"],
                    "Number of processors to use.",
                    equate=False),
-           _Option(["-g", "gapped"], 
+           _Option(["-g", "gapped"],
                    "Whether to do a gapped alignment.  T/F",
                    equate=False),
         ]
@@ -155,22 +158,22 @@ class _BlastAllOrPgpCommandLine(_BlastCommandLine):
     def __init__(self, cmd=None, **kwargs):
         assert cmd is not None
         extra_parameters = [
-           _Option(["-G", "gap_open"], 
+           _Option(["-G", "gap_open"],
                    "Gap open penalty",
                    equate=False),
-           _Option(["-E", "gap_extend"], 
+           _Option(["-E", "gap_extend"],
                     "Gap extension penalty",
                    equate=False),
            _Option(["-A", "window_size"],
                     "Multiple hits window size",
                    equate=False),
-           _Option(["-f", "hit_extend"], 
+           _Option(["-f", "hit_extend"],
                    "Threshold for extending hits.",
                    equate=False),
            _Option(["-K", "keep_hits"],
                    " Number of best hits from a region to keep.",
                    equate=False),
-           _Option(["-W", "wordsize"], 
+           _Option(["-W", "wordsize"],
                    "Word size",
                    equate=False),
            _Option(["-P", "passes"],
@@ -212,19 +215,19 @@ class BlastallCommandline(_BlastAllOrPgpCommandLine):
     #TODO - This could use more checking for valid parameters to the program.
     def __init__(self, cmd="blastall",**kwargs):
         import warnings
-        warnings.warn("Like blastall, this wrapper is now obsolete, and will be deprecated and removed in a future release of Biopython.", PendingDeprecationWarning)
+        warnings.warn("Like blastall, this wrapper is now deprecated and will be removed in a future release of Biopython.", BiopythonDeprecationWarning)
         self.parameters = [
             #Sorted in the same order as the output from blastall --help
             #which should make it easier to keep them up to date in future.
-            #Note that some arguments are defined the the base clases (above).
+            #Note that some arguments are defined in the base classes (above).
            _Option(["-p", "program"],
                    "The blast program to use (e.g. blastp, blastn).",
                    is_required=True,
                    equate=False),
-           _Option(["-q", "nuc_mismatch"], 
+           _Option(["-q", "nuc_mismatch"],
                    "Penalty for a nucleotide mismatch (blastn only).",
                    equate=False),
-           _Option(["-r", "nuc_match"], 
+           _Option(["-r", "nuc_match"],
                    "Reward for a nucleotide match (blastn only).",
                    equate=False),
            _Option(["-Q", "query_genetic_code"],
@@ -233,10 +236,10 @@ class BlastallCommandline(_BlastAllOrPgpCommandLine):
            _Option(["-D", "db_genetic_code"],
                    "DB Genetic code (for tblast[nx] only).",
                    equate=False),
-           _Option(["-M", "matrix"], 
+           _Option(["-M", "matrix"],
                    "Matrix to use",
                    equate=False),
-           _Option(["-S", "strands"], 
+           _Option(["-S", "strands"],
                    "Query strands to search against database (for blast[nx], "
                    "and tblastx). 3 is both, 1 is top, 2 is bottom.",
                    equate=False),
@@ -258,7 +261,7 @@ class BlastallCommandline(_BlastAllOrPgpCommandLine):
                    In older versions of BLAST, -L set the length of region
                    used to judge hits (see -K parameter).""",
                    equate=False),
-           _Option(["-w", "frame_shit_penalty"],
+           _Option(["-w", "frame_shift_penalty"],
                    "Frame shift penalty (OOF algorithm for blastx).",
                    equate=False),
            _Option(["-t", "largest_intron"],
@@ -289,7 +292,7 @@ class BlastallCommandline(_BlastAllOrPgpCommandLine):
                    "Compute locally optimal Smith-Waterman alignments (This "
                    "option is only available for gapped tblastn.) T/F",
                    equate=False),
-        ] 
+        ]
         _BlastAllOrPgpCommandLine.__init__(self, cmd, **kwargs)
 
 
@@ -299,7 +302,7 @@ class BlastpgpCommandline(_BlastAllOrPgpCommandLine):
     With the release of BLAST+ (BLAST rewritten in C++ instead of C), the NCBI
     are replacing blastpgp with a renamed tool psiblast. This module provides
     NcbipsiblastCommandline as a wrapper for the new tool psiblast.
-    
+
     Like blastpgp (and blastall), this wrapper is now obsolete, and will be
     deprecated and removed in a future release of Biopython.
 
@@ -315,7 +318,7 @@ class BlastpgpCommandline(_BlastAllOrPgpCommandLine):
     """
     def __init__(self, cmd="blastpgp",**kwargs):
         import warnings
-        warnings.warn("Like blastpgp (and blastall), this wrapper is now obsolete, and will be deprecated and removed in a future release of Biopython.", PendingDeprecationWarning)
+        warnings.warn("Like blastpgp (and blastall), this wrapper is now deprecated and will be removed in a future release of Biopython.", BiopythonDeprecationWarning)
         self.parameters = [
            _Option(["-C", "checkpoint_outfile"],
                    "Output file for PSI-BLAST checkpointing.",
@@ -337,7 +340,7 @@ class BlastpgpCommandline(_BlastAllOrPgpCommandLine):
                    "Input alignment file for PSI-BLAST restart.",
                    filename=True,
                    equate=False),
-           _Option(["-S", "required_start"], 
+           _Option(["-S", "required_start"],
                    "Start of required region in query.",
                    equate=False),
            _Option(["-H", "required_end"],
@@ -346,27 +349,27 @@ class BlastpgpCommandline(_BlastAllOrPgpCommandLine):
            _Option(["-j", "npasses"],
                    "Number of passes",
                    equate=False),
-           _Option(["-N", "nbits_gapping"], 
+           _Option(["-N", "nbits_gapping"],
                    "Number of bits to trigger gapping.",
                    equate=False),
            _Option(["-c", "pseudocounts"],
                    "Pseudocounts constants for multiple passes.",
                    equate=False),
-           _Option(["-h", "model_threshold"], 
+           _Option(["-h", "model_threshold"],
                    "E-value threshold to include in multipass model.",
                    equate=False),
            #Does the old name "region_length" for -L make sense?
-           _Option(["-L", "region_length"], 
+           _Option(["-L", "region_length"],
                    "Cost to decline alignment (disabled when zero).",
                    equate=False),
-           _Option(["-M", "matrix"], 
+           _Option(["-M", "matrix"],
                    "Matrix (string, default BLOSUM62).",
                    equate=False),
            _Option(["-p", "program"],
                    "The blast program to use (e.g blastpgp, patseedp or seedp).",
                    is_required=True,
                    equate=False),
-        ] 
+        ]
         _BlastAllOrPgpCommandLine.__init__(self, cmd, **kwargs)
 
 
@@ -378,7 +381,7 @@ class RpsBlastCommandline(_BlastCommandLine):
     second tool rpstblastn, both taking different command line arguments. This
     module provides NcbirpsblastCommandline and NcbirpsblasntCommandline as
     wrappers for the new tools.
-    
+
     Like the old rpsblast (and blastall), this wrapper is now obsolete, and will
     be deprecated and removed in a future release of Biopython.
 
@@ -394,10 +397,10 @@ class RpsBlastCommandline(_BlastCommandLine):
     """
     def __init__(self, cmd="rpsblast",**kwargs):
         import warnings
-        warnings.warn("Like the old rpsblast (and blastall), this wrapper is now obsolete, and will be deprecated and removed in a future release of Biopython.", PendingDeprecationWarning)
+        warnings.warn("Like the old rpsblast (and blastall), this wrapper is now deprecated and will be removed in a future release of Biopython.", BiopythonDeprecationWarning)
         self.parameters = [
            #Note -N is also in blastpgp, but not blastall
-           _Option(["-N", "nbits_gapping"], 
+           _Option(["-N", "nbits_gapping"],
                    "Number of bits to trigger gapping.",
                    equate=False),
            #Note blastall and blastpgp wrappers have -P with name "passes".
@@ -409,19 +412,20 @@ class RpsBlastCommandline(_BlastCommandLine):
                    "Logfile name.",
                    filename=True,
                    equate=False),
-           _Option(["-p", "protein"], 
+           _Option(["-p", "protein"],
                    "Query sequence is protein. T/F",
                    equate=False),
-           _Option(["-L", "range_restriction"], 
+           _Option(["-L", "range_restriction"],
                    "Location on query sequence (string format start,end).",
                    equate=False),
-        ] 
+        ]
         _BlastCommandLine.__init__(self, cmd, **kwargs)
 
 ##############################################################################
 # Legacy BLAST wrappers above, (new) BLAST+ wrappers below
 ##############################################################################
 
+
 class _NcbibaseblastCommandline(AbstractCommandline):
     """Base Commandline object for (new) NCBI BLAST+ wrappers (PRIVATE).
 
@@ -446,7 +450,7 @@ class _NcbibaseblastCommandline(AbstractCommandline):
                     filename=True,
                     equate=False),
             #Formatting options:
-            _Option(["-outfmt", "outfmt"], 
+            _Option(["-outfmt", "outfmt"],
                     "Alignment view.  Integer 0-11.  Use 5 for XML output "
                     "(differs from classic BLAST which used 7 for XML).",
                     equate=False),
@@ -486,10 +490,10 @@ class _NcbibaseblastCommandline(AbstractCommandline):
             if self._get_parameter(a):
                 for b in incompatibles[a]:
                     if self._get_parameter(b):
-                        raise ValueError("Options %s and %s are incompatible." \
+                        raise ValueError("Options %s and %s are incompatible."
                                          % (a,b))
 
-        
+
 class _NcbiblastCommandline(_NcbibaseblastCommandline):
     """Base Commandline object for (new) NCBI BLAST+ wrappers (PRIVATE).
 
@@ -503,7 +507,7 @@ class _NcbiblastCommandline(_NcbibaseblastCommandline):
             _Option(["-query", "query"],
                     "The sequence to search with.",
                     filename=True,
-                    equate=False), #Should this be required?
+                    equate=False),  # Should this be required?
             _Option(["-query_loc", "query_loc"],
                     "Location on the query sequence (Format: start-stop)",
                     equate=False),
@@ -511,7 +515,7 @@ class _NcbiblastCommandline(_NcbibaseblastCommandline):
             _Option(["-db", "db"],
                     "The database to BLAST against.",
                     equate=False),
-            _Option(["-evalue", "evalue"], 
+            _Option(["-evalue", "evalue"],
                     "Expectation value cutoff.",
                     equate=False),
             _Option(["-word_size","word_size"],
@@ -532,19 +536,19 @@ class _NcbiblastCommandline(_NcbibaseblastCommandline):
             #Restrict search or results
             _Option(["-gilist", "gilist"],
                     """Restrict search of database to list of GI's.
- 
+
                     Incompatible with: negative_gilist, seqidlist, remote, subject, subject_loc""",
                     filename=True,
                     equate=False),
             _Option(["-negative_gilist", "negative_gilist"],
                     """Restrict search of database to everything except the listed GIs.
- 
+
                     Incompatible with: gilist, seqidlist, remote, subject, subject_loc""",
                     filename=True,
                     equate=False),
             _Option(["-seqidlist", "seqidlist"],
                     """Restrict search of database to list of SeqID's.
- 
+
                     Incompatible with: gilist, negative_gilist, remote, subject, subject_loc""",
                     filename=True,
                     equate=False),
@@ -563,6 +567,9 @@ class _NcbiblastCommandline(_NcbibaseblastCommandline):
             _Option(["-searchsp", "searchsp"],
                     "Effective length of the search space (integer)",
                     equate=False),
+            _Option(["-max_hsps_per_subject", "max_hsps_per_subject"],
+                    "Override maximum number of HSPs per subject to save for ungapped searches (integer)",
+                    equate=False),
             #Extension options
             _Option(["-xdrop_ungap", "xdrop_ungap"],
                     "X-dropoff value (in bits) for ungapped extensions. Float.",
@@ -651,7 +658,7 @@ class _Ncbiblast2SeqCommandline(_NcbiblastCommandline):
 
                     Incompatible with: db, gilist, seqidlist, negative_gilist,
                     db_soft_mask, db_hard_mask, remote.
-                    
+
                     See also subject.""",
                     equate=False),
             #Restrict search or results:
@@ -688,7 +695,6 @@ class _Ncbiblast2SeqCommandline(_NcbiblastCommandline):
             self.parameters = extra_parameters
         _NcbiblastCommandline.__init__(self, cmd, **kwargs)
 
-
     def _validate(self):
         incompatibles = {"subject_loc":["db", "gilist", "negative_gilist", "seqidlist", "remote"],
                          "culling_limit":["best_hit_overhang","best_hit_score_edge"],
@@ -738,6 +744,7 @@ class _NcbiblastMain2SeqCommandline(_Ncbiblast2SeqCommandline):
         self._validate_incompatibilities(incompatibles)
         _Ncbiblast2SeqCommandline._validate(self)
 
+
 class NcbiblastpCommandline(_NcbiblastMain2SeqCommandline):
     """Create a commandline for the NCBI BLAST+ program blastp (for proteins).
 
@@ -888,7 +895,7 @@ class NcbiblastnCommandline(_NcbiblastMain2SeqCommandline):
                     """Discontiguous MegaBLAST template length (integer).
 
                     Allowed values: 16, 18, 21
-                    
+
                     Requires: template_type.""",
                     checker_function=lambda value : value in [16,18,21,'16','18','21'],
                     equate=False),
@@ -903,9 +910,9 @@ class NcbiblastnCommandline(_NcbiblastMain2SeqCommandline):
                     "Perform ungapped alignment only?"),
             _Option(["-off_diagonal_range", "off_diagonal_range"],
                     """Number of off-diagonals to search for the 2nd hit (integer).
-                    
+
                     Expects a positive integer, or 0 (default) to turn off.
-                    
+
                     Added in BLAST 2.2.23+
                     """,
                     equate=False),
@@ -953,7 +960,9 @@ class NcbiblastxCommandline(_NcbiblastMain2SeqCommandline):
                     equate=False),
             #General search options:
             _Option(["-frame_shift_penalty", "frame_shift_penalty"],
-                    "Frame shift penalty (integer, at least 1, default ignored).",
+                    """Frame shift penalty (integer, at least 1, default ignored) (OBSOLETE).
+
+                    This was removed in BLAST 2.2.27+""",
                     equate=False),
             _Option(["-max_intron_length", "max_intron_length"],
                     """Maximum intron length (integer).
@@ -969,6 +978,18 @@ class NcbiblastxCommandline(_NcbiblastMain2SeqCommandline):
                     "Minimum word score such that the word is added to the "
                     "BLAST lookup table (float)",
                     equate=False),
+            _Option(["-comp_based_stats", "comp_based_stats"],
+                    """Use composition-based statistics for blastp, blastx, or tblastn:
+                        D or d: default (equivalent to 2 )
+                        0 or F or f: no composition-based statistics
+                        1: Composition-based statistics as in NAR 29:2994-3005, 2001
+                        2 or T or t : Composition-based score adjustment as in Bioinformatics 21:902-911, 2005, conditioned on sequence properties
+                        3: Composition-based score adjustment as in Bioinformatics 21:902-911, 2005, unconditionally
+
+                        For programs other than tblastn, must either be absent or be D, F or 0
+                        Default = `2'
+                    """,
+                    equate=False),
             #Query filtering options:
             _Option(["-seg", "seg"],
                     """Filter query sequence with SEG (string).
@@ -979,6 +1000,8 @@ class NcbiblastxCommandline(_NcbiblastMain2SeqCommandline):
             #Extension options:
             _Switch(["-ungapped", "ungapped"],
                     "Perform ungapped alignment only?"),
+            _Switch(["-use_sw_tback", "use_sw_tback"],
+                    "Compute locally optimal Smith-Waterman alignments?"),
             ]
         _NcbiblastMain2SeqCommandline.__init__(self, cmd, **kwargs)
 
@@ -1009,7 +1032,9 @@ class NcbitblastnCommandline(_NcbiblastMain2SeqCommandline):
                     Integer. Default is one.""",
                     equate=False),
             _Option(["-frame_shift_penalty", "frame_shift_penalty"],
-                    "Frame shift penalty (integer, at least 1, default ignored).",
+                    """Frame shift penalty (integer, at least 1, default ignored) (OBSOLETE).
+
+                    This was removed in BLAST 2.2.27+""",
                     equate=False),
             _Option(["-max_intron_length", "max_intron_length"],
                     """Maximum intron length (integer).
@@ -1222,6 +1247,13 @@ class NcbipsiblastCommandline(_Ncbiblast2SeqCommandline):
 
                     Float. Default is 0.002.""",
                     equate=False),
+            _Switch(["-ignore_msa_master", "ignore_msa_master"],
+                    """Ignore the master sequence when creating PSSM
+
+                    * Requires:  in_msa
+                    * Incompatible with:  msa_master_idx, in_pssm, query,
+                    query_loc, phi_pattern
+                    """),
             #PHI-BLAST options:
             _Option(["-phi_pattern", "phi_pattern"],
                     """File name containing pattern to search
@@ -1235,7 +1267,10 @@ class NcbipsiblastCommandline(_Ncbiblast2SeqCommandline):
     def _validate(self):
         incompatibles = {"num_iterations":["remote"],
                          "in_msa":["in_pssm", "query"],
-                         "in_pssm":["in_msa","query","phi_pattern"]}
+                         "in_pssm":["in_msa","query","phi_pattern"],
+                         "ignore_msa_master":["msa_master_idx", "in_pssm",
+                                 "query", "query_loc", "phi_pattern"],
+                         }
         self._validate_incompatibilities(incompatibles)
         _Ncbiblast2SeqCommandline._validate(self)
 
@@ -1356,7 +1391,7 @@ class NcbiblastformatterCommandline(_NcbibaseblastCommandline):
 
     The blast_formatter command allows you to convert the ASN.1 output into
     the other output formats (XML, tabular, plain text, HTML).
-    
+
     >>> from Bio.Blast.Applications import NcbiblastformatterCommandline
     >>> cline = NcbiblastformatterCommandline(archive="example.asn", outfmt=5, out="example.xml")
     >>> cline
@@ -1378,10 +1413,10 @@ class NcbiblastformatterCommandline(_NcbibaseblastCommandline):
         self.parameters = [
             # Input options
             _Option(["-rid", "rid"],
-                    "BLAST Request ID (RID), not compatiable with archive arg",
+                    "BLAST Request ID (RID), not compatible with archive arg",
                     equate=False),
             _Option(["-archive", "archive"],
-                    "Archive file of results, not compatiable with rid arg.",
+                    "Archive file of results, not compatible with rid arg.",
                     filename=True,
                     equate=False),
             # Restrict search or results
@@ -1396,7 +1431,7 @@ class NcbiblastformatterCommandline(_NcbibaseblastCommandline):
         incompatibles = {"rid":["archive"]}
         self._validate_incompatibilities(incompatibles)
         _NcbibaseblastCommandline._validate(self)
-        
+
 
 def _test():
     """Run the Bio.Blast.Applications module's doctests."""
