@@ -15,13 +15,13 @@ Functions:
 qblast        Do a BLAST search using the QBLAST API.
 """
 
-import sys
 try:
     from cStringIO import StringIO
 except ImportError:
     from StringIO import StringIO
 
-from Bio._py3k import _as_string
+from Bio._py3k import _as_string, _as_bytes
+
 
 def qblast(program, database, sequence,
            auto_format=None,composition_based_statistics=None,
@@ -62,7 +62,8 @@ def qblast(program, database, sequence,
     http://www.ncbi.nlm.nih.gov/BLAST/blast_overview.html
 
     """
-    import urllib, urllib2
+    import urllib
+    import urllib2
     import time
 
     assert program in ['blastn', 'blastp', 'blastx', 'tblastn', 'tblastx']
@@ -110,7 +111,7 @@ def qblast(program, database, sequence,
         ('CMD', 'Put'),
         ]
     query = [x for x in parameters if x[1] is not None]
-    message = urllib.urlencode(query)
+    message = _as_bytes(urllib.urlencode(query))
 
     # Send off the initial query to qblast.
     # Note the NCBI do not currently impose a rate limit here, other
@@ -122,7 +123,7 @@ def qblast(program, database, sequence,
     handle = urllib2.urlopen(request)
 
     # Format the "Get" command, which gets the formatted results from qblast
-    # Parameters taken from http://www.ncbi.nlm.nih.gov/BLAST/Doc/node6.html on 9 July 2007	
+    # Parameters taken from http://www.ncbi.nlm.nih.gov/BLAST/Doc/node6.html on 9 July 2007
     rid, rtoe = _parse_qblast_ref_page(handle)
     parameters = [
         ('ALIGNMENTS',alignments),
@@ -142,7 +143,7 @@ def qblast(program, database, sequence,
         ('CMD', 'Get'),
         ]
     query = [x for x in parameters if x[1] is not None]
-    message = urllib.urlencode(query)
+    message = _as_bytes(urllib.urlencode(query))
 
     # Poll NCBI until the results are ready.  Use a 3 second wait
     delay = 3.0
@@ -167,7 +168,7 @@ def qblast(program, database, sequence,
         if results=="\n\n":
             continue
         # XML results don't have the Status tag when finished
-        if results.find("Status=") < 0:
+        if "Status=" not in results:
             break
         i = results.index("Status=")
         j = results.index("\n", i)
@@ -177,6 +178,7 @@ def qblast(program, database, sequence,
 
     return StringIO(results)
 
+
 def _parse_qblast_ref_page(handle):
     """Extract a tuple of RID, RTOE from the 'please wait' page (PRIVATE).
 
@@ -242,7 +244,5 @@ def _parse_qblast_ref_page(handle):
     try:
         return rid, int(rtoe)
     except ValueError:
-        raise ValueError("A non-integer RTOE found in " \
+        raise ValueError("A non-integer RTOE found in "
                          +"the 'please wait' page, %s" % repr(rtoe))
-
- 
