@@ -25,6 +25,7 @@ from Bio.Blast import Record
 import xml.sax
 from xml.sax.handler import ContentHandler
 
+
 class _XMLparser(ContentHandler):
     """Generic SAX Parser
 
@@ -49,7 +50,7 @@ class _XMLparser(ContentHandler):
         """
         # Replace '-' with '_' in XML tag names
         return name.replace('-', '_')
-    
+
     def startElement(self, name, attr):
         """Found XML start tag
 
@@ -60,7 +61,7 @@ class _XMLparser(ContentHandler):
         attr -- tag attributes
         """
         self._tag.append(name)
-        
+
         # Try to call a method (defined in subclasses)
         method = self._secure_name('_start_' + name)
 
@@ -70,17 +71,16 @@ class _XMLparser(ContentHandler):
             eval("self.%s()" % method)
             if self._debug > 4:
                 print "NCBIXML: Parsed:  " + method
-        else:
-            # Doesn't exist (yet)
+        elif self._debug > 3:
+            # Doesn't exist (yet) and may want to warn about it
             if method not in self._debug_ignore_list:
-                if self._debug > 3:
-                    print "NCBIXML: Ignored: " + method
+                print "NCBIXML: Ignored: " + method
                 self._debug_ignore_list.append(method)
 
         #We don't care about white space in parent tags like Hsp,
         #but that white space doesn't belong to child tags like Hsp_midline
         if self._value.strip():
-            raise ValueError("What should we do with %s before the %s tag?" \
+            raise ValueError("What should we do with %s before the %s tag?"
                              % (repr(self._value), name))
         self._value = ""
 
@@ -97,7 +97,7 @@ class _XMLparser(ContentHandler):
         name -- tag name
         """
         # DON'T strip any white space, we may need it e.g. the hsp-midline
-        
+
         # Try to call a method (defined in subclasses)
         method = self._secure_name('_end_' + name)
         #Note could use try / except AttributeError
@@ -106,16 +106,16 @@ class _XMLparser(ContentHandler):
             eval("self.%s()" % method)
             if self._debug > 2:
                 print "NCBIXML: Parsed:  " + method, self._value
-        else:
-            # Doesn't exist (yet)
+        elif self._debug > 1:
+            # Doesn't exist (yet) and may want to warn about it
             if method not in self._debug_ignore_list:
-                if self._debug > 1:
-                    print "NCBIXML: Ignored: " + method, self._value
+                print "NCBIXML: Ignored: " + method, self._value
                 self._debug_ignore_list.append(method)
-        
+
         # Reset character buffer
         self._value = ''
-        
+
+
 class BlastParser(_XMLparser):
     """Parse XML BLAST data into a Record.Blast object
 
@@ -131,10 +131,10 @@ class BlastParser(_XMLparser):
         """
         # Calling superclass method
         _XMLparser.__init__(self, debug)
-        
+
         self._parser = xml.sax.make_parser()
         self._parser.setContentHandler(self)
-        
+
         # To avoid ValueError: unknown url type: NCBI_BlastOutput.dtd
         self._parser.setFeature(xml.sax.handler.feature_validation, 0)
         self._parser.setFeature(xml.sax.handler.feature_namespaces, 0)
@@ -148,7 +148,7 @@ class BlastParser(_XMLparser):
         self._records = []
         self._header = Record.Header()
         self._parameters = Record.Parameters()
-        self._parameters.filter = None #Maybe I should update the class?
+        self._parameters.filter = None  # Maybe I should update the class?
 
     def _start_Iteration(self):
         self._blast = Record.Blast()
@@ -208,7 +208,8 @@ class BlastParser(_XMLparser):
         #Clear the object (a new empty one is create in _start_Iteration)
         self._blast = None
 
-        if self._debug : "NCBIXML: Added Blast record to results"
+        if self._debug:
+            print "NCBIXML: Added Blast record to results"
 
     # Header
     def _end_BlastOutput_program(self):
@@ -231,7 +232,7 @@ class BlastParser(_XMLparser):
 
         #The version is the second word (field one)
         self._header.version = parts[1]
-        
+
         #Check there is a third word (the date)
         if len(parts) >= 3:
             if parts[2][0] == "[" and parts[2][-1] == "]":
@@ -319,7 +320,7 @@ class BlastParser(_XMLparser):
         """matrix used (-M)
         """
         self._parameters.matrix = self._value
-        
+
     def _end_Parameters_expect(self):
         """expect values cutoff (-e)
         """
@@ -336,7 +337,7 @@ class BlastParser(_XMLparser):
 ##         """inclusion threshold for a psi-blast iteration (-h)
 ##         """
 ##         pass # XXX TODO PSI
-    
+
     def _end_Parameters_sc_match(self):
         """match score for nucleotide-nucleotide comparaison (-r)
         """
@@ -425,21 +426,21 @@ class BlastParser(_XMLparser):
         """raw score of HSP
         """
         self._hsp.score = float(self._value)
-        if self._descr.score == None:
+        if self._descr.score is None:
             self._descr.score = float(self._value)
 
     def _end_Hsp_bit_score(self):
         """bit score of HSP
         """
         self._hsp.bits = float(self._value)
-        if self._descr.bits == None:
+        if self._descr.bits is None:
             self._descr.bits = float(self._value)
 
     def _end_Hsp_evalue(self):
-        """expect value value of the HSP
+        """expect value of the HSP
         """
         self._hsp.expect = float(self._value)
-        if self._descr.e == None:
+        if self._descr.e is None:
             self._descr.e = float(self._value)
 
     def _end_Hsp_query_from(self):
@@ -560,31 +561,32 @@ class BlastParser(_XMLparser):
         """Karlin-Altschul parameter H
         """
         self._blast.ka_params = self._blast.ka_params + (float(self._value),)
-    
+
+
 def read(handle, debug=0):
-   """Returns a single Blast record (assumes just one query).
+    """Returns a single Blast record (assumes just one query).
 
-   This function is for use when there is one and only one BLAST
-   result in your XML file.
+    This function is for use when there is one and only one BLAST
+    result in your XML file.
 
-   Use the Bio.Blast.NCBIXML.parse() function if you expect more than
-   one BLAST record (i.e. if you have more than one query sequence).
+    Use the Bio.Blast.NCBIXML.parse() function if you expect more than
+    one BLAST record (i.e. if you have more than one query sequence).
 
-   """
-   iterator = parse(handle, debug)
-   try:
-       first = iterator.next()
-   except StopIteration:
-       first = None
-   if first is None:
-       raise ValueError("No records found in handle")
-   try:
-       second = iterator.next()
-   except StopIteration:
-       second = None
-   if second is not None:
-       raise ValueError("More than one record found in handle")
-   return first
+    """
+    iterator = parse(handle, debug)
+    try:
+        first = iterator.next()
+    except StopIteration:
+        first = None
+    if first is None:
+        raise ValueError("No records found in handle")
+    try:
+        second = iterator.next()
+    except StopIteration:
+        second = None
+    if second is not None:
+        raise ValueError("More than one record found in handle")
+    return first
 
 
 def parse(handle, debug=0):
@@ -599,7 +601,7 @@ def parse(handle, debug=0):
     in.
 
     Should cope with new BLAST 2.2.14+ which gives a single XML file
-    for mutliple query records.
+    for multiple query records.
 
     Should also cope with XML output from older versions BLAST which
     gave multiple XML files concatenated together (giving a single file
@@ -615,12 +617,12 @@ def parse(handle, debug=0):
     if not text:
         #NO DATA FOUND!
         raise ValueError("Your XML file was empty")
-    
+
     while text:
         #We are now starting a new XML file
         if not text.startswith(XML_START):
             raise ValueError("Your XML file did not start with %s... "
-                             "but instead %s" \
+                             "but instead %s"
                              % (XML_START, repr(text[:20])))
 
         expat_parser = expat.ParserCreate()
@@ -647,15 +649,15 @@ def parse(handle, debug=0):
             #start of another XML file...
             pending = handle.read(MARGIN)
 
-            if (text+pending).find("\n" + XML_START) == -1:
+            if ("\n" + XML_START) not in (text + pending):
                 # Good - still dealing with the same XML file
-                expat_parser.Parse(text, False)        
+                expat_parser.Parse(text, False)
                 while blast_parser._records:
                     yield blast_parser._records.pop(0)
             else:
                 # This is output from pre 2.2.14 BLAST,
                 # one XML file for each query!
-                
+
                 # Finish the old file:
                 text, pending = (text+pending).split("\n" + XML_START,1)
                 pending = XML_START + pending
@@ -663,7 +665,7 @@ def parse(handle, debug=0):
                 expat_parser.Parse(text, True) # End of XML record
                 while blast_parser._records:
                     yield blast_parser._records.pop(0)
-               
+
                 #Now we are going to re-loop, reset the
                 #parsers and start reading the next XML file
                 text, pending = pending, ""
@@ -673,13 +675,13 @@ def parse(handle, debug=0):
         #was adding records later then the Python one
         while blast_parser._records:
             yield blast_parser._records.pop(0)
-            
+
         #At this point we have finished the first XML record.
         #If the file is from an old version of blast, it may
         #contain more XML records (check if text=="").
         assert pending==""
         assert len(blast_parser._records) == 0
-        
+
     #We should have finished the file!
     assert text==""
     assert pending==""
@@ -687,7 +689,6 @@ def parse(handle, debug=0):
 
 if __name__ == '__main__':
     import sys
-    import os
     handle = open(sys.argv[1])
     r_list = parse(handle)
 
