@@ -22,6 +22,7 @@ Parameters         Holds information from the parameters.
 
 from Bio.Align import Generic
 
+
 class Header(object):
     """Saves information from a blast header.
 
@@ -33,7 +34,7 @@ class Header(object):
 
     query               Name of query sequence.
     query_letters       Number of letters in the query sequence.  (int)
-    
+
     database            Name of the database.
     database_sequences  Number of sequences in the database.  (int)
     database_letters    Number of letters in the database.  (int)
@@ -52,6 +53,7 @@ class Header(object):
         self.database_sequences = None
         self.database_letters = None
 
+
 class Description(object):
     """Stores information about one hit in the descriptions section.
 
@@ -61,7 +63,6 @@ class Description(object):
     bits            Bit score. (float)
     e               E value.  (float)
     num_alignments  Number of alignments for the same subject.  (int)
-    
     """
     def __init__(self):
         self.title = ''
@@ -69,9 +70,11 @@ class Description(object):
         self.bits = None
         self.e = None
         self.num_alignments = None
+
     def __str__(self):
         return "%-66s %5s  %s" % (self.title, self.score, self.e)
 
+
 class Alignment(object):
     """Stores information about one hit in the alignments section.
 
@@ -89,11 +92,13 @@ class Alignment(object):
         self.hit_def = ''
         self.length = None
         self.hsps = []
+
     def __str__(self):
         lines = self.title.split('\n')
         lines.append("Length = %s\n" % self.length)
         return '\n           '.join(lines)
 
+
 class HSP(object):
     """Stores information about one hsp in an alignment hit.
 
@@ -122,7 +127,7 @@ class HSP(object):
     sbjct           The sbjct sequence.
     sbjct_start     The start residue for the sbjct sequence.  (1-based)
     sbjct_end       The end residue for the sbjct sequence.  (1-based)
-    
+
     Not all flavors of BLAST return values for every attribute:
               score     expect     identities   positives    strand  frame
     BLASTP     X          X            X            X
@@ -152,7 +157,7 @@ class HSP(object):
         self.align_length = None
         self.strand = (None, None)
         self.frame = ()
-        
+
         self.query = ''
         self.query_start = None
         self.query_end = None
@@ -162,33 +167,34 @@ class HSP(object):
         self.sbjct_end = None
 
     def __str__(self):
-        lines = ["Score %i (%i bits), expectation %0.1e, alignment length %i" \
+        lines = ["Score %i (%i bits), expectation %0.1e, alignment length %i"
                  % (self.score, self.bits, self.expect, self.align_length)]
         if self.align_length < 50:
             lines.append("Query:%s %s %s" % (str(self.query_start).rjust(8),
                                        str(self.query),
                                        str(self.query_end)))
-            lines.append("               %s" \
+            lines.append("               %s"
                          % (str(self.match)))
             lines.append("Sbjct:%s %s %s" % (str(self.sbjct_start).rjust(8),
                                        str(self.sbjct),
                                        str(self.sbjct_end)))
         else:
-            lines.append("Query:%s %s...%s %s" \
+            lines.append("Query:%s %s...%s %s"
                          % (str(self.query_start).rjust(8),
                             str(self.query)[:45],
                             str(self.query)[-3:],
                             str(self.query_end)))
-            lines.append("               %s...%s" \
+            lines.append("               %s...%s"
                          % (str(self.match)[:45],
                             str(self.match)[-3:]))
-            lines.append("Sbjct:%s %s...%s %s" \
+            lines.append("Sbjct:%s %s...%s %s"
                          % (str(self.sbjct_start).rjust(8),
                             str(self.sbjct)[:45],
                             str(self.sbjct)[-3:],
                             str(self.sbjct_end)))
         return "\n".join(lines)
 
+
 class MultipleAlignment(object):
     """Holds information about a multiple alignment.
 
@@ -220,11 +226,11 @@ class MultipleAlignment(object):
         parse_number = 0
         n = 0
         for name, start, seq, end in self.alignment:
-            if name == 'QUERY': #QUERY is the first in each alignment block
+            if name == 'QUERY':  # QUERY is the first in each alignment block
                 parse_number += 1
                 n = 0
 
-            if parse_number == 1: # create on first_parse, append on all others
+            if parse_number == 1:  # create on first_parse, append on all others
                 seq_parts.append(seq)
                 seq_names.append(name)
             else:
@@ -237,6 +243,7 @@ class MultipleAlignment(object):
 
         return generic
 
+
 class Round(object):
     """Holds information from a PSI-BLAST round.
 
@@ -246,7 +253,6 @@ class Round(object):
     new_seqs     Sequences not found, or below threshold.  List of Description.
     alignments          A list of Alignment objects.
     multiple_alignment  A MultipleAlignment object.
-    
     """
     def __init__(self):
         self.number = None
@@ -255,9 +261,10 @@ class Round(object):
         self.alignments = []
         self.multiple_alignment = None
 
+
 class DatabaseReport(object):
     """Holds information about a database report.
-    
+
     Members:
     database_name              List of database names.  (can have multiple dbs)
     num_letters_in_database    Number of letters in the database.  (int)
@@ -277,6 +284,7 @@ class DatabaseReport(object):
         self.gapped = 0
         self.ka_params_gap = (None, None, None)
 
+
 class Parameters(object):
     """Holds information about the parameters.
 
@@ -340,7 +348,8 @@ class Parameters(object):
         self.gap_trigger = (None, None)
         self.blast_cutoff = (None, None)
 
-#TODO - Add a friendly __str__ method to BLAST results    
+
+#TODO - Add a friendly __str__ method to BLAST results
 class Blast(Header, DatabaseReport, Parameters):
     """Saves the results from a blast search.
 
@@ -359,6 +368,7 @@ class Blast(Header, DatabaseReport, Parameters):
         self.alignments = []
         self.multiple_alignment = None
 
+
 class PSIBlast(Header, DatabaseReport, Parameters):
     """Saves the results from a blastpgp search.
 
