@@ -25,7 +25,7 @@ ambiguous_dna_by_id = {}
 ambiguous_rna_by_name = {}
 ambiguous_rna_by_id = {}
 ambiguous_generic_by_name = {} # ambiguous DNA or RNA
-ambiguous_generic_by_id = {} # ambiguous DNA or RNA 
+ambiguous_generic_by_id = {} # ambiguous DNA or RNA
 
 # standard IUPAC unambiguous codons
 standard_dna_table = None
@@ -35,17 +35,20 @@ standard_rna_table = None
 # appropriate distribution of codons, so do not cache the results of
 # back_table lookups!
 
+
 class TranslationError(Exception):
     pass
 
+
 class CodonTable(object):
     nucleotide_alphabet = Alphabet.generic_nucleotide
     protein_alphabet = Alphabet.generic_protein
-    
+
     forward_table = {}    # only includes codons which actually code
     back_table = {}       # for back translations
     start_codons = []
     stop_codons = []
+
     # Not always called from derived classes!
     def __init__(self, nucleotide_alphabet = nucleotide_alphabet,
                  protein_alphabet = protein_alphabet,
@@ -86,8 +89,8 @@ class CodonTable(object):
             letters = "UCAG"
 
         #Build the table...
-        answer=answer + "\n\n  |" + "|".join( \
-            ["  %s      " % c2 for c2 in letters] \
+        answer=answer + "\n\n  |" + "|".join(
+            ["  %s      " % c2 for c2 in letters]
             ) + "|"
         answer=answer + "\n--+" \
                + "+".join(["---------" for c2 in letters]) + "+--"
@@ -111,11 +114,12 @@ class CodonTable(object):
                         else:
                             line = line + " %s   |" % amino
                 line = line + " " + c3
-                answer = answer + "\n"+ line 
+                answer = answer + "\n"+ line
             answer=answer + "\n--+" \
                   + "+".join(["---------" for c2 in letters]) + "+--"
         return answer
-            
+
+
 def make_back_table(table, default_stop_codon):
     #  ONLY RETURNS A SINGLE CODON
     # Do the sort so changes in the hash implementation won't affect
@@ -130,7 +134,7 @@ def make_back_table(table, default_stop_codon):
 class NCBICodonTable(CodonTable):
     nucleotide_alphabet = Alphabet.generic_nucleotide
     protein_alphabet = IUPAC.protein
-    
+
     def __init__(self, id, names, table, start_codons, stop_codons):
         self.id = id
         self.names = names
@@ -143,6 +147,7 @@ class NCBICodonTable(CodonTable):
 class NCBICodonTableDNA(NCBICodonTable):
     nucleotide_alphabet = IUPAC.unambiguous_dna
 
+
 class NCBICodonTableRNA(NCBICodonTable):
     nucleotide_alphabet = IUPAC.unambiguous_rna
 
@@ -177,6 +182,7 @@ class AmbiguousCodonTable(CodonTable):
     def __getattr__(self, name):
         return getattr(self._codon_table, name)
 
+
 def list_possible_proteins(codon, forward_table, ambiguous_nucleotide_values):
         c1, c2, c3 = codon
         x1 = ambiguous_nucleotide_values[c1]
@@ -194,12 +200,13 @@ def list_possible_proteins(codon, forward_table, ambiguous_nucleotide_values):
                         stops.append(y1+y2+y3)
         if stops:
             if possible:
-                raise TranslationError("ambiguous codon '%s' codes " % codon \
+                raise TranslationError("ambiguous codon '%s' codes " % codon
                                        + "for both proteins and stop codons")
             # This is a true stop codon - tell the caller about it
             raise KeyError(codon)
         return possible.keys()
 
+
 def list_ambiguous_codons(codons, ambiguous_nucleotide_values):
     """Extends a codon list to include all possible ambigous codons.
 
@@ -217,14 +224,14 @@ def list_ambiguous_codons(codons, ambiguous_nucleotide_values):
     #Note ambiguous_nucleotide_values['R'] = 'AG' (etc)
     #This will generate things like 'TRR' from ['TAG', 'TGA'], which
     #we don't want to include:
-    c1_list = sorted(letter for (letter, meanings) \
-               in ambiguous_nucleotide_values.iteritems() \
+    c1_list = sorted(letter for (letter, meanings)
+               in ambiguous_nucleotide_values.iteritems()
                if set([codon[0] for codon in codons]).issuperset(set(meanings)))
-    c2_list = sorted(letter for (letter, meanings) \
-               in ambiguous_nucleotide_values.iteritems() \
+    c2_list = sorted(letter for (letter, meanings)
+               in ambiguous_nucleotide_values.iteritems()
                if set([codon[1] for codon in codons]).issuperset(set(meanings)))
-    c3_list = sorted(letter for (letter, meanings) \
-               in ambiguous_nucleotide_values.iteritems() \
+    c3_list = sorted(letter for (letter, meanings)
+               in ambiguous_nucleotide_values.iteritems()
                if set([codon[2] for codon in codons]).issuperset(set(meanings)))
     #candidates is a list (not a set) to preserve the iteration order
     candidates = []
@@ -234,14 +241,14 @@ def list_ambiguous_codons(codons, ambiguous_nucleotide_values):
                 codon = c1+c2+c3
                 if codon not in candidates and codon not in codons:
                     candidates.append(codon)
-    answer = codons[:] #copy
+    answer = codons[:]  # copy
     #print "Have %i new candidates" % len(candidates)
     for ambig_codon in candidates:
         wanted = True
         #e.g. 'TRR' -> 'TAA', 'TAG', 'TGA', 'TGG'
-        for codon in [c1+c2+c3 \
-                      for c1 in ambiguous_nucleotide_values[ambig_codon[0]] \
-                      for c2 in ambiguous_nucleotide_values[ambig_codon[1]] \
+        for codon in [c1+c2+c3
+                      for c1 in ambiguous_nucleotide_values[ambig_codon[0]]
+                      for c2 in ambiguous_nucleotide_values[ambig_codon[1]]
                       for c3 in ambiguous_nucleotide_values[ambig_codon[2]]]:
             if codon not in codons:
                 #This ambiguous codon can code for a non-stop, exclude it!
@@ -252,11 +259,12 @@ def list_ambiguous_codons(codons, ambiguous_nucleotide_values):
             answer.append(ambig_codon)
     return answer
 
-assert list_ambiguous_codons(['TGA', 'TAA'],IUPACData.ambiguous_dna_values) == ['TGA', 'TAA', 'TRA']
-assert list_ambiguous_codons(['TAG', 'TGA'],IUPACData.ambiguous_dna_values) == ['TAG', 'TGA']
-assert list_ambiguous_codons(['TAG', 'TAA'],IUPACData.ambiguous_dna_values) == ['TAG', 'TAA', 'TAR']
-assert list_ambiguous_codons(['UAG', 'UAA'],IUPACData.ambiguous_rna_values) == ['UAG', 'UAA', 'UAR']
-assert list_ambiguous_codons(['TGA', 'TAA', 'TAG'],IUPACData.ambiguous_dna_values) == ['TGA', 'TAA', 'TAG', 'TAR', 'TRA']
+assert list_ambiguous_codons(['TGA', 'TAA'], IUPACData.ambiguous_dna_values) == ['TGA', 'TAA', 'TRA']
+assert list_ambiguous_codons(['TAG', 'TGA'], IUPACData.ambiguous_dna_values) == ['TAG', 'TGA']
+assert list_ambiguous_codons(['TAG', 'TAA'], IUPACData.ambiguous_dna_values) == ['TAG', 'TAA', 'TAR']
+assert list_ambiguous_codons(['UAG', 'UAA'], IUPACData.ambiguous_rna_values) == ['UAG', 'UAA', 'UAR']
+assert list_ambiguous_codons(['TGA', 'TAA', 'TAG'],
+                                 IUPACData.ambiguous_dna_values) == ['TGA', 'TAA', 'TAG', 'TAR', 'TRA']
 
 # Forward translation is "onto", that is, any given codon always maps
 # to the same protein, or it doesn't map at all.  Thus, I can build
@@ -273,6 +281,7 @@ assert list_ambiguous_codons(['TGA', 'TAA', 'TAG'],IUPACData.ambiguous_dna_value
 #  >>> t.forward_table["YTA"]
 #  'L'
 
+
 class AmbiguousForwardTable(object):
     def __init__(self, forward_table, ambiguous_nucleotide, ambiguous_protein):
         self.forward_table = forward_table
@@ -289,7 +298,7 @@ class AmbiguousForwardTable(object):
         for name, val in inverted.iteritems():
             inverted[name] = val.keys()
         self._inverted = inverted
-        
+
         self._cache = {}
 
     def get(self, codon, failobj = None):
@@ -297,7 +306,7 @@ class AmbiguousForwardTable(object):
             return self.__getitem__(codon)
         except KeyError:
             return failobj
-        
+
     def __getitem__(self, codon):
         try:
             x = self._cache[codon]
@@ -364,7 +373,7 @@ class AmbiguousForwardTable(object):
 
         #Sort by key is 2.x and 3.x compatible
         possible.sort(key=lambda x:(len(self.ambiguous_protein[x]), x))
-                          
+
         x = possible[0]
         self._cache[codon] = x
         return x
@@ -376,7 +385,7 @@ def register_ncbi_table(name, alt_name, id,
     #In most cases names are divided by "; ", however there is also
     #'Bacterial and Plant Plastid' (which used to be just 'Bacterial')
     names = [x.strip() for x in name.replace(" and ","; ").split("; ")]
-    
+
     dna = NCBICodonTableDNA(id, names + [alt_name], table, start_codons,
                             stop_codons)
 
@@ -385,7 +394,7 @@ def register_ncbi_table(name, alt_name, id,
                                     IUPACData.ambiguous_dna_values,
                                     IUPAC.extended_protein,
                                     IUPACData.extended_protein_values)
-    
+
     # replace all T's with U's for the RNA tables
     rna_table = {}
     generic_table = {}
@@ -408,7 +417,7 @@ def register_ncbi_table(name, alt_name, id,
         codon = codon.replace("T", "U")
         generic_stop_codons.append(codon)
         rna_stop_codons.append(codon)
-    
+
     generic = NCBICodonTable(id, names + [alt_name], generic_table,
                              generic_start_codons, generic_stop_codons)
 
@@ -853,8 +862,6 @@ register_ncbi_table(name = 'Thraustochytrium Mitochondrial',
                     start_codons = [ 'ATT', 'ATG', 'GTG', ]
                     )
 
-
-
 #Basic sanity test,
 for key, val in generic_by_name.iteritems():
     assert key in ambiguous_generic_by_name[key].names
@@ -867,7 +874,7 @@ for n in ambiguous_generic_by_id:
     assert ambiguous_rna_by_id[n].forward_table["GUN"] == "V"
     if n != 23 :
         #For table 23, UUN = F, L or stop.
-        assert ambiguous_rna_by_id[n].forward_table["UUN"] == "X" #F or L
+        assert ambiguous_rna_by_id[n].forward_table["UUN"] == "X"  # F or L
     #R = A or G, so URR = UAA or UGA / TRA = TAA or TGA = stop codons
     if "UAA" in unambiguous_rna_by_id[n].stop_codons \
     and "UGA" in unambiguous_rna_by_id[n].stop_codons:
