@@ -39,13 +39,16 @@ except:
 
 connection = None
 
+
 class NoInsertionError(Exception):
     pass
 
+
 def _check_is_public(name):
     if name[:6] == "_names":
         raise AttributeError
-    
+
+
 class QueryRow(list):
     def __init__(self, cursor):
         try:
@@ -56,7 +59,7 @@ class QueryRow(list):
 
         object.__setattr__(self, "_names", [x[0] for x in cursor.description]) # FIXME: legacy
         object.__setattr__(self, "_names_hash", {})
-        
+
         for i, name in enumerate(self._names):
             self._names_hash[name] = i
 
@@ -65,7 +68,7 @@ class QueryRow(list):
         try:
             return self[self._names_hash[name]]
         except (KeyError, AttributeError):
-            raise AttributeError("'%s' object has no attribute '%s'" \
+            raise AttributeError("'%s' object has no attribute '%s'"
                                  % (self.__class__.__name__, name))
 
     def __setattr__(self, name, value):
@@ -73,7 +76,7 @@ class QueryRow(list):
             self._names_hash
         except AttributeError:
             return object.__setattr__(self, name, value)
-            
+
         _check_is_public(name)
         try:
             index = self._names_hash[name]
@@ -81,6 +84,7 @@ class QueryRow(list):
         except KeyError:
             return object.__setattr__(self, name, value)
 
+
 class Query(object):
     """
     SHOW TABLES
@@ -119,11 +123,13 @@ class Query(object):
         for item in self:
             print item
 
+
 class QueryGeneric(Query):
     def __init__(self, statement, *args, **keywds):
         Query.__init__(self, *args, **keywds)
         self.statement = statement,
 
+
 class IterationCursor(object):
     def __init__(self, query, connection=connection):
         if connection is None:
@@ -138,8 +144,10 @@ class IterationCursor(object):
     def next(self):
         return self.row_class(self.cursor)
 
+
 class QuerySingle(Query, QueryRow):
     ignore_warnings = 0
+
     def __init__(self, *args, **keywds):
         message = self.MSG_FAILURE
         Query.__init__(self, *args, **keywds)
@@ -154,6 +162,7 @@ class QuerySingle(Query, QueryRow):
     def cursor(self):
         return self.single_cursor
 
+
 class QueryAll(list, Query):
     def __init__(self, *args, **keywds):
         Query.__init__(self, *args, **keywds)
@@ -162,10 +171,12 @@ class QueryAll(list, Query):
     def process_row(self, row):
         return row
 
+
 class QueryAllFirstItem(QueryAll):
     def process_row(self, row):
         return row[0]
 
+
 class Create(QuerySingle):
     def __init__(self, *args, **keywds):
         try:
@@ -173,12 +184,14 @@ class Create(QuerySingle):
         except StopIteration:
             self.message = self.MSG_SUCCESS
 
+
 class Update(Create):
     pass
 
+
 class Insert(Create):
     MSG_INTEGRITY_ERROR = "Couldn't insert: %s. "
-    
+
     def __init__(self, *args, **keywds):
         try:
             Create.__init__(self, *args, **keywds)
@@ -188,9 +201,9 @@ class Insert(Create):
                 self.total_count
             except AttributeError:
                 self.total_count = 0
-            
+
             raise MySQLdb.IntegrityError(self.error_message)
-            
+
         self.id = self.cursor().insert_id()
         try:
             self.total_count += self.cursor().rowcount
@@ -200,8 +213,9 @@ class Insert(Create):
         if self.cursor().rowcount == 0:
             raise NoInsertionError
 
+
 def _test(*args, **keywds):
-    import doctest, sys
+    import doctest
     doctest.testmod(sys.modules[__name__], *args, **keywds)
 
 if __name__ == "__main__":
