@@ -63,12 +63,15 @@ parse        Parses the XML results returned by those of the above functions
              >>> handle.close()
 
              This function is appropriate only if the XML file contains
-             multiple records, and is particular useful for large files. 
+             multiple records, and is particular useful for large files.
 
 _open        Internally used function.
 
 """
-import urllib, urllib2, time, warnings
+import urllib
+import urllib2
+import time
+import warnings
 import os.path
 
 from Bio._py3k import _binary_to_string_handle
@@ -91,11 +94,12 @@ def epost(db, **keywds):
 
     Raises an IOError exception if there's a network error.
     """
-    cgi='http://eutils.ncbi.nlm.nih.gov/entrez/eutils/epost.fcgi'
-    variables = {'db' : db}
+    cgi = 'http://eutils.ncbi.nlm.nih.gov/entrez/eutils/epost.fcgi'
+    variables = {'db': db}
     variables.update(keywds)
     return _open(cgi, variables, post=True)
 
+
 def efetch(db, **keywds):
     """Fetches Entrez results which are returned as a handle.
 
@@ -121,19 +125,20 @@ def efetch(db, **keywds):
     Warning: The NCBI changed the default retmode in Feb 2012, so many
     databases which previously returned text output now give XML.
     """
-    cgi='http://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi'
-    variables = {'db' : db}
+    cgi = 'http://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi'
+    variables = {'db': db}
     keywords = keywds
     if "id" in keywds and isinstance(keywds["id"], list):
         #Fix for NCBI change (probably part of EFetch 2,0, Feb 2012) where
         #a list of ID strings now gives HTTP Error 500: Internal server error
         #This was turned into ...&id=22307645&id=22303114&... which used to work
         #while now the NCBI appear to insist on ...&id=22301129,22299544,...
-        keywords = keywds.copy() #Don't alter input dict!
+        keywords = keywds.copy()  # Don't alter input dict!
         keywords["id"] = ",".join(keywds["id"])
     variables.update(keywords)
     return _open(cgi, variables)
 
+
 def esearch(db, term, **keywds):
     """ESearch runs an Entrez search and returns a handle to the results.
 
@@ -163,12 +168,13 @@ def esearch(db, term, **keywds):
     True
 
     """
-    cgi='http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi'
-    variables = {'db' : db,
-                 'term' : term}
+    cgi = 'http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi'
+    variables = {'db': db,
+                 'term': term}
     variables.update(keywds)
     return _open(cgi, variables)
 
+
 def elink(**keywds):
     """ELink checks for linked external articles and returns a handle.
 
@@ -202,11 +208,12 @@ def elink(**keywds):
 
     This is explained in much more detail in the Biopython Tutorial.
     """
-    cgi='http://eutils.ncbi.nlm.nih.gov/entrez/eutils/elink.fcgi'
+    cgi = 'http://eutils.ncbi.nlm.nih.gov/entrez/eutils/elink.fcgi'
     variables = {}
     variables.update(keywds)
     return _open(cgi, variables)
 
+
 def einfo(**keywds):
     """EInfo returns a summary of the Entez databases as a results handle.
 
@@ -229,11 +236,12 @@ def einfo(**keywds):
     True
 
     """
-    cgi='http://eutils.ncbi.nlm.nih.gov/entrez/eutils/einfo.fcgi'
+    cgi = 'http://eutils.ncbi.nlm.nih.gov/entrez/eutils/einfo.fcgi'
     variables = {}
     variables.update(keywds)
     return _open(cgi, variables)
 
+
 def esummary(**keywds):
     """ESummary retrieves document summaries as a results handle.
 
@@ -260,11 +268,12 @@ def esummary(**keywds):
     Computational biology and chemistry
 
     """
-    cgi='http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi'
+    cgi = 'http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi'
     variables = {}
     variables.update(keywds)
     return _open(cgi, variables)
 
+
 def egquery(**keywds):
     """EGQuery provides Entrez database counts for a global search.
 
@@ -293,11 +302,12 @@ def egquery(**keywds):
     True
 
     """
-    cgi='http://eutils.ncbi.nlm.nih.gov/entrez/eutils/egquery.fcgi'
+    cgi = 'http://eutils.ncbi.nlm.nih.gov/entrez/eutils/egquery.fcgi'
     variables = {}
     variables.update(keywds)
     return _open(cgi, variables)
 
+
 def espell(**keywds):
     """ESpell retrieves spelling suggestions, returned in a results handle.
 
@@ -312,23 +322,24 @@ def espell(**keywds):
 
     Short example:
 
-    >>> from Bio import Entrez 
+    >>> from Bio import Entrez
     >>> Entrez.email = "Your.Name.Here@example.org"
     >>> record = Entrez.read(Entrez.espell(term="biopythooon"))
-    >>> print record["Query"] 
+    >>> print record["Query"]
     biopythooon
-    >>> print record["CorrectedQuery"] 
+    >>> print record["CorrectedQuery"]
     biopython
 
     """
-    cgi='http://eutils.ncbi.nlm.nih.gov/entrez/eutils/espell.fcgi'
+    cgi = 'http://eutils.ncbi.nlm.nih.gov/entrez/eutils/espell.fcgi'
     variables = {}
     variables.update(keywds)
     return _open(cgi, variables)
 
+
 def read(handle, validate=True):
     """Parses an XML file from the NCBI Entrez Utilities into python objects.
-    
+
     This function parses an XML file created by NCBI's Entrez Utilities,
     returning a multilevel data structure of Python lists and dictionaries.
     Most XML files returned by NCBI's Entrez Utilities can be parsed by
@@ -351,9 +362,10 @@ def read(handle, validate=True):
     record = handler.read(handle)
     return record
 
+
 def parse(handle, validate=True):
     """Parses an XML file from the NCBI Entrez Utilities into python objects.
-    
+
     This function parses an XML file created by NCBI's Entrez Utilities,
     returning a multilevel data structure of Python lists and dictionaries.
     This function is suitable for XML files that (in Python) can be represented
@@ -382,6 +394,7 @@ def parse(handle, validate=True):
     records = handler.parse(handle)
     return records
 
+
 def _open(cgi, params={}, post=False):
     """Helper function to build the URL and open a handle to it (PRIVATE).
 
@@ -412,7 +425,7 @@ def _open(cgi, params={}, post=False):
         params["tool"] = tool
     # Tell Entrez who we are
     if not "email" in params:
-        if email!=None:
+        if email is not None:
             params["email"] = email
         else:
             warnings.warn("""
@@ -448,7 +461,7 @@ _open.previous = 0
 
 def _test():
     """Run the module's doctests (PRIVATE)."""
-    print "Runing doctests..."
+    print "Running doctests..."
     import doctest
     doctest.testmod()
     print "Done"
