@@ -24,7 +24,7 @@ def get_prodoc_entry(id, cgi='http://www.expasy.ch/cgi-bin/get-prodoc-entry'):
     """get_prodoc_entry(id,
     cgi='http://www.expasy.ch/cgi-bin/get-prodoc-entry') -> handle
 
-    Get a handle to a PRODOC entry at ExPASy in HTML format. 
+    Get a handle to a PRODOC entry at ExPASy in HTML format.
 
     For a non-existing key XXX, ExPASy returns an HTML-formatted page
     containing this line:
@@ -34,6 +34,7 @@ def get_prodoc_entry(id, cgi='http://www.expasy.ch/cgi-bin/get-prodoc-entry'):
     handle = urllib.urlopen("%s?%s" % (cgi, id))
     return handle
 
+
 def get_prosite_entry(id,
                       cgi='http://www.expasy.ch/cgi-bin/get-prosite-entry'):
     """get_prosite_entry(id,
@@ -48,6 +49,7 @@ def get_prosite_entry(id,
     handle = urllib.urlopen("%s?%s" % (cgi, id))
     return handle
 
+
 def get_prosite_raw(id, cgi='http://www.expasy.ch/cgi-bin/get-prosite-raw.pl'):
     """get_prosite_raw(id,
                        cgi='http://www.expasy.ch/cgi-bin/get-prosite-raw.pl')
@@ -60,29 +62,16 @@ def get_prosite_raw(id, cgi='http://www.expasy.ch/cgi-bin/get-prosite-raw.pl'):
     handle = urllib.urlopen("%s?%s" % (cgi, id))
     return handle
 
-def get_sprot_raw(id, cgi=None):
+
+def get_sprot_raw(id):
     """Get a handle to a raw SwissProt entry at ExPASy.
 
     For an ID of XXX, fetches http://www.uniprot.org/uniprot/XXX.txt
     (as per the http://www.expasy.ch/expasy_urls.html documentation).
-
-
-    For a non-existing key XXX, ExPASy returns an HTML Error 404 page.
-
-    This function used to take a cgi option to specify the URL, but that
-    is no longer supported. This is because prior to November 2009 we
-    used to use http://www.expasy.ch/cgi-bin/get-sprot-raw.pl?XXX
-    However, at the time of writting this returns FASTA format instead
-    (probably an ExPASy/UniProt oversight). Under the new URL scheme,
-    we cannot just append "?XXX" to the cgi argument.
     """
-    if cgi :
-        import warnings
-        import Bio
-        warnings.warn("The cgi argument in get_sprot_raw is not "
-                      "supported anymore", Bio.BiopythonDeprecationWarning)
     return urllib.urlopen("http://www.uniprot.org/uniprot/%s.txt" % id)
 
+
 def sprot_search_ful(text, make_wild=None, swissprot=1, trembl=None,
                      cgi='http://www.expasy.ch/cgi-bin/sprot-search-ful'):
     """sprot_search_ful(text, make_wild=None, swissprot=1, trembl=None,
@@ -91,7 +80,7 @@ def sprot_search_ful(text, make_wild=None, swissprot=1, trembl=None,
     Search SwissProt by full text.
 
     """
-    variables = {'SEARCH' : text}
+    variables = {'SEARCH': text}
     if make_wild:
         variables['makeWild'] = 'on'
     if swissprot:
@@ -103,6 +92,7 @@ def sprot_search_ful(text, make_wild=None, swissprot=1, trembl=None,
     handle = urllib.urlopen(fullcgi)
     return handle
 
+
 def sprot_search_de(text, swissprot=1, trembl=None,
                     cgi='http://www.expasy.ch/cgi-bin/sprot-search-de'):
     """sprot_search_de(text, swissprot=1, trembl=None,
@@ -112,7 +102,7 @@ def sprot_search_de(text, swissprot=1, trembl=None,
     organelle.
 
     """
-    variables = {'SEARCH' : text}
+    variables = {'SEARCH': text}
     if swissprot:
         variables['S'] = 'on'
     if trembl:
