@@ -10,6 +10,7 @@ o Qualifier - Qualifiers on a Feature.
 # local stuff
 import Bio.GenBank
 
+
 def _wrapped_genbank(information, indent, wrap_space = 1, split_char = " "):
     """Write a line of GenBank info that can wrap over multiple lines.
 
@@ -44,7 +45,7 @@ def _wrapped_genbank(information, indent, wrap_space = 1, split_char = " "):
         while cur_pos < len(information):
             info_parts.append(information[cur_pos: cur_pos + info_length])
             cur_pos += info_length
-            
+
     # first get the information string split up by line
     output_parts = []
     cur_part = ""
@@ -70,8 +71,9 @@ def _wrapped_genbank(information, indent, wrap_space = 1, split_char = " "):
     for output_part in output_parts[1:]:
         output_info += " " * indent + output_part + "\n"
 
-    return output_info            
-        
+    return output_info
+
+
 def _indent_genbank(information, indent):
     """Write out information with the specified indent.
 
@@ -90,7 +92,8 @@ def _indent_genbank(information, indent):
 
     return output_info
 
-class Record:
+
+class Record(object):
     """Hold GenBank information in a format similar to the original record.
 
     The Record class is meant to make data easy to get to when you are
@@ -152,7 +155,7 @@ class Record:
                               str(GB_FEATURE_INDENT -
                                   GB_FEATURE_INTERNAL_INDENT) + "s"
     SEQUENCE_FORMAT = "%" + str(GB_SEQUENCE_INDENT) + "s"
-    
+
     def __init__(self):
         self.locus = ''
         self.size = ''
@@ -224,7 +227,7 @@ class Record:
         output += self._contig_line()
         output += "//"
         return output
-            
+
     def _locus_line(self):
         """Provide the output string for the LOCUS line.
         """
@@ -233,17 +236,17 @@ class Record:
         output += "%-9s" % self.locus
         output += " " # 22 space
         output += "%7s" % self.size
-        if self.residue_type.find("PROTEIN") >= 0:
+        if "PROTEIN" in self.residue_type:
             output += " aa"
         else:
             output += " bp "
 
         # treat circular types differently, since they'll have long residue
         # types
-        if self.residue_type.find("circular") >= 0:
-             output += "%17s" % self.residue_type
+        if "circular" in self.residue_type:
+            output += "%17s" % self.residue_type
         # second case: ss-DNA types of records
-        elif self.residue_type.find("-") >= 0:
+        elif "-" in self.residue_type:
             output += "%7s" % self.residue_type
             output += " " * 10 # spaces for circular
         else:
@@ -279,7 +282,7 @@ class Record:
             output += _wrapped_genbank(acc_info, Record.GB_BASE_INDENT)
         else:
             output = ""
-        
+
         return output
 
     def _version_line(self):
@@ -334,14 +337,14 @@ class Record:
         """
         output = ""
         if len(self.keywords) >= 0:
-            output +=  Record.BASE_FORMAT % "KEYWORDS"
+            output += Record.BASE_FORMAT % "KEYWORDS"
             keyword_info = ""
             for keyword in self.keywords:
                 keyword_info += "%s; " % keyword
             # replace the ; at the end with a period
             keyword_info = keyword_info[:-2]
             keyword_info += "."
-            
+
             output += _wrapped_genbank(keyword_info,
                                        Record.GB_BASE_INDENT)
 
@@ -372,7 +375,7 @@ class Record:
         output = Record.BASE_FORMAT % "SOURCE"
         output += _wrapped_genbank(self.source, Record.GB_BASE_INDENT)
         return output
-    
+
     def _organism_line(self):
         """Output for ORGANISM line with taxonomy info.
         """
@@ -389,7 +392,7 @@ class Record:
         output += _wrapped_genbank(taxonomy_info, Record.GB_BASE_INDENT)
 
         return output
-            
+
     def _comment_line(self):
         """Output for the COMMENT lines.
         """
@@ -467,7 +470,7 @@ class Record:
                     # stop looping if we are out of sequence
                     if end_pos > len(self.sequence):
                         break
-                
+
                 output += "\n"
                 cur_seq_pos += 60
         return output
@@ -485,7 +488,7 @@ class Record:
                     output += Record.BASE_FORMAT % "WGS_SCAFLD"
                     output += self.wgs_scafld
             return output
-        
+
     def _contig_line(self):
         """Output for CONTIG location information from RefSeq.
         """
@@ -495,16 +498,16 @@ class Record:
             output += _wrapped_genbank(self.contig,
                                        Record.GB_BASE_INDENT, split_char = ',')
         return output
-        
 
-class Reference:
+
+class Reference(object):
     """Hold information from a GenBank reference.
 
     Attributes:
     o number - The number of the reference in the listing of references.
     o bases - The bases in the sequence the reference refers to.
     o authors - String with all of the authors.
-    o consrtm - Consortium the authors belong to. 
+    o consrtm - Consortium the authors belong to.
     o title - The title of the reference.
     o journal - Information about the journal where the reference appeared.
     o medline_id - The medline id for the reference.
@@ -531,7 +534,7 @@ class Reference:
         output += self._medline_line()
         output += self._pubmed_line()
         output += self._remark_line()
-        
+
         return output
 
     def _reference_line(self):
@@ -592,7 +595,7 @@ class Reference:
             output += Record.INTERNAL_FORMAT % "MEDLINE"
             output += self.medline_id + "\n"
         return output
-    
+
     def _pubmed_line(self):
         """Output for PUBMED information.
         """
@@ -601,7 +604,7 @@ class Reference:
             output += Record.OTHER_INTERNAL_FORMAT % "PUBMED"
             output += self.pubmed_id + "\n"
         return output
-    
+
     def _remark_line(self):
         """Output for REMARK information.
         """
@@ -610,8 +613,9 @@ class Reference:
             output += Record.INTERNAL_FORMAT % "REMARK"
             output += _wrapped_genbank(self.remark, Record.GB_BASE_INDENT)
         return output
-    
-class Feature:
+
+
+class Feature(object):
     """Hold information about a Feature in the Feature Table of GenBank record.
 
     Attributes:
@@ -630,19 +634,20 @@ class Feature:
                                    split_char = ',')
         for qualifier in self.qualifiers:
             output += " " * Record.GB_FEATURE_INDENT
-            
+
             # determine whether we can wrap on spaces
             space_wrap = 1
             for no_space_key in \
-                Bio.GenBank._BaseGenBankConsumer.remove_space_keys:
-                if qualifier.key.find(no_space_key) >= 0:
+                    Bio.GenBank._BaseGenBankConsumer.remove_space_keys:
+                if no_space_key in qualifier.key:
                     space_wrap = 0
-            
+
             output += _wrapped_genbank(qualifier.key + qualifier.value,
                                        Record.GB_FEATURE_INDENT, space_wrap)
         return output
 
-class Qualifier:
+
+class Qualifier(object):
     """Hold information about a qualifier in a GenBank feature.
 
     Attributes:
