@@ -10,7 +10,7 @@ Rather than using Bio.GenBank, you are now encouraged to use Bio.SeqIO with
 the "genbank" or "embl" format names to parse GenBank or EMBL files into
 SeqRecord and SeqFeature objects (see the Biopython tutorial for details).
 
-Using Bio.GenBank directly to parse GenBank files is only useful if you want 
+Using Bio.GenBank directly to parse GenBank files is only useful if you want
 to obtain GenBank-specific Record objects, which is a much closer
 representation to the raw file contents that the SeqRecord alternative from
 the FeatureParser (used in Bio.SeqIO).
@@ -57,7 +57,7 @@ FEATURE_QUALIFIER_INDENT = 21
 FEATURE_KEY_SPACER = " " * FEATURE_KEY_INDENT
 FEATURE_QUALIFIER_SPACER = " " * FEATURE_QUALIFIER_INDENT
 
-#Regular expresions for location parsing
+#Regular expressions for location parsing
 _solo_location = r"[<>]?\d+"
 _pair_location = r"[<>]?\d+\.\.[<>]?\d+"
 _between_location = r"\d+\^\d+"
@@ -86,8 +86,8 @@ assert _re_oneof_position.match("one-of(3,6,9)")
 
 
 _simple_location = r"\d+\.\.\d+"
-_re_simple_location = re.compile(_simple_location)
-_re_simple_compound = re.compile(r"^(join|order|bond)\(%s(,%s)*\)$" \
+_re_simple_location = re.compile(r"^%s$" % _simple_location)
+_re_simple_compound = re.compile(r"^(join|order|bond)\(%s(,%s)*\)$"
                                  % (_simple_location, _simple_location))
 _complex_location = r"([a-zA-z][a-zA-Z0-9_]*(\.[a-zA-Z0-9]+)?\:)?(%s|%s|%s|%s|%s)" \
                     % (_pair_location, _solo_location, _between_location,
@@ -95,11 +95,12 @@ _complex_location = r"([a-zA-z][a-zA-Z0-9_]*(\.[a-zA-Z0-9]+)?\:)?(%s|%s|%s|%s|%s
 _re_complex_location = re.compile(r"^%s$" % _complex_location)
 _possibly_complemented_complex_location = r"(%s|complement\(%s\))" \
                                           % (_complex_location, _complex_location)
-_re_complex_compound = re.compile(r"^(join|order|bond)\(%s(,%s)*\)$" \
+_re_complex_compound = re.compile(r"^(join|order|bond)\(%s(,%s)*\)$"
                                  % (_possibly_complemented_complex_location,
                                     _possibly_complemented_complex_location))
 
 assert _re_simple_location.match("104..160")
+assert not _re_simple_location.match("68451760..68452073^68452074")
 assert not _re_simple_location.match("<104..>160")
 assert not _re_simple_location.match("104")
 assert not _re_simple_location.match("<1")
@@ -118,7 +119,7 @@ assert not _re_simple_compound.match("(1..69)")
 assert _re_complex_location.match("(3.9)..10")
 assert _re_complex_location.match("26..(30.33)")
 assert _re_complex_location.match("(13.19)..(20.28)")
-assert _re_complex_location.match("41^42") #between
+assert _re_complex_location.match("41^42")  # between
 assert _re_complex_location.match("AL121804:41^42")
 assert _re_complex_location.match("AL121804:41..610")
 assert _re_complex_location.match("AL121804.2:41..610")
@@ -139,7 +140,7 @@ assert not _re_simple_location.match("join(complement(149815..150200),complement
 
 def _pos(pos_str, offset=0):
     """Build a Position object (PRIVATE).
-    
+
     For an end position, leave offset as zero (default):
 
     >>> _pos("5")
@@ -213,7 +214,7 @@ def _pos(pos_str, offset=0):
     elif _re_oneof_position.match(pos_str):
         assert pos_str.startswith("one-of(")
         assert pos_str[-1]==")"
-        parts = [SeqFeature.ExactPosition(int(pos)+offset) \
+        parts = [SeqFeature.ExactPosition(int(pos)+offset)
                  for pos in pos_str[7:-1].split(",")]
         if offset == -1:
             default = min(int(pos) for pos in parts)
@@ -223,9 +224,10 @@ def _pos(pos_str, offset=0):
     else:
         return SeqFeature.ExactPosition(int(pos_str)+offset)
 
+
 def _loc(loc_str, expected_seq_length, strand):
     """FeatureLocation from non-compound non-complement location (PRIVATE).
-    
+
     Simple examples,
 
     >>> _loc("123..456", 1000, +1)
@@ -244,13 +246,13 @@ def _loc(loc_str, expected_seq_length, strand):
 
     >>> _loc("123^124", 1000, 0)
     FeatureLocation(ExactPosition(123), ExactPosition(123), strand=0)
-    
+
     The expected sequence length is needed for a special case, a between
     position at the start/end of a circular genome:
 
     >>> _loc("1000^1", 1000, 1)
     FeatureLocation(ExactPosition(1000), ExactPosition(1000), strand=1)
-    
+
     Apart from this special case, between positions P^Q must have P+1==Q,
 
     >>> _loc("123^456", 1000, 1)
@@ -284,9 +286,10 @@ def _loc(loc_str, expected_seq_length, strand):
             e = loc_str
     return SeqFeature.FeatureLocation(_pos(s,-1), _pos(e), strand)
 
+
 def _split_compound_loc(compound_loc):
     """Split a tricky compound location string (PRIVATE).
-    
+
     >>> list(_split_compound_loc("123..145"))
     ['123..145']
     >>> list(_split_compound_loc("123..145,200..209"))
@@ -315,7 +318,7 @@ def _split_compound_loc(compound_loc):
             assert compound_loc[0:2] != ".."
             i = compound_loc.find(",")
             part = compound_loc[:i]
-            compound_loc = compound_loc[i:] #includes the comma
+            compound_loc = compound_loc[i:]  # includes the comma
             while part.count("(") > part.count(")"):
                 assert "one-of(" in part, (part, compound_loc)
                 i = compound_loc.find(")")
@@ -328,7 +331,7 @@ def _split_compound_loc(compound_loc):
                     compound_loc = ""
                 else:
                     part += compound_loc[:i]
-                    compound_loc = compound_loc[i:] #includes the comma
+                    compound_loc = compound_loc[i:]  # includes the comma
             while part.count("(") > part.count(")"):
                 assert part.count("one-of(") == 2
                 i = compound_loc.find(")")
@@ -345,6 +348,7 @@ def _split_compound_loc(compound_loc):
         for part in compound_loc.split(","):
             yield part
 
+
 class Iterator(object):
     """Iterator interface to move over a file of GenBank entries one at a time (OBSOLETE).
 
@@ -372,9 +376,11 @@ class Iterator(object):
             lines = []
             while True:
                 line = self.handle.readline()
-                if not line : return None #Premature end of file?
+                if not line:
+                    return None  # Premature end of file?
                 lines.append(line)
-                if line.rstrip() == "//" : break
+                if line.rstrip() == "//":
+                    break
             return "".join(lines)
         try:
             return self._parser.parse(self.handle)
@@ -384,16 +390,19 @@ class Iterator(object):
     def __iter__(self):
         return iter(self.next, None)
 
+
 class ParserFailureError(Exception):
     """Failure caused by some kind of problem in the parser.
     """
     pass
 
+
 class LocationParserError(Exception):
     """Could not Properly parse out a location from a GenBank file.
     """
     pass
 
+
 class FeatureParser(object):
     """Parse GenBank files into Seq + Feature objects (OBSOLETE).
 
@@ -402,7 +411,7 @@ class FeatureParser(object):
 
     Please use Bio.SeqIO.parse(...) or Bio.SeqIO.read(...) instead.
     """
-    def __init__(self, debug_level = 0, use_fuzziness = 1, 
+    def __init__(self, debug_level = 0, use_fuzziness = 1,
                  feature_cleaner = FeatureValueCleaner()):
         """Initialize a GenBank parser and Feature consumer.
 
@@ -414,7 +423,7 @@ class FeatureParser(object):
         o use_fuzziness - Specify whether or not to use fuzzy representations.
         The default is 1 (use fuzziness).
         o feature_cleaner - A class which will be used to clean out the
-        values of features. This class must implement the function 
+        values of features. This class must implement the function
         clean_value. GenBank.utils has a "standard" cleaner class, which
         is used by default.
         """
@@ -425,11 +434,12 @@ class FeatureParser(object):
     def parse(self, handle):
         """Parse the specified handle.
         """
-        self._consumer = _FeatureConsumer(self.use_fuzziness, 
+        self._consumer = _FeatureConsumer(self.use_fuzziness,
                                           self._cleaner)
         self._scanner.feed(handle, self._consumer)
         return self._consumer.data
 
+
 class RecordParser(object):
     """Parse GenBank files into Record objects (OBSOLETE).
 
@@ -458,6 +468,7 @@ class RecordParser(object):
         self._scanner.feed(handle, self._consumer)
         return self._consumer.data
 
+
 class _BaseGenBankConsumer(object):
     """Abstract GenBank consumer providing useful general functions (PRIVATE).
 
@@ -508,7 +519,7 @@ class _BaseGenBankConsumer(object):
         if not taxonomy_string or taxonomy_string==".":
             #Missing data, no taxonomy
             return []
-        
+
         if taxonomy_string[-1] == '.':
             tax_info = taxonomy_string[:-1]
         else:
@@ -565,9 +576,9 @@ class _BaseGenBankConsumer(object):
         where 1 is the first base and [i, j] means to include both i and j.
 
         In python, 0 is the first base and [i, j] means to include i, but
-        not j. 
+        not j.
 
-        So, to convert "biological" to python coordinates, we need to 
+        So, to convert "biological" to python coordinates, we need to
         subtract 1 from the start, and leave the end and things should
         be converted happily.
         """
@@ -576,6 +587,7 @@ class _BaseGenBankConsumer(object):
 
         return new_start, new_end
 
+
 class _FeatureConsumer(_BaseGenBankConsumer):
     """Create a SeqRecord object with Features to return (PRIVATE).
 
@@ -619,7 +631,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         self.data.annotations['data_file_division'] = division
 
     def date(self, submit_date):
-        self.data.annotations['date'] = submit_date 
+        self.data.annotations['date'] = submit_date
 
     def definition(self, definition):
         """Set the definition as the description of the sequence.
@@ -650,7 +662,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
             self.data.annotations['accessions'] = new_acc_nums
 
         # if we haven't set the id information yet, add the first acc num
-        if self.data.id is None:
+        if not self.data.id:
             if len(new_acc_nums) > 0:
                 #self.data.id = new_acc_nums[0]
                 #Use the FIRST accession as the ID, not the first on this line!
@@ -677,7 +689,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         if version_id.count(".")==1 and version_id.split(".")[1].isdigit():
             self.accession(version_id.split(".")[0])
             self.version_suffix(version_id.split(".")[1])
-        else:
+        elif version_id:
             #For backwards compatibility...
             self.data.id = version_id
 
@@ -704,7 +716,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         This line type is expected to replace the PROJECT line in 2009. e.g.
 
         During transition:
-        
+
         PROJECT     GenomeProject:28471
         DBLINK      Project:28471
                     Trace Assembly Archive:123456
@@ -784,7 +796,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
             self.data.annotations['taxonomy'].extend(lineage)
         except KeyError:
             self.data.annotations['taxonomy'] = lineage
-        
+
     def reference_num(self, content):
         """Signal the beginning of a new reference object.
         """
@@ -801,7 +813,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         """Attempt to determine the sequence region the reference entails.
 
         Possible types of information we may have to deal with:
-        
+
         (bases 1 to 86436)
         (sites)
         (bases 1 to 105654; 110423 to 111122)
@@ -812,14 +824,12 @@ class _FeatureConsumer(_BaseGenBankConsumer):
 
         all_locations = []
         # parse if we've got 'bases' and 'to'
-        if ref_base_info.find('bases') != -1 and \
-            ref_base_info.find('to') != -1:
+        if 'bases' in ref_base_info and 'to' in ref_base_info:
             # get rid of the beginning 'bases'
             ref_base_info = ref_base_info[5:]
             locations = self._split_reference_locations(ref_base_info)
             all_locations.extend(locations)
-        elif (ref_base_info.find("residues") >= 0 and
-              ref_base_info.find("to") >= 0):
+        elif 'residues' in ref_base_info and 'to' in ref_base_info:
             residues_start = ref_base_info.find("residues")
             # get only the information after "residues"
             ref_base_info = ref_base_info[(residues_start + len("residues ")):]
@@ -840,7 +850,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
 
     def _split_reference_locations(self, location_string):
         """Get reference locations out of a string of reference information
-        
+
         The passed string should be of the form:
 
             1 to 20; 20 to 100
@@ -943,10 +953,10 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         # the number 266 and have the information in a more reasonable
         # place. So we'll just grab out the number and feed this to the
         # parser. We shouldn't really be losing any info this way.
-        if location_line.find('replace') != -1:
+        if 'replace' in location_line:
             comma_pos = location_line.find(',')
             location_line = location_line[8:comma_pos]
-        
+
         cur_feature = self._cur_feature
 
         #Handle top level complement here for speed
@@ -954,8 +964,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
             assert location_line.endswith(")")
             location_line = location_line[11:-1]
             strand = -1
-        elif self._seq_type.find("DNA") >= 0 \
-        or self._seq_type.find("RNA") >= 0:
+        elif 'DNA' in self._seq_type.upper() or 'RNA' in self._seq_type.upper():
             #Nucleotide
             strand = 1
         else:
@@ -988,7 +997,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
             e = cur_feature.sub_features[-1].location.end
             cur_feature.location = SeqFeature.FeatureLocation(s,e, strand)
             return
-        
+
         #Handle the general case with more complex regular expressions
         if _re_complex_location.match(location_line):
             #e.g. "AL121804.2:41..610"
@@ -1051,13 +1060,12 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         cur_feature.location = None
         import warnings
         from Bio import BiopythonParserWarning
-        warnings.warn(BiopythonParserWarning("Couldn't parse feature location: %r" \
+        warnings.warn(BiopythonParserWarning("Couldn't parse feature location: %r"
                                              % (location_line)))
 
-
     def feature_qualifier(self, key, value):
         """When we get a qualifier key and its value.
-        
+
         Can receive None, since you can have valueless keys such as /pseudo
         """
         # Hack to try to preserve historical behaviour of /pseudo etc
@@ -1065,7 +1073,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
             if key not in self._cur_feature.qualifiers:
                 self._cur_feature.qualifiers[key] = [""]
                 return
-            
+
         value = value.replace('"', '')
         if self._feature_cleaner is not None:
             value = self._feature_cleaner.clean_value(key, value)
@@ -1076,7 +1084,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         # otherwise start a new list of the key with its values
         else:
             self._cur_feature.qualifiers[key] = [value]
-       
+
     def feature_qualifier_name(self, content_list):
         """Use feature_qualifier instead (OBSOLETE)."""
         raise NotImplementedError("Use the feature_qualifier method instead.")
@@ -1131,16 +1139,16 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         from Bio.Seq import Seq, UnknownSeq
 
         #Try and append the version number to the accession for the full id
-        if self.data.id is None:
+        if not self.data.id:
             assert 'accessions' not in self.data.annotations, \
                    self.data.annotations['accessions']
-            self.data.id = self.data.name #Good fall back?
+            self.data.id = self.data.name  # Good fall back?
         elif self.data.id.count('.') == 0:
             try:
                 self.data.id+='.%i' % self.data.annotations['sequence_version']
             except KeyError:
                 pass
-        
+
         # add the sequence information
         # first, determine the alphabet
         # we default to an generic alphabet if we don't have a
@@ -1155,24 +1163,23 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         and self._expected_size != len(sequence):
             import warnings
             from Bio import BiopythonParserWarning
-            warnings.warn("Expected sequence length %i, found %i (%s)." \
+            warnings.warn("Expected sequence length %i, found %i (%s)."
                           % (self._expected_size, len(sequence), self.data.id),
                           BiopythonParserWarning)
 
         if self._seq_type:
             # mRNA is really also DNA, since it is actually cDNA
-            if self._seq_type.find('DNA') != -1 or \
-               self._seq_type.find('mRNA') != -1:
+            if 'DNA' in self._seq_type.upper() or 'MRNA' in self._seq_type.upper():
                 seq_alphabet = IUPAC.ambiguous_dna
             # are there ever really RNA sequences in GenBank?
-            elif self._seq_type.find('RNA') != -1:
+            elif 'RNA' in self._seq_type.upper():
                 #Even for data which was from RNA, the sequence string
                 #is usually given as DNA (T not U).  Bug 2408
                 if "T" in sequence and "U" not in sequence:
                     seq_alphabet = IUPAC.ambiguous_dna
                 else:
                     seq_alphabet = IUPAC.ambiguous_rna
-            elif self._seq_type.upper().find('PROTEIN') != -1:
+            elif 'PROTEIN' in self._seq_type.upper():
                 seq_alphabet = IUPAC.protein  # or extended protein?
             # work around ugly GenBank records which have circular or
             # linear but no indication of sequence type
@@ -1188,6 +1195,7 @@ class _FeatureConsumer(_BaseGenBankConsumer):
         else:
             self.data.seq = Seq(sequence, seq_alphabet)
 
+
 class _RecordConsumer(_BaseGenBankConsumer):
     """Create a GenBank Record object from scanner generated information (PRIVATE).
     """
@@ -1200,7 +1208,7 @@ class _RecordConsumer(_BaseGenBankConsumer):
         self._cur_reference = None
         self._cur_feature = None
         self._cur_qualifier = None
-        
+
     def wgs(self, content):
         self.data.wgs = content.split('-')
 
@@ -1214,6 +1222,12 @@ class _RecordConsumer(_BaseGenBankConsumer):
         self.data.size = content
 
     def residue_type(self, content):
+        # Be lenient about parsing, but technically lowercase residue types are malformed.
+        if 'dna' in content or 'rna' in content:
+            import warnings
+            from Bio import BiopythonParserWarning
+            warnings.warn("Invalid seq_type (%s): DNA/RNA should be uppercase." % content,
+                          BiopythonParserWarning)
         self.data.residue_type = content
 
     def data_file_division(self, content):
@@ -1300,13 +1314,13 @@ class _RecordConsumer(_BaseGenBankConsumer):
 
     def medline_id(self, content):
         self._cur_reference.medline_id = content
-        
+
     def pubmed_id(self, content):
         self._cur_reference.pubmed_id = content
 
     def remark(self, content):
         self._cur_reference.remark = content
-        
+
     def comment(self, content):
         self.data.comment += "\n".join(content)
 
@@ -1316,7 +1330,7 @@ class _RecordConsumer(_BaseGenBankConsumer):
 
     def primary(self,content):
         pass
-    
+
     def features_line(self, content):
         """Get ready for the feature table when we reach the FEATURE line.
         """
@@ -1365,7 +1379,7 @@ class _RecordConsumer(_BaseGenBankConsumer):
 
     def feature_qualifier_name(self, content_list):
         """Deal with qualifier names
-        
+
         We receive a list of keys, since you can have valueless keys such as
         /pseudo which would be passed in with the next key (since no other
         tags separate them in the file)
@@ -1373,7 +1387,7 @@ class _RecordConsumer(_BaseGenBankConsumer):
         import Record
         for content in content_list:
             # the record parser keeps the /s -- add them if we don't have 'em
-            if content.find("/") != 0:
+            if not content.startswith("/"):
                 content = "/%s" % content
             # add on a qualifier if we've got one
             if self._cur_qualifier is not None:
@@ -1384,13 +1398,13 @@ class _RecordConsumer(_BaseGenBankConsumer):
 
     def feature_qualifier_description(self, content):
         # if we have info then the qualifier key should have a ='s
-        if self._cur_qualifier.key.find("=") == -1:
+        if '=' not in self._cur_qualifier.key:
             self._cur_qualifier.key = "%s=" % self._cur_qualifier.key
         cur_content = self._remove_newlines(content)
         # remove all spaces from the value if it is a type where spaces
         # are not important
         for remove_space_key in self.__class__.remove_space_keys:
-            if self._cur_qualifier.key.find(remove_space_key) >= 0:
+            if remove_space_key in self._cur_qualifier.key:
                 cur_content = self._remove_spaces(cur_content)
         self._cur_qualifier.value = self._normalize_spaces(cur_content)
 
@@ -1403,7 +1417,7 @@ class _RecordConsumer(_BaseGenBankConsumer):
     def contig_location(self, content):
         """Signal that we have contig information to add to the record.
         """
-        self.data.contig = self._clean_location(content) 
+        self.data.contig = self._clean_location(content)
 
     def sequence(self, content):
         """Add sequence information to a list of sequence strings.
@@ -1441,6 +1455,7 @@ def parse(handle):
     """
     return iter(Iterator(handle, RecordParser()))
 
+
 def read(handle):
     """Read a handle containing a single GenBank entry as a Record object.
 
@@ -1450,7 +1465,7 @@ def read(handle):
     >>> print record.accession
     ['NC_000932']
     >>> handle.close()
-                       
+
     To get a SeqRecord object use Bio.SeqIO.read(..., format="gb")
     instead.
     """
@@ -1469,12 +1484,13 @@ def read(handle):
         raise ValueError("More than one record found in handle")
     return first
 
+
 def _test():
     """Run the Bio.GenBank module's doctests."""
     import doctest
     import os
     if os.path.isdir(os.path.join("..","..","Tests")):
-        print "Runing doctests..."
+        print "Running doctests..."
         cur_dir = os.path.abspath(os.curdir)
         os.chdir(os.path.join("..","..","Tests"))
         doctest.testmod()
@@ -1482,7 +1498,7 @@ def _test():
         del cur_dir
         print "Done"
     elif os.path.isdir(os.path.join("Tests")):
-        print "Runing doctests..."
+        print "Running doctests..."
         cur_dir = os.path.abspath(os.curdir)
         os.chdir(os.path.join("Tests"))
         doctest.testmod()
