@@ -13,7 +13,8 @@ o Record - All of the information in an GEO record.
 See http://www.ncbi.nlm.nih.gov/geo/
 """
 
-class Record:
+
+class Record(object):
     """Hold GEO information in a format similar to the original record.
 
     The Record class is meant to make data easy to get to when you are
@@ -42,14 +43,14 @@ class Record:
         att_keys.sort()
         for key in att_keys:
             contents = self.entity_attributes[ key ]
-            if( type( contents ) == type( [] ) ):
+            if isinstance(contents, list):
                 for item in contents:
                     try:
                         output = output + '%s: %s\n' % ( key, item[ :40 ] )
                         output = output + out_block( item[ 40: ] )
                     except:
                         pass
-            elif( type( contents ) == type( '' ) ):
+            elif isinstance(contents, str):
                 output = output + '%s: %s\n' % ( key, contents[ :40 ] )
                 output = output + out_block( contents[ 40: ] )
             else:
@@ -78,12 +79,13 @@ class Record:
             for col in row:
                 output = output + '%s\t' % col
             output = output + '\n'
-            
+
         return output
 
+
 def out_block( text, prefix = '' ):
     output = ''
     for j in range( 0, len( text ), 80 ):
-        output = output + '%s%s\n'  % ( prefix, text[ j: j + 80 ] )
+        output = output + '%s%s\n' % ( prefix, text[ j: j + 80 ] )
     output = output + '\n'
     return output
