@@ -29,7 +29,6 @@ from reportlab.lib import colors
 # GenomeDiagram imports
 from _Colors import ColorTranslator
 
-import string
 
 class Feature(object):
     """ Class to wrap Bio.SeqFeature objects for GenomeDiagram
@@ -75,7 +74,7 @@ class Feature(object):
         o arrowshaft_height  Float denoting length of the representative arrow
                              shaft to be drawn, relative to the bounding box height.
                              The arrow head takes the full height of the bound box.
-         
+
         o name_qualifiers   List of Strings, describes the qualifiers that may
                     contain feature names in the wrapped Bio.SeqFeature object
 
@@ -104,7 +103,7 @@ class Feature(object):
 
     """
     def __init__(self, parent=None, feature_id=None, feature=None,
-                 color=colors.lightgreen, label=0, colour=None):
+                 color=colors.lightgreen, label=0, border=None, colour=None):
         """ __init__(self, parent=None, feature_id=None, feature=None,
                  color=colors.lightgreen, label=0)
 
@@ -119,6 +118,9 @@ class Feature(object):
                        colour).  Either argument is overridden if 'color'
                        is found in feature qualifiers
 
+            o border   color.Color Color to draw the feature border, use
+                       None for the same as the fill color, False for no border.
+
             o label     Boolean, 1 if the label should be shown
         """
         #Let the UK spelling (colour) override the USA spelling (color)
@@ -126,11 +128,12 @@ class Feature(object):
             color = colour
 
         self._colortranslator = ColorTranslator()
-        
+
         # Initialise attributes
         self.parent = parent
-        self.id = feature_id        
+        self.id = feature_id
         self.color = color            # default color to draw the feature
+        self.border = border
         self._feature = None            # Bio.SeqFeature object to wrap
         self.hide = 0                   # show by default
         self.sigil = 'BOX'
@@ -143,7 +146,7 @@ class Feature(object):
         self.label_color = colors.black
         self.label_angle = 45
         self.label_position = 'start'
-        
+
         if feature is not None:
             self.set_feature(feature)
 
@@ -157,7 +160,6 @@ class Feature(object):
         self._feature = feature
         self.__process_feature()
 
-
     def __process_feature(self):
         """ __process_feature(self)
 
@@ -175,13 +177,14 @@ class Feature(object):
             bounds += [start, end]
         else:
             for subfeature in self._feature.sub_features:
-                start = self._feature.location.nofuzzy_start
-                end = self._feature.location.nofuzzy_end
+                start = subfeature.location.nofuzzy_start
+                end = subfeature.location.nofuzzy_end
                 #if start > end and self.strand == -1:
                 #    start, end = end, start
-                self.locations.append((start, end))                
+                self.locations.append((start, end))
                 bounds += [start, end]
         self.type = str(self._feature.type)                     # Feature type
+        #TODO - Strand can vary with subfeatures (e.g. mixed strand tRNA)
         if self._feature.strand is None:
             #This is the SeqFeature default (None), but the drawing code
             #only expects 0, +1 or -1.
@@ -189,23 +192,16 @@ class Feature(object):
         else:
             self.strand = int(self._feature.strand)                 # Feature strand
         if 'color' in self._feature.qualifiers:                # Artemis color (if present)
-            # Artemis color used to be only a single integer, but as of
-            # Oct '04 appears to be dot-delimited.  This is a quick fix to
-            # allow dot-delimited strings, but only use the first integer
-            artemis_color = self._feature.qualifiers['color'][0] # Local copy of string
-            if artemis_color.count('.'):                          # dot-delimited
-                artemis_color = artemis_color.split('.')[0]      # Use only first integer
-            else:                                     # Assume just an integer
-                artemis_color = artemis_color       # Use integer
-            self.color = self._colortranslator.artemis_color(artemis_color)
+            self.color = self._colortranslator.artemis_color(
+                                         self._feature.qualifiers['color'][0])
         self.name = self.type
-        for qualifier in self.name_qualifiers:            
+        for qualifier in self.name_qualifiers:
             if qualifier in self._feature.qualifiers:
                 self.name = self._feature.qualifiers[qualifier][0]
                 break
+        #Note will be 0 to N for origin wrapping feature on genome of length N
         self.start, self.end = min(bounds), max(bounds)
 
-
     def get_feature(self):
         """ get_feature(self) -> Bio.SeqFeature
 
@@ -224,7 +220,7 @@ class Feature(object):
             o color    The color to draw the feature - either a colors.Color
                        object, an RGB tuple of floats, or an integer
                        corresponding to colors in colors.txt
-                           
+
             Set the color in which the feature will be drawn
         """
         #TODO - Make this into the set method for a color property?
@@ -240,7 +236,6 @@ class Feature(object):
         return getattr(self._feature, name) # try to get the attribute from the feature
 
 
-    
 ################################################################################
 # RUN AS SCRIPT
 ################################################################################
