@@ -32,7 +32,8 @@ id_wrap = lambda indent : [indent, "",
 struct_wrap = lambda indent : [indent, "",
                                ("  ","",1,1)]
 
-class Record:
+
+class Record(object):
     """Holds info from a KEGG Enzyme record.
 
     Members:
@@ -74,13 +75,14 @@ class Record:
         self.disease    = []
         self.structures = []
         self.dblinks    = []
+
     def __str__(self):
         """__str__(self)
 
         Returns a string representation of this Record.
         """
         return self._entry() + \
-               self._name()  + \
+               self._name() + \
                self._classname() + \
                self._sysname() + \
                self._reaction() + \
@@ -96,76 +98,92 @@ class Record:
                self._structures() + \
                self._dblinks() + \
                "///"
+
     def _entry(self):
         return _write_kegg("ENTRY",
                            ["EC " + self.entry])
+
     def _name(self):
         return _write_kegg("NAME",
-                           [_wrap_kegg(l, wrap_rule = name_wrap) \
+                           [_wrap_kegg(l, wrap_rule = name_wrap)
                             for l in self.name])
+
     def _classname(self):
         return _write_kegg("CLASS",
                            self.classname)
+
     def _sysname(self):
         return _write_kegg("SYSNAME",
-                           [_wrap_kegg(l, wrap_rule = name_wrap) \
+                           [_wrap_kegg(l, wrap_rule = name_wrap)
                             for l in self.sysname])
+
     def _reaction(self):
         return _write_kegg("REACTION",
-                           [_wrap_kegg(l, wrap_rule = rxn_wrap) \
+                           [_wrap_kegg(l, wrap_rule = rxn_wrap)
                             for l in self.reaction])
+
     def _substrate(self):
         return _write_kegg("SUBSTRATE",
-                           [_wrap_kegg(l, wrap_rule = name_wrap) \
+                           [_wrap_kegg(l, wrap_rule = name_wrap)
                             for l in self.substrate])
+
     def _product(self):
         return _write_kegg("PRODUCT",
-                           [_wrap_kegg(l, wrap_rule = name_wrap) \
+                           [_wrap_kegg(l, wrap_rule = name_wrap)
                             for l in self.product])
+
     def _inhibitor(self):
         return _write_kegg("INHIBITOR",
-                           [_wrap_kegg(l, wrap_rule = name_wrap) \
+                           [_wrap_kegg(l, wrap_rule = name_wrap)
                             for l in self.inhibitor])
+
     def _cofactor(self):
         return _write_kegg("COFACTOR",
-                           [_wrap_kegg(l, wrap_rule = name_wrap) \
+                           [_wrap_kegg(l, wrap_rule = name_wrap)
                             for l in self.cofactor])
+
     def _effector(self):
         return _write_kegg("EFFECTOR",
-                           [_wrap_kegg(l, wrap_rule = name_wrap) \
+                           [_wrap_kegg(l, wrap_rule = name_wrap)
                             for l in self.effector])
+
     def _comment(self):
         return _write_kegg("COMMENT",
-                           [_wrap_kegg(l, wrap_rule = id_wrap(0)) \
+                           [_wrap_kegg(l, wrap_rule = id_wrap(0))
                             for l in self.comment])
+
     def _pathway(self):
         s = []
         for entry in self.pathway:
             s.append(entry[0] + ": " + entry[1] + "  " + entry[2])
         return _write_kegg("PATHWAY",
-                           [_wrap_kegg(l, wrap_rule = id_wrap(16)) \
+                           [_wrap_kegg(l, wrap_rule = id_wrap(16))
                             for l in s])
+
     def _genes(self):
         s = []
         for entry in self.genes:
             s.append(entry[0] + ": " + " ".join(entry[1]))
         return _write_kegg("GENES",
-                           [_wrap_kegg(l, wrap_rule = id_wrap(5)) \
+                           [_wrap_kegg(l, wrap_rule = id_wrap(5))
                             for l in s])
+
     def _disease(self):
         s = []
         for entry in self.disease:
             s.append(entry[0] + ": " + entry[1] + "  " + entry[2])
         return _write_kegg("DISEASE",
-                           [_wrap_kegg(l, wrap_rule = id_wrap(13)) \
-                            for l in s])    
+                           [_wrap_kegg(l, wrap_rule = id_wrap(13))
+                            for l in s])
+
     def _structures(self):
         s = []
         for entry in self.structures:
             s.append(entry[0] + ": " + "  ".join(entry[1]) + "  ")
         return _write_kegg("STRUCTURES",
-                           [_wrap_kegg(l, wrap_rule = struct_wrap(5)) \
+                           [_wrap_kegg(l, wrap_rule = struct_wrap(5))
                             for l in s])
+
     def _dblinks(self):
         # This is a bit of a cheat that won't work if enzyme entries
         # have more than one link id per db id. For now, that's not
@@ -177,7 +195,6 @@ class Record:
         return _write_kegg("DBLINKS", s)
 
 
-
 def parse(handle):
     """Parse a KEGG Enzyme file, returning Record objects.
 
@@ -241,7 +258,7 @@ def parse(handle):
                 row = database, number, name
                 record.disease[-1] = row
         elif keyword=="EFFECTOR    ":
-             record.effector.append(data.strip(";"))
+            record.effector.append(data.strip(";"))
         elif keyword=="GENES       ":
             if data[3:5]==': ':
                 key, values = data.split(":",1)
@@ -257,24 +274,22 @@ def parse(handle):
                 row = key, values
                 record.genes[-1] = row
         elif keyword=="INHIBITOR   ":
-             record.inhibitor.append(data.strip(";"))
+            record.inhibitor.append(data.strip(";"))
         elif keyword=="NAME        ":
-             record.name.append(data.strip(";"))
+            record.name.append(data.strip(";"))
         elif keyword=="PATHWAY     ":
             if data[:5]=='PATH:':
-                path, map, name = data.split(None,2)
-                pathway = (path[:-1], map, name)
+                _, map_num, name = data.split(None,2)
+                pathway = ('PATH', map_num, name)
                 record.pathway.append(pathway)
             else:
-                pathway = record.pathway[-1]
-                path, map, name = pathway
-                name = name + " " + data
-                pathway = path, map, name
-                record.pathway[-1] = pathway
+                ec_num, name = data.split(None,1)
+                pathway = 'PATH', ec_num, name
+                record.pathway.append(pathway)
         elif keyword=="PRODUCT     ":
-             record.product.append(data.strip(";"))
+            record.product.append(data.strip(";"))
         elif keyword=="REACTION    ":
-             record.reaction.append(data.strip(";"))
+            record.reaction.append(data.strip(";"))
         elif keyword=="STRUCTURES  ":
             if data[:4]=='PDB:':
                 database = data[:3]
@@ -288,26 +303,11 @@ def parse(handle):
                 row = (database, accessions)
                 record.structures[-1] = row
         elif keyword=="SUBSTRATE   ":
-             record.substrate.append(data.strip(";"))
+            record.substrate.append(data.strip(";"))
         elif keyword=="SYSNAME     ":
-             record.sysname.append(data.strip(";"))
+            record.sysname.append(data.strip(";"))
 
-def _test():
-    """Run the Bio.KEGG.Enzyme module's doctests.
-    
-    This will try and locate the unit tests directory, and run the doctests
-    from there in order that the relative paths used in the examples work.
-    """
-    import doctest
-    import os
-    if os.path.isdir(os.path.join("..","..","..","Tests")):
-        print "Runing doctests..."
-        cur_dir = os.path.abspath(os.curdir)
-        os.chdir(os.path.join("..","..","..","Tests"))
-        doctest.testmod()
-        os.chdir(cur_dir)
-        del cur_dir
-        print "Done"
 
 if __name__ == "__main__":
-    _test()
+    from Bio._utils import run_doctest
+    run_doctest()
