@@ -14,10 +14,11 @@ from Bio.Seq import Seq
 # local modules
 from Pattern import PatternRepository
 
-class MotifFinder:
+
+class MotifFinder(object):
     """Find motifs in a set of Sequence Records.
     """
-    def __init__(self, alphabet_strict = 1):
+    def __init__(self, alphabet_strict=1):
         """Initialize a finder to get motifs.
 
         Arguments:
@@ -71,7 +72,7 @@ class MotifFinder:
 
             # now start finding motifs in the sequence
             for start in range(len(seq_record.seq) - (motif_size - 1)):
-                motif = seq_record.seq[start:start + motif_size].tostring()
+                motif = str(seq_record.seq[start:start + motif_size])
 
                 # if we are being alphabet strict, make sure the motif
                 # falls within the specified alphabet
@@ -130,7 +131,7 @@ class MotifFinder:
             motif_diffs[cur_key] = 0 - second_motifs[cur_key]
 
         return PatternRepository(motif_diffs)
-                
+
     def _add_motif(self, motif_dict, motif_to_add):
         """Add a motif to the given dictionary.
         """
@@ -142,8 +143,9 @@ class MotifFinder:
             motif_dict[motif_to_add] = 1
 
         return motif_dict
-    
-class MotifCoder:
+
+
+class MotifCoder(object):
     """Convert motifs and a sequence into neural network representations.
 
     This is designed to convert a sequence into a representation that
@@ -176,7 +178,7 @@ class MotifCoder:
 
         This converts a sequence into a representation based on the motifs.
         The representation is returned as a list of the relative amount of
-        each motif (number of times a motif occured divided by the total
+        each motif (number of times a motif occurred divided by the total
         number of motifs in the sequence). The values in the list correspond
         to the input order of the motifs specified in the initializer.
         """
@@ -184,10 +186,10 @@ class MotifCoder:
         seq_motifs = {}
         for motif in self._motifs:
             seq_motifs[motif] = 0
-        
+
         # count all of the motifs we are looking for in the sequence
         for start in range(len(sequence) - (self._motif_size - 1)):
-            motif = sequence[start:start + self._motif_size].tostring()
+            motif = str(sequence[start:start + self._motif_size])
 
             if motif in seq_motifs:
                 seq_motifs[motif] += 1
@@ -197,7 +199,7 @@ class MotifCoder:
         max_count = max(seq_motifs.values())
 
         # as long as we have some motifs present, normalize them
-        # otherwise we'll just return 0 for everything 
+        # otherwise we'll just return 0 for everything
         if max_count > 0:
             for motif in seq_motifs.keys():
                 seq_motifs[motif] = (float(seq_motifs[motif] - min_count)
@@ -209,4 +211,3 @@ class MotifCoder:
             motif_amounts.append(seq_motifs[motif])
 
         return motif_amounts
-        
