@@ -11,8 +11,7 @@ import numpy
 
 from Bio.PDB.MMCIF2Dict import MMCIF2Dict
 from Bio.PDB.StructureBuilder import StructureBuilder
-from Bio.PDB.PDBExceptions import \
-        PDBConstructionException, PDBConstructionWarning
+from Bio.PDB.PDBExceptions import PDBConstructionException
 
 
 class MMCIFParser(object):
@@ -73,7 +72,7 @@ class MMCIFParser(object):
         # Historically, Biopython PDB parser uses model_id to mean array index
         # so serial_id means the Model ID specified in the file
         current_model_id = 0
-        current_serial_id = 0 
+        current_serial_id = 0
         for i in xrange(0, len(atom_id_list)):
             x=x_list[i]
             y=y_list[i]
@@ -108,17 +107,17 @@ class MMCIFParser(object):
                 structure_builder.init_chain(current_chain_id)
                 current_residue_id=resseq
                 icode, int_resseq=self._get_icode(resseq)
-                structure_builder.init_residue(resname, hetatm_flag, int_resseq, 
+                structure_builder.init_residue(resname, hetatm_flag, int_resseq,
                     icode)
             elif current_residue_id!=resseq:
                 current_residue_id=resseq
                 icode, int_resseq=self._get_icode(resseq)
-                structure_builder.init_residue(resname, hetatm_flag, int_resseq, 
+                structure_builder.init_residue(resname, hetatm_flag, int_resseq,
                     icode)
-            coord=numpy.array((x, y, z), 'f')  
+            coord=numpy.array((x, y, z), 'f')
             element = element_list[i] if element_list else None
             structure_builder.init_atom(name, coord, tempfactor, occupancy, altloc,
-                name, element=element)   
+                name, element=element)
             if aniso_flag==1:
                 u=(aniso_u11[i], aniso_u12[i], aniso_u13[i],
                     aniso_u22[i], aniso_u23[i], aniso_u33[i])
@@ -136,13 +135,13 @@ class MMCIFParser(object):
             cell=numpy.array((a, b, c, alpha, beta, gamma), 'f')
             spacegroup=mmcif_dict["_symmetry.space_group_name_H-M"]
             spacegroup=spacegroup[1:-1] # get rid of quotes!!
-            if spacegroup==None:
+            if spacegroup is None:
                 raise Exception
             structure_builder.set_symmetry(spacegroup, cell)
         except:
             pass    # no cell found, so just ignore
 
-    def _get_icode(self, resseq):           
+    def _get_icode(self, resseq):
         """Tries to return the icode. In MMCIF files this is just part of
         resseq! In PDB files, it's a separate field."""
         last_resseq_char=resseq[-1]
@@ -152,7 +151,7 @@ class MMCIFParser(object):
         else:
             icode=" "
             int_resseq=int(resseq)
-        return icode, int_resseq    
+        return icode, int_resseq
 
 
 if __name__=="__main__":
@@ -172,4 +171,3 @@ if __name__=="__main__":
         for chain in model.get_list():
             print chain
             print "Found %d residues." % len(chain.get_list())
-
