@@ -54,11 +54,10 @@ from Bio.Alphabet import generic_protein
 from Bio.Seq import Seq
 from Bio.SCOP.Raf import to_one_letter_code
 from Bio.PDB.PDBExceptions import PDBException
-from Bio.PDB.Residue import Residue, DisorderedResidue
 from Bio.PDB.Vector import calc_dihedral, calc_angle
 
 
-standard_aa_names=["ALA", "CYS", "ASP", "GLU", "PHE", "GLY", "HIS", "ILE", "LYS", 
+standard_aa_names=["ALA", "CYS", "ASP", "GLU", "PHE", "GLY", "HIS", "ILE", "LYS",
                    "LEU", "MET", "ASN", "PRO", "GLN", "ARG", "SER", "THR", "VAL",
                    "TRP", "TYR"]
 
@@ -80,9 +79,10 @@ for i in range(0, 20):
     d3_to_index[n3]=i
     dindex_to_3[i]=n3
 
+
 def index_to_one(index):
     """Index to corresponding one letter amino acid name.
-    
+
     >>> index_to_one(0)
     'A'
     >>> index_to_one(19)
@@ -90,9 +90,10 @@ def index_to_one(index):
     """
     return dindex_to_1[index]
 
+
 def one_to_index(s):
     """One letter code to index.
-    
+
     >>> one_to_index('A')
     0
     >>> one_to_index('Y')
@@ -100,9 +101,10 @@ def one_to_index(s):
     """
     return d1_to_index[s]
 
+
 def index_to_three(i):
     """Index to corresponding three letter amino acid name.
-    
+
     >>> index_to_three(0)
     'ALA'
     >>> index_to_three(19)
@@ -110,9 +112,10 @@ def index_to_three(i):
     """
     return dindex_to_3[i]
 
+
 def three_to_index(s):
     """Three letter code to index.
-    
+
     >>> three_to_index('ALA')
     0
     >>> three_to_index('TYR')
@@ -120,9 +123,10 @@ def three_to_index(s):
     """
     return d3_to_index[s]
 
+
 def three_to_one(s):
     """Three letter code to one letter code.
-    
+
     >>> three_to_one('ALA')
     'A'
     >>> three_to_one('TYR')
@@ -138,9 +142,10 @@ def three_to_one(s):
     i=d3_to_index[s]
     return dindex_to_1[i]
 
+
 def one_to_three(s):
     """One letter code to three letter code.
-    
+
     >>> one_to_three('A')
     'ALA'
     >>> one_to_three('Y')
@@ -149,13 +154,14 @@ def one_to_three(s):
     i=d1_to_index[s]
     return dindex_to_3[i]
 
+
 def is_aa(residue, standard=False):
     """Return True if residue object/string is an amino acid.
 
     @param residue: a L{Residue} object OR a three letter amino acid code
     @type residue: L{Residue} or string
 
-    @param standard: flag to check for the 20 AA (default false) 
+    @param standard: flag to check for the 20 AA (default false)
     @type standard: boolean
 
     >>> is_aa('ALA')
@@ -182,7 +188,7 @@ class Polypeptide(list):
     """A polypeptide is simply a list of L{Residue} objects."""
     def get_ca_list(self):
         """Get list of C-alpha atoms in the polypeptide.
-        
+
         @return: the list of C-alpha atoms
         @rtype: [L{Atom}, L{Atom}, ...]
         """
@@ -268,7 +274,7 @@ class Polypeptide(list):
     def get_sequence(self):
         """Return the AA sequence as a Seq object.
 
-        @return: polypeptide sequence 
+        @return: polypeptide sequence
         @rtype: L{Seq}
         """
         s=""
@@ -279,7 +285,7 @@ class Polypeptide(list):
 
     def __repr__(self):
         """Return string representation of the polypeptide.
-        
+
         Return <Polypeptide start=START end=END>, where START
         and END are sequence identifiers of the outer residues.
         """
@@ -288,12 +294,13 @@ class Polypeptide(list):
         s="<Polypeptide start=%s end=%s>" % (start, end)
         return s
 
+
 class _PPBuilder:
     """Base class to extract polypeptides.
-    
+
     It checks if two consecutive residues in a chain are connected.
     The connectivity test is implemented by a subclass.
-    
+
     This assumes you want both standard and non-standard amino acids.
     """
     def __init__(self, radius):
@@ -317,7 +324,7 @@ class _PPBuilder:
         else:
             # not a standard AA so skip
             return False
-    
+
     def build_peptides(self, entity, aa_only=1):
         """Build and return a list of Polypeptide objects.
 
@@ -330,7 +337,7 @@ class _PPBuilder:
         is_connected=self._is_connected
         accept=self._accept
         level=entity.get_level()
-        # Decide wich entity we are dealing with
+        # Decide which entity we are dealing with
         if level=="S":
             model=entity[0]
             chain_list=model.get_list()
@@ -419,12 +426,12 @@ class PPBuilder(_PPBuilder):
             nlist=[n]
         for nn in nlist:
             for cc in clist:
-                # To form a peptide bond, N and C must be 
+                # To form a peptide bond, N and C must be
                 # within radius and have the same altloc
                 # identifier or one altloc blank
                 n_altloc=nn.get_altloc()
                 c_altloc=cc.get_altloc()
-                if n_altloc==c_altloc or n_altloc==" " or c_altloc==" ": 
+                if n_altloc==c_altloc or n_altloc==" " or c_altloc==" ":
                     if test_dist(nn, cc):
                         # Select the disordered atoms that
                         # are indeed bonded
@@ -441,7 +448,7 @@ class PPBuilder(_PPBuilder):
             return 1
         else:
             return 0
-    
+
 
 if __name__=="__main__":
     import sys
@@ -474,4 +481,3 @@ if __name__=="__main__":
         print pp.get_sequence()
     for pp in ppb.build_peptides(s[0]["A"]):
         print pp.get_sequence()
-
