@@ -9,6 +9,7 @@ warnings.warn("The module Bio.Pathway.Rep.HashSet is now deprecated, "
               "Use Python's built in set object instead.",
               DeprecationWarning)
 
+
 class HashSet(object):
     """A set abstraction supporting the basic set operations.
 
@@ -20,19 +21,21 @@ class HashSet(object):
         self._elements = {}
         for e in elements:
             self._elements[e] = 1
-            
+
     def __contains__(self, element):
         """Returns true iff this set contains element."""
         return element in self._elements
-    
+
     def __eq__(self, set):
         """Returns true iff x == y for all elements in self, set."""
         if not isinstance(set, HashSet):
             return 0
         for x in self.list():
-            if not (x in set): return 0
+            if not (x in set):
+                return 0
         for x in set.list():
-            if not (x in self): return 0
+            if not (x in self):
+                return 0
         return 1
 
     def __len__(self):
@@ -40,7 +43,7 @@ class HashSet(object):
         return len(self._elements)
 
     def __ne__(self, set):
-        """Returns true iff this set is not equal to set.""" 
+        """Returns true iff this set is not equal to set."""
         return not self.__eq__(set)
 
     def __repr__(self):
@@ -49,7 +52,7 @@ class HashSet(object):
 
     def __str__(self):
         """Returns a string representation of this set."""
-        return "{" + ",".join(map(str, self.list())) + "}" 
+        return "{" + ",".join(map(str, self.list())) + "}"
 
     # Element access:
 
@@ -99,6 +102,3 @@ class HashSet(object):
             for j in s.list():
                 p.append((i,j))
         return HashSet(p)
-    
-
-
