@@ -327,6 +327,7 @@ class RaxmlCommandline(AbstractCommandline):
                         "Name of the working directory where RAxML will "
                         "write its output files. Default: current directory.",
                         filename=True,
+                        equate=False,
                         ),
 
                 _Option(['-x', 'rapid_bootstrap_seed'],
@@ -353,7 +354,7 @@ class RaxmlCommandline(AbstractCommandline):
                 _Option(['-N', '-#', 'num_replicates'],
                     "Number of alternative runs on distinct starting trees. "
                     "In combination with the '-b' option, this will invoke a "
-                    "multiple boostrap analysis. "
+                    "multiple bootstrap analysis. "
                     "DEFAULT: 1 single analysis."
                     "Note that '-N' has been added as an alternative since "
                     "'-#' sometimes caused problems with certain MPI job "
@@ -367,4 +368,3 @@ class RaxmlCommandline(AbstractCommandline):
         # ENH: enforce -s, -n and -m
         if not self.parsimony_seed:
             self.parsimony_seed = 10000
-
