@@ -6,7 +6,9 @@
 __docformat__ = "restructuredtext en"
 
 from _Phyml import PhymlCommandline
+from _Raxml import RaxmlCommandline
 
 #Make this explicit, then they show up in the API docs
 __all__ = ["PhymlCommandline",
+           "RaxmlCommandline",
            ]
