@@ -4,8 +4,6 @@
 # as part of this package.
 
 
-import os
-from Bio.PopGen import GenePop
 from Bio.PopGen.GenePop import FileParser
 import Bio.PopGen.FDist
 
@@ -13,6 +11,7 @@ import Bio.PopGen.FDist
 # add locus, etc...). The recommended strategy is convert back
 # and forth from/to GenePop and use GenePop Utils
 
+
 def convert_genepop_to_fdist(gp_rec, report_pops = None):
     """Converts a GenePop record to a FDist one.
 
@@ -27,6 +26,7 @@ def convert_genepop_to_fdist(gp_rec, report_pops = None):
     else:
         return _convert_genepop_to_fdist_big(gp_rec, report_pops)
 
+
 def _convert_genepop_to_fdist(gp_rec):
     """Converts a standard GenePop record to a FDist one.
 
@@ -37,7 +37,7 @@ def _convert_genepop_to_fdist(gp_rec):
        FDist record.
     """
     fd_rec = Bio.PopGen.FDist.Record()
-    
+
     fd_rec.data_org = 0
     fd_rec.num_loci = len(gp_rec.loci_list)
     fd_rec.num_pops = len(gp_rec.populations)
@@ -49,7 +49,7 @@ def _convert_genepop_to_fdist(gp_rec):
                 for al in indiv[1][lc_i]:
                     if al is not None and al not in alleles:
                         alleles.append(al)
-        alleles.sort() #Dominance requires this
+        alleles.sort()  # Dominance requires this
 
         #here we go again (necessary...)
         for pop_i in range(len(gp_rec.populations)):
@@ -59,7 +59,7 @@ def _convert_genepop_to_fdist(gp_rec):
                     if al is not None:
                         count = allele_counts.get(al, 0)
                         allele_counts[al] = count + 1
-            allele_array = [] #We need the same order as in alleles
+            allele_array = []  # We need the same order as in alleles
             for allele in alleles:
                 allele_array.append(allele_counts.get(allele, 0))
             pop_data.append(allele_array)
@@ -68,6 +68,7 @@ def _convert_genepop_to_fdist(gp_rec):
         fd_rec.loci_data.append((len(alleles), pop_data))
     return fd_rec
 
+
 def _convert_genepop_to_fdist_big(gp_rec, report_pops = None):
     """Converts a big GenePop record to a FDist one.
 
@@ -88,17 +89,19 @@ def _convert_genepop_to_fdist_big(gp_rec, report_pops = None):
     pops = []
     work_rec = FileParser.read(gp_rec.fname)
     lParser = work_rec.get_individual()
+
     def init_pop():
         my_pop = []
         for i in range(num_loci):
             my_pop.append({})
         return my_pop
+
     curr_pop = init_pop()
     num_pops = 1
     if report_pops:
         report_pops(num_pops)
     while lParser:
-        if lParser != True:
+        if lParser is not True:
             for loci_pos in range(num_loci):
                 for al in lParser[1][loci_pos]:
                     if al is not None:
@@ -111,7 +114,7 @@ def _convert_genepop_to_fdist_big(gp_rec, report_pops = None):
                 report_pops(num_pops)
             curr_pop = init_pop()
         lParser = work_rec.get_individual()
-    work_rec._handle.close() #TODO - Needs a proper fix
+    work_rec._handle.close()  # TODO - Needs a proper fix
     pops.append(curr_pop)
     fd_rec.num_pops = num_pops
     for loci_pos in range(num_loci):
@@ -145,7 +148,6 @@ def _convert_genepop_to_fdist_big_old(gp_rec, report_loci = None):
             popCnt += 1
         return popCnt
 
-    
     fd_rec.data_org = 0
     fd_rec.num_loci = len(gp_rec.loci_list)
     work_rec0 = FileParser.read(gp_rec.fname)
@@ -162,25 +164,27 @@ def _convert_genepop_to_fdist_big_old(gp_rec, report_loci = None):
         pop_data = []
         lParser = work_rec.get_individual()
         while lParser:
-            if lParser != True:
+            if lParser is not True:
                 for al in lParser[1][lc_i]:
                     if al is not None and al not in alleles:
                         alleles.append(al)
             lParser = work_rec.get_individual()
         #here we go again (necessary...)
         alleles.sort()
+
         def process_pop(pop_data, alleles, allele_counts):
-            allele_array = [] #We need the same order as in alleles
+            allele_array = []  # We need the same order as in alleles
             for allele in alleles:
                 allele_array.append(allele_counts.get(allele, 0))
             pop_data.append(allele_array)
+
         lParser = work_rec2.get_individual()
         allele_counts = {}
         for allele in alleles:
             allele_counts[allele] = 0
         allele_counts[None]=0
         while lParser:
-            if lParser == True:
+            if lParser is True:
                 process_pop(pop_data, alleles, allele_counts)
                 allele_counts = {}
                 for allele in alleles:
@@ -199,7 +203,6 @@ def approximate_fst(desired_fst, simulated_fst, parameter_fst,
            max_run_fst = 1, min_run_fst = 0, limit = 0.005):
     """Calculates the next Fst attempt in order to approximate a
        desired Fst.
-    
     """
     if abs(simulated_fst - desired_fst) < limit:
         return parameter_fst, max_run_fst, min_run_fst
@@ -210,4 +213,3 @@ def approximate_fst(desired_fst, simulated_fst, parameter_fst,
         min_run_fst = parameter_fst
         next_parameter_fst = (max_run_fst + parameter_fst)/2
     return next_parameter_fst, max_run_fst, min_run_fst
-
