@@ -8,15 +8,11 @@ This version will run Sincoal2 (if necessary) Asynchrously.
 
 """
 
-from logging import debug
-from sys import exit
 import os
-import tarfile
-import tempfile
 
-from Controller import SimCoalController
 import Cache
 
+
 class SimCoalCache(Cache.SimCoalCache):
     def __init__(self, data_dir, simcoal_dir):
         self.data_dir = data_dir
@@ -29,7 +25,7 @@ class SimCoalCache(Cache.SimCoalCache):
         f = inputFiles[parFile]
         text = f.read()
         f.close()
-        w = open (os.sep.join([self.data_dir, 'SimCoal', 'runs', parFile]), 'w')
+        w = open(os.sep.join([self.data_dir, 'SimCoal', 'runs', parFile]), 'w')
         w.write(text)
         w.close()
         self.run_simcoal(parFile, numSims, ploydi)
