@@ -9,7 +9,6 @@
 #
 
 import re
-import itertools
 from Bio.Restriction import RanaConfig as RanaConf
 
 """
@@ -20,7 +19,7 @@ Usage:
     List, column or map.
 
     the easiest way to use it is:
-    
+
     >>> from Bio.Restriction.PrintFormat import PrintFormat
     >>> from Bio.Restriction.Restriction import AllEnzymes
     >>> from Bio import Entrez
@@ -33,7 +32,7 @@ Usage:
     >>> new.print_that(dct, '\n my pBR322 analysis\n\n','\n no site :\n\n')
 
      my pBR322 analysis
-     
+
     AasI       :  2169, 2582.
     AatII      :  4289.
     ...
@@ -41,32 +40,33 @@ Usage:
     ...
     ZraI       :  4287.
     ZrmI       :  3847.
-    
+
      no site:
-     
-    AarI      AatI      Acc65I    AcsI      AcvI      AdeI      AflII     AgeI    
+
+    AarI      AatI      Acc65I    AcsI      AcvI      AdeI      AflII     AgeI
     ...
             More enzymes.
     ...
-    Vha464I   XapI      XbaI      XcmI      XhoI      XmaCI     XmaI      XmaJI     
-    Zsp2I 
+    Vha464I   XapI      XbaI      XcmI      XhoI      XmaCI     XmaI      XmaJI
+    Zsp2I
 
     >>> new.sequence = pBR322.seq
     >>> new.print_as("map")
     >>> new.print_that(dct)
     ...
-    
-    Some of the methods of PrintFormat are meant to be overriden by derived
+
+    Some of the methods of PrintFormat are meant to be overridden by derived
     class.
 """
 
+
 class PrintFormat(object):
     """PrintFormat allow the printing of results of restriction analysis."""
 
     ConsoleWidth = RanaConf.ConsoleWidth
     NameWidth    = RanaConf.NameWidth
     MaxSize      = RanaConf.MaxSize
-    Cmodulo      = ConsoleWidth%NameWidth       
+    Cmodulo      = ConsoleWidth%NameWidth
     PrefWidth    = ConsoleWidth - Cmodulo
     Indent       = RanaConf.Indent
     linesize     = PrefWidth - NameWidth
@@ -91,18 +91,17 @@ class PrintFormat(object):
             self.make_format = self._make_number
         else:
             self.make_format = self._make_list
-            
+
         return
-            
 
     def print_that(self, dct, title='',  s1=''):
         """PF.print_that(dct, [title[, s1]]) -> Print dct nicely formatted.
 
         dct is a dictionary as returned by a RestrictionBatch.search()
-        
+
         title is the title of the map.
-        It must be a formated string, i.e. you must include the line break.
-        
+        It must be a formatted string, i.e. you must include the line break.
+
         s1 is the title separating the list of enzymes that have sites from
         those without sites.
         s1 must be a formatted string as well.
@@ -118,7 +117,7 @@ class PrintFormat(object):
                 nc.append(k)
         print self.make_format(ls, title, nc, s1)
         return
-       
+
     def make_format(self, cut=[], title='', nc=[], s1=''):
         """PF.make_format(cut, nc, title, s) -> string
 
@@ -133,7 +132,7 @@ class PrintFormat(object):
         """PF._make_number(ls,title, nc,s1) -> string.
 
         return a string of form:
-        
+
         title.
 
         enzyme1     :   position1, position2.
@@ -149,7 +148,7 @@ class PrintFormat(object):
         """PF._make_number(ls,title, nc,s1) -> string.
 
         return a string of form:
-        
+
         title.
 
             enzyme1, position
@@ -168,13 +167,13 @@ class PrintFormat(object):
         """PF._make_number(ls,title, nc,s1) -> string.
 
         title.
-        
+
         enzyme which cut 1 time:
-        
+
         enzyme1     :   position1.
 
         enzyme which cut 2 times:
-        
+
         enzyme2     :   position1, position2.
         ...
 
@@ -183,7 +182,7 @@ class PrintFormat(object):
         nc is a list of non cutting enzymes.
         s1 is the sentence before the non cutting enzymes."""
         return self._make_number_only(ls, title)+self._make_nocut_only(nc,s1)
-    
+
     def _make_nocut(self, ls,title, nc,s1):
         """PF._make_nocut(ls,title, nc,s1) -> string.
 
@@ -191,17 +190,17 @@ class PrintFormat(object):
 
         ls is a list of cutting enzymes -> will not be used.
         Here for compatibility with make_format.
-        
+
         title is the title.
         nc is a list of non cutting enzymes.
         s1 is the sentence before the non cutting enzymes."""
-        return title + self._make_nocut_only(nc, s1) 
+        return title + self._make_nocut_only(nc, s1)
 
     def _make_nocut_only(self, nc, s1, ls =[],title=''):
         """PF._make_nocut_only(nc, s1) -> string.
 
         return a formatted string of the non cutting enzymes.
-        
+
         nc is a list of non cutting enzymes.
         s1 is the sentence before the non cutting enzymes.
         """
@@ -209,7 +208,7 @@ class PrintFormat(object):
             return s1
         nc.sort()
         st = ''
-        stringsite = s1 or '\n   Enzymes which do not cut the sequence.\n\n'    
+        stringsite = s1 or '\n   Enzymes which do not cut the sequence.\n\n'
         Join = ''.join
         for key in nc:
             st = Join((st, str.ljust(str(key), self.NameWidth)))
@@ -218,18 +217,18 @@ class PrintFormat(object):
                 st = ''
         stringsite = Join((stringsite, st, '\n'))
         return stringsite
-    
+
     def _make_list_only(self, ls, title, nc = [], s1 = ''):
         """PF._make_list_only(ls, title) -> string.
 
         return a string of form:
-        
+
         title.
 
         enzyme1     :   position1, position2.
         enzyme2     :   position1, position2, position3.
         ...
-        
+
         ls is a list of results.
         title is a string.
         Non cutting enzymes are not included."""
@@ -241,19 +240,18 @@ class PrintFormat(object):
         """PF._make_number_only(ls, title) -> string.
 
         return a string of form:
-        
+
         title.
-        
+
         enzyme which cut 1 time:
-        
+
         enzyme1     :   position1.
 
         enzyme which cut 2 times:
-        
+
         enzyme2     :   position1, position2.
         ...
-        
-                
+
         ls is a list of results.
         title is a string.
         Non cutting enzymes are not included."""
@@ -261,7 +259,7 @@ class PrintFormat(object):
             return title
         ls.sort(lambda x,y : cmp(len(x[1]), len(y[1])))
         iterator = iter(ls)
-        cur_len  = 1
+        cur_len = 1
         new_sect = []
         for name, sites in iterator:
             l = len(sites)
@@ -273,12 +271,12 @@ class PrintFormat(object):
             new_sect.append((name,sites))
         title += "\n\nenzymes which cut %i times :\n\n"%cur_len
         return self.__next_section(new_sect, title)
-            
+
     def _make_map_only(self, ls, title, nc = [],  s1 = ''):
         """PF._make_map_only(ls, title) -> string.
 
         return a string of form:
-        
+
         title.
 
             enzyme1, position
@@ -286,8 +284,7 @@ class PrintFormat(object):
         AAAAAAAAAAAAAAAAAAAAA...
         |||||||||||||||||||||
         TTTTTTTTTTTTTTTTTTTTT...
-        
-                
+
         ls is a list of results.
         title is a string.
         Non cutting enzymes are not included.
@@ -320,8 +317,8 @@ class PrintFormat(object):
                     break
             cutloc[x] = l
         cutloc[x] = mapping
-        sequence = self.sequence.tostring()
-        revsequence = self.sequence.complement().tostring()
+        sequence = str(self.sequence)
+        revsequence = str(self.sequence.complement())
         a = '|'
         base, counter = 0, 0
         emptyline = ' ' * 60
@@ -332,14 +329,16 @@ class PrintFormat(object):
             for key in cutloc[counter]:
                 s = ''
                 if key == base:
-                    for n in enzymemap[key] : s = ' '.join((s,n))
+                    for n in enzymemap[key]:
+                        s = ' '.join((s,n))
                     l = line[0:59]
                     lineo = Join((l, str(key), s, '\n'))
                     line2 = Join((l, a, '\n'))
                     linetot = Join((lineo, line2))
                     map = Join((map, linetot))
                     break
-                for n in enzymemap[key] : s = ' '.join((s,n))
+                for n in enzymemap[key]:
+                    s = ' '.join((s,n))
                 k = key%60
                 lineo = Join((line[0:(k-1)], str(key), s, '\n'))
                 line = Join((line[0:(k-1)], a, line[k:]))
@@ -351,7 +350,7 @@ class PrintFormat(object):
                                  Join((str.ljust(str(counter+1), 15), ' '* 30,
                                         str.rjust(str(base), 15),'\n\n'))
                                  ))
-            map = Join((map, mapunit)) 
+            map = Join((map, mapunit))
         line = ' '* 60
         for key in cutloc[base]:
             s = ''
@@ -364,7 +363,8 @@ class PrintFormat(object):
                 linetot = Join((lineo, line2))
                 map = Join((map, linetot))
                 break
-            for n in enzymemap[key] : s = Join((s,' ',n))
+            for n in enzymemap[key]:
+                s = Join((s,' ',n))
             k = key%60
             lineo = Join((line[0:(k-1)],str(key),s,'\n'))
             line = Join((line[0:(k-1)],a,line[k:]))
@@ -380,9 +380,9 @@ class PrintFormat(object):
                                        '\n\n'))))
         map = Join((map,mapunit))
         return map
-    
+
 ###### private method to do lists:
-    
+
     def __next_section(self, ls, into):
         """FP.__next_section(ls, into) -> string.
 
@@ -410,9 +410,9 @@ class PrintFormat(object):
                 #   cut where appropriate and add the indentation
                 #
                 l = [x.group() for x in re.finditer(pat, l)]
-                stringsite = indentation.join(l) 
+                stringsite = indentation.join(l)
             else:
-                stringsite = l    
+                stringsite = l
             into = Join((into,
                          str(name).ljust(self.NameWidth),' :  ',stringsite,'\n'))
         return into
