@@ -8,15 +8,15 @@
 """ASTRAL RAF (Rapid Access Format) Sequence Maps.
 
 The ASTRAL RAF Sequence Maps record the relationship between the PDB SEQRES
-records (representing the sequence of the molecule used in an experiment) to 
-the ATOM records (representing the atoms experimentally observed). 
+records (representing the sequence of the molecule used in an experiment) to
+the ATOM records (representing the atoms experimentally observed).
 
 This data is derived from the Protein Data Bank CIF files. Known errors in the
 CIF files are corrected manually, with the original PDB file serving as the
-final arbiter in case of discrepancies. 
+final arbiter in case of discrepancies.
 
 Residues are referenced by residue ID. This consists of a the PDB residue
-sequence number (upto 4 digits) and an optional PDB  insertion code (an
+sequence number (up to 4 digits) and an optional PDB insertion code (an
 ascii alphabetic character, a-z, A-Z). e.g. "1", "10A", "1010b", "-1"
 
 See "ASTRAL RAF Sequence Maps":http://astral.stanford.edu/raf.html
@@ -26,15 +26,16 @@ to_one_letter_code -- A mapping from the 3-letter amino acid codes found
                         include chemically modified residues.
 """
 
-from copy import copy 
+from copy import copy
 
 from Bio.SCOP.Residues import Residues
 
 from three_to_one_dict import to_one_letter_code
 
+
 def normalize_letters(one_letter_code):
     """Convert RAF one-letter amino acid codes into IUPAC standard codes.
-    
+
     Letters are uppercased, and "." ("Unknown") is converted to "X".
     """
     if one_letter_code == '.':
@@ -42,6 +43,7 @@ def normalize_letters(one_letter_code):
     else:
         return one_letter_code.upper()
 
+
 class SeqMapIndex(dict):
     """An RAF file index.
 
@@ -50,13 +52,13 @@ class SeqMapIndex(dict):
 
     The index key is a concatenation of the  PDB ID and chain ID. e.g
     "2drcA", "155c_". RAF uses an underscore to indicate blank
-    chain IDs.    
+    chain IDs.
     """
 
     def __init__(self, filename):
         """
         Arguments:
-        
+
           filename  -- The file to index
         """
         dict.__init__(self)
@@ -67,9 +69,10 @@ class SeqMapIndex(dict):
             position = 0
             while True:
                 line = f.readline()
-                if not line: break
+                if not line:
+                    break
                 key = line[0:5]
-                if key != None:
+                if key is not None:
                     self[key]=position
                 position = f.tell()
         finally:
@@ -88,7 +91,6 @@ class SeqMapIndex(dict):
             f.close()
         return record
 
-
     def getSeqMap(self, residues):
         """Get the sequence map for a collection of residues.
 
@@ -98,9 +100,10 @@ class SeqMapIndex(dict):
         if isinstance(residues, basestring):
             residues = Residues(residues)
 
-        pdbid  = residues.pdbid
+        pdbid = residues.pdbid
         frags = residues.fragments
-        if not frags: frags =(('_','',''),) # All residues of unnamed chain
+        if not frags:
+            frags =(('_','',''),) # All residues of unnamed chain
 
         seqMap = None
         for frag in frags:
@@ -108,29 +111,30 @@ class SeqMapIndex(dict):
             if chainid=='' or chainid=='-' or chainid==' ' or chainid=='_':
                 chainid = '_'
             id = pdbid + chainid
-            
-            
+
             sm = self[id]
-            
+
             #Cut out fragment of interest
             start = 0
             end = len(sm.res)
-            if frag[1] : start = int(sm.index(frag[1], chainid))
-            if frag[2] : end = int(sm.index(frag[2], chainid)+1)
-            
+            if frag[1]:
+                start = int(sm.index(frag[1], chainid))
+            if frag[2]:
+                end = int(sm.index(frag[2], chainid)+1)
+
             sm = sm[start:end]
 
-            if seqMap == None:
+            if seqMap is None:
                 seqMap = sm
             else:
                 seqMap += sm
-                            
+
         return seqMap
 
 
 class SeqMap(object):
     """An ASTRAL RAF (Rapid Access Format) Sequence Map.
-    
+
     This is a list like object; You can find the location of particular residues
     with index(), slice this SeqMap into fragments, and glue fragments back
     together with extend().
@@ -154,25 +158,24 @@ class SeqMap(object):
         self.res = []
         if line:
             self._process(line)
-        
 
     def _process(self, line):
         """Parses a RAF record into a SeqMap object.
         """
         header_len = 38
- 
-        line = line.rstrip()  # no trailing whitespace        
 
-        if len(line)<header_len: 
+        line = line.rstrip()  # no trailing whitespace
+
+        if len(line)<header_len:
             raise ValueError("Incomplete header: "+line)
 
         self.pdbid = line[0:4]
         chainid = line[4:5]
-        
+
         self.version = line[6:10]
 
         #Raf format versions 0.01 and 0.02 are identical for practical purposes
-        if(self.version != "0.01" and  self.version !="0.02"):
+        if(self.version != "0.01" and self.version !="0.02"):
             raise ValueError("Incompatible RAF version: "+self.version)
 
         self.pdb_datestamp = line[14:20]
@@ -184,13 +187,12 @@ class SeqMap(object):
                 raise ValueError("Corrupt Field: ("+f+")")
             r = Res()
             r.chainid = chainid
-            r.resid =  f[0:5].strip()
+            r.resid = f[0:5].strip()
             r.atom = normalize_letters(f[5:6])
             r.seqres = normalize_letters(f[6:7])
 
             self.res.append(r)
 
-
     def index(self, resid, chainid="_"):
         for i in range(0, len(self.res)):
             if self.res[i].resid == resid and self.res[i].chainid == chainid:
@@ -248,15 +250,15 @@ class SeqMap(object):
         residue subset.
 
         pdb_handle -- A handle to the relevant PDB file.
-        
+
         out_handle -- All output is written to this file like object.
         """
-        #This code should be refactored when (if?) biopython gets a PDB parser 
+        #This code should be refactored when (if?) biopython gets a PDB parser
 
-        #The set of residues that I have to find records for. 
+        #The set of residues that I have to find records for.
         resSet = {}
         for r in self.res:
-            if r.atom=='X' : #Unknown residue type
+            if r.atom=='X':  # Unknown residue type
                 continue
             chainid = r.chainid
             if chainid == '_':
@@ -283,8 +285,8 @@ class SeqMap(object):
             #for k in resFound.keys():
             #    del resSet[k]
             #print resSet
-                                     
-            raise RuntimeError('I could not find at least one ATOM or HETATM' \
+
+            raise RuntimeError('I could not find at least one ATOM or HETATM'
                    +' record for each and every residue in this sequence map.')
 
 
@@ -293,9 +295,9 @@ class Res(object):
 
     chainid -- A single character chain ID.
 
-    resid   -- The residue ID. 
+    resid   -- The residue ID.
 
-    atom    -- amino acid one-letter code from ATOM records. 
+    atom    -- amino acid one-letter code from ATOM records.
 
     seqres  -- amino acid one-letter code from SEQRES records.
     """
@@ -311,8 +313,8 @@ def parse(handle):
     in the file.
 
     Arguments:
-        
+
         handle -- file-like object.
-    """ 
+    """
     for line in handle:
         yield SeqMap(line)
