@@ -1,3 +1,9 @@
+import warnings
+from Bio import BiopythonDeprecationWarning
+warnings.warn("Long obsolete module Bio/Search.py is deprecated.",
+              BiopythonDeprecationWarning)
+
+
 # BLASTN 2.0a19MP-WashU [05-Feb-1998] [Build decunix3.2 01:53:29 05-Feb-1998]
 # BLASTP 2.0.4 [Feb-24-1998]
 class Algorithm(object):
@@ -6,6 +12,7 @@ class Algorithm(object):
         self.version = version           # '2.1.2' or '2.0a19MP-WashU'
         self.description = description   # '[05-Feb-1998] [Build dec ...1998]'
 
+
 # Query=  YAL001C YAL001C, Chr I from 147596 to 147665, and 147756 to 151168,
 #     reverse complement
 #         (3483 letters)
@@ -16,6 +23,7 @@ class Query(object):
         self.description = description  # 'YAL001C, Chr I from 147596 to ... '
         self.length = length            # 3483
 
+
 # Database:  ArabidopsisN
 #            66,211 sequences; 69,074,155 total letters.
 class Database(object):
@@ -24,6 +32,7 @@ class Database(object):
         self.letters = letters      # 69074155
         self.entries = entries      # 66211
 
+
 class TableInfo(object):
     def __init__(self, full_description, info):
         self.__dict__.update(info)
@@ -41,6 +50,7 @@ class Search(object):
         self.parameters = parameters
         self.statistics = statistics
 
+
 class Hit(object):
     def __init__(self, name, description, accession, length,
                  algorithm, hsps = None):
@@ -57,13 +67,12 @@ class Hit(object):
         return self.length
 
 
-
-# >GB_PL:ATF18F4 AL021637 Arabidopsis thaliana DNA chromosome 4, BAC clone 
+# >GB_PL:ATF18F4 AL021637 Arabidopsis thaliana DNA chromosome 4, BAC clone
 #           F18F4 (ESSAII project). 2/98
 #             Length = 93,646
-#  
+#
 #   Minus Strand HSPs:
-#  
+#
 #  Score = 226 (33.9 bits), Expect = 0.80, P = 0.55
 #  Identities = 98/142 (69%), Positives = 98/142 (69%), Strand = Minus / Plus
 #    [...lines deleted...]
@@ -78,8 +87,10 @@ class _SeqLength:
         self.identical = identical
         self.positives = positives
         self.gaps = gaps
+
     def __len__(self):
         return self.length
+
     def __getattr__(self, name):
         if name == "frac_identical":
             return float(self.identical) / self.length
@@ -93,13 +104,14 @@ class HomologySeq(_SeqLength):
         _SeqLength.__init__(self, len(seq), identical, positives, gaps)
         self.seq = seq
 
+
 class HSPSeq(_SeqLength):
     def __init__(self, name, seq, location, identical, positives, gaps):
         _SeqLength.__init__(self, len(seq), identical, positives, gaps)
         self.name = name
         self.seq = seq
         self.location = location
-        
+
 
 class HSP(_SeqLength):
     def __init__(self,
@@ -130,7 +142,7 @@ class HSP(_SeqLength):
         identical = info["identical"]
         # bioperl calls this 'conserved'
         positives = info.get("positives", identical)
-        
+
         _SeqLength.__init__(self, len(query_seq), identical,
                             positives, homology_gaps)
 
