@@ -1,6 +1,6 @@
 # Copyright 2000-2003 Jeff Chang.
 # Copyright 2001-2008 Brad Chapman.
-# Copyright 2005-2011 by Peter Cock.
+# Copyright 2005-2012 by Peter Cock.
 # Copyright 2006-2009 Michiel de Hoon.
 # All rights reserved.
 # This code is part of the Biopython distribution and governed by its
@@ -45,10 +45,12 @@ o BetweenPosition - Specify a position occuring between a range (OBSOLETE?).
 o BeforePosition - Specify the position as being found before some base.
 o AfterPosition - Specify the position as being found after some base.
 o OneOfPosition - Specify a position where the location can be multiple positions.
+o UnknownPosition - Represents missing information like '?' in UniProt.
 """
 
 from Bio.Seq import MutableSeq, reverse_complement
 
+
 class SeqFeature(object):
     """Represent a Sequence Feature on an object.
 
@@ -59,7 +61,7 @@ class SeqFeature(object):
     be related to others. For example, in the example GenBank feature
     shown below, the location_operator would be "join"
     o strand - A value specifying on which strand (of a DNA sequence, for
-    instance) the feature deals with. 1 indicates the plus strand, -1 
+    instance) the feature deals with. 1 indicates the plus strand, -1
     indicates the minus strand, 0 indicates stranded but unknown (? in GFF3),
     while the default of None indicates that strand doesn't apply (dot in GFF3,
     e.g. features on proteins). Note this is a shortcut for accessing the
@@ -71,7 +73,7 @@ class SeqFeature(object):
     o ref_db - A different database for the reference accession number.
     Note this is a shortcut for the reference property of the location
     o qualifiers - A dictionary of qualifiers on the feature. These are
-    analagous to the qualifiers from a GenBank feature table. The keys of
+    analogous to the qualifiers from a GenBank feature table. The keys of
     the dictionary are qualifier names, the values are the qualifier
     values.
     o sub_features - Additional SeqFeatures which fall under this 'parent'
@@ -91,7 +93,7 @@ class SeqFeature(object):
     method to do this for you.
     """
     def __init__(self, location = None, type = '', location_operator = '',
-                 strand = None, id = "<unknown id>", 
+                 strand = None, id = "<unknown id>",
                  qualifiers = None, sub_features = None,
                  ref = None, ref_db = None):
         """Initialize a SeqFeature on a Sequence.
@@ -152,6 +154,7 @@ class SeqFeature(object):
 
     def _get_strand(self):
         return self.location.strand
+
     def _set_strand(self, value):
         try:
             self.location.strand = value
@@ -161,6 +164,7 @@ class SeqFeature(object):
                     raise ValueError("Can't set strand without a location.")
             else:
                 raise
+
     strand = property(fget = _get_strand, fset = _set_strand,
                       doc = """Feature's strand
 
@@ -169,6 +173,7 @@ class SeqFeature(object):
 
     def _get_ref(self):
         return self.location.ref
+
     def _set_ref(self, value):
         try:
             self.location.ref = value
@@ -186,6 +191,7 @@ class SeqFeature(object):
 
     def _get_ref_db(self):
         return self.location.ref_db
+
     def _set_ref_db(self, value):
         self.location.ref_db = value
     ref_db = property(fget = _get_ref_db, fset = _set_ref_db,
@@ -240,7 +246,7 @@ class SeqFeature(object):
 
     def _flip(self, length):
         """Returns a copy of the feature with its location flipped (PRIVATE).
-        
+
         The argument length gives the length of the parent sequence. For
         example a location 0..20 (+1 strand) with parent length 30 becomes
         after flipping 10..30 (-1 strand). Strandless (None) or unknown
@@ -282,26 +288,27 @@ class SeqFeature(object):
             #(the MutableSeq reverse complement acts in situ)
             parent_sequence = parent_sequence.toseq()
         if self.sub_features:
-            if self.location_operator!="join":
+            if self.location_operator != "join":
                 raise ValueError(self.location_operator)
             if self.location.strand == -1:
                 #This is a special case given how the GenBank parser works.
                 #Must avoid doing the reverse complement twice.
                 parts = []
                 for f_sub in self.sub_features[::-1]:
-                    assert f_sub.location.strand==-1
+                    assert f_sub.location.strand == -1
                     parts.append(f_sub.location.extract(parent_sequence))
             else:
                 #This copes with mixed strand features:
-                parts = [f_sub.location.extract(parent_sequence) \
+                parts = [f_sub.location.extract(parent_sequence)
                          for f_sub in self.sub_features]
             #We use addition rather than a join to avoid alphabet issues:
             f_seq = parts[0]
-            for part in parts[1:] : f_seq += part
+            for part in parts[1:]:
+                f_seq += part
             return f_seq
         else:
             return self.location.extract(parent_sequence)
-    
+
     def __nonzero__(self):
         """Returns True regardless of the length of the feature.
 
@@ -433,6 +440,7 @@ class SeqFeature(object):
 
 # --- References
 
+
 # TODO -- Will this hold PubMed and Medline information decently?
 class Reference(object):
     """Represent a Generic Reference object.
@@ -480,23 +488,70 @@ class Reference(object):
         return "%s(title=%s, ...)" % (self.__class__.__name__,
                                       repr(self.title))
 
+
 # --- Handling feature locations
 
 class FeatureLocation(object):
     """Specify the location of a feature along a sequence.
 
-    This attempts to deal with fuzziness of position ends, but also
-    make it easy to get the start and end in the 'normal' case (no
-    fuzziness).
-
-    You should access the start and end attributes with
-    your_location.start and your_location.end. If the start and
-    end are exact, this will return the positions, if not, we'll return
-    the approriate Fuzzy class with info about the position and fuzziness.
+    The FeatureLocation is used for simple continous features, which can
+    be described as running from a start position to and end position
+    (optionally with a strand and reference information).  More complex
+    locations made up from several non-continuous parts (e.g. a coding
+    sequence made up of several exons) are currently described using a
+    SeqFeature with sub-features.
 
     Note that the start and end location numbering follow Python's scheme,
     thus a GenBank entry of 123..150 (one based counting) becomes a location
     of [122:150] (zero based counting).
+
+    >>> from Bio.SeqFeature import FeatureLocation
+    >>> f = FeatureLocation(122, 150)
+    >>> print f
+    [122:150]
+    >>> print f.start
+    122
+    >>> print f.end
+    150
+    >>> print f.strand
+    None
+
+    Note the strand defaults to None. If you are working with nucleotide
+    sequences you'd want to be explicit if it is the forward strand:
+
+    >>> from Bio.SeqFeature import FeatureLocation
+    >>> f = FeatureLocation(122, 150, strand=+1)
+    >>> print f
+    [122:150](+)
+    >>> print f.strand
+    1
+
+    Note that for a parent sequence of length n, the FeatureLocation
+    start and end must satisfy the inequality 0 <= start <= end <= n.
+    This means even for features on the reverse strand of a nucleotide
+    sequence, we expect the 'start' coordinate to be less than the
+    'end' coordinate.
+
+    >>> from Bio.SeqFeature import FeatureLocation
+    >>> r = FeatureLocation(122, 150, strand=-1)
+    >>> print r
+    [122:150](-)
+    >>> print r.start
+    122
+    >>> print r.end
+    150
+    >>> print r.strand
+    -1
+
+    i.e. Rather than thinking of the 'start' and 'end' biologically in a
+    strand aware manor, think of them as the 'left most' or 'minimum'
+    boundary, and the 'right most' or 'maximum' boundary of the region
+    being described.
+
+    In the example above we have used standard exact positions, but there
+    are also specialised position objects used to represent fuzzy positions
+    as well, for example a GenBank location like complement(<123..150)
+    would use a BeforePosition object for the start.
     """
     def __init__(self, start, end, strand=None, ref=None, ref_db=None):
         """Specify the start, end, strand etc of a sequence feature.
@@ -509,12 +564,12 @@ class FeatureLocation(object):
         to make it easy to deal with non-fuzzy ends.
 
         i.e. Short form:
-        
+
         >>> from Bio.SeqFeature import FeatureLocation
         >>> loc = FeatureLocation(5, 10, strand=-1)
         >>> print loc
         [5:10](-)
-        
+
         Explicit form:
 
         >>> from Bio.SeqFeature import FeatureLocation, ExactPosition
@@ -553,29 +608,32 @@ class FeatureLocation(object):
         AL391218.9
 
         """
+        #TODO - Check 0 <= start <= end (<= length of reference)
         if isinstance(start, AbstractPosition):
             self._start = start
-        elif isinstance(start, int):
+        elif isinstance(start, int) or isinstance(start, long):
             self._start = ExactPosition(start)
         else:
-            raise TypeError(start)
+            raise TypeError("start=%r %s" % (start, type(start)))
         if isinstance(end, AbstractPosition):
             self._end = end
-        elif isinstance(end, int):
+        elif isinstance(end, int) or isinstance(end, long):
             self._end = ExactPosition(end)
         else:
-            raise TypeError(end)
+            raise TypeError("end=%r %s" % (end, type(end)))
         self.strand = strand
         self.ref = ref
         self.ref_db = ref_db
 
     def _get_strand(self):
         return self._strand
+
     def _set_strand(self, value):
         if value not in [+1, -1, 0, None]:
-            raise ValueError("Strand should be +1, -1, 0 or None, not %r" \
+            raise ValueError("Strand should be +1, -1, 0 or None, not %r"
                              % value)
         self._strand = value
+
     strand = property(fget = _get_strand, fset = _set_strand,
                       doc = "Strand of the location (+1, -1, 0 or None).")
 
@@ -630,7 +688,7 @@ class FeatureLocation(object):
 
     def __len__(self):
         """Returns the length of the region described by the FeatureLocation.
-        
+
         Note that extra care may be needed for fuzzy locations, e.g.
 
         >>> from Bio.SeqFeature import FeatureLocation
@@ -746,11 +804,10 @@ class FeatureLocation(object):
 
         This is now a alias for int(feature.end), which should be
         used in preference -- unless you are trying to support old
-        versions of Biopython.  
+        versions of Biopython.
         """
         return int(self._end)
 
-
     def extract(self, parent_sequence):
         """Extract feature sequence from the supplied parent sequence."""
         if self.ref or self.ref_db:
@@ -759,7 +816,7 @@ class FeatureLocation(object):
         if isinstance(parent_sequence, MutableSeq):
             #This avoids complications with reverse complements
             #(the MutableSeq reverse complement acts in situ)
-           parent_sequence = parent_sequence.toseq()
+            parent_sequence = parent_sequence.toseq()
         f_seq = parent_sequence[self.nofuzzy_start:self.nofuzzy_end]
         if self.strand == -1:
             try:
@@ -769,6 +826,7 @@ class FeatureLocation(object):
                 f_seq = reverse_complement(f_seq)
         return f_seq
 
+
 class AbstractPosition(object):
     """Abstract base class representing a position.
     """
@@ -777,6 +835,7 @@ class AbstractPosition(object):
         """String representation of the location for debugging."""
         return "%s(...)" % (self.__class__.__name__)
 
+
 class ExactPosition(int, AbstractPosition):
     """Specify the specific position of a boundary.
 
@@ -838,14 +897,16 @@ class ExactPosition(int, AbstractPosition):
         #By default perserve any subclass
         return self.__class__(length - int(self))
 
+
 class UncertainPosition(ExactPosition):
     """Specify a specific position which is uncertain.
-    
+
     This is used in UniProt, e.g. ?222 for uncertain position 222, or in the
     XML format explicitly marked as uncertain. Does not apply to GenBank/EMBL.
     """
     pass
 
+
 class UnknownPosition(AbstractPosition):
     """Specify a specific position which is unknown (has no position).
 
@@ -874,7 +935,8 @@ class UnknownPosition(AbstractPosition):
 
     def _flip(self, length):
         return self
-        
+
+
 class WithinPosition(int, AbstractPosition):
     """Specify the position of a boundary within some coordinates.
 
@@ -885,7 +947,7 @@ class WithinPosition(int, AbstractPosition):
 
     This allows dealing with a position like ((1.4)..100). This
     indicates that the start of the sequence is somewhere between 1
-    and 4. Since this is a start coordindate, it should acts like
+    and 4. Since this is a start coordinate, it should acts like
     it is at position 1 (or in Python counting, 0).
 
     >>> p = WithinPosition(10,10,13)
@@ -957,10 +1019,12 @@ class WithinPosition(int, AbstractPosition):
     True
     >>> p2 == 13
     True
-    
+
     """
     def __new__(cls, position, left, right):
-        assert position==left or position==right
+        assert position==left or position==right, \
+            "WithinPosition: %r should match left %r or right %r" \
+            (position, left, right)
         obj = int.__new__(cls, position)
         obj._left = left
         obj._right = right
@@ -995,6 +1059,7 @@ class WithinPosition(int, AbstractPosition):
                               length - self._right,
                               length - self._left)
 
+
 class BetweenPosition(int, AbstractPosition):
     """Specify the position of a boundary between two coordinates (OBSOLETE?).
 
@@ -1003,7 +1068,7 @@ class BetweenPosition(int, AbstractPosition):
     o left - The start (left) position of the boundary
     o right - The end (right) position of the boundary
 
-    This allows dealing with a position like 123^456. This                                                  
+    This allows dealing with a position like 123^456. This
     indicates that the start of the sequence is somewhere between
     123 and 456. It is up to the parser to set the position argument
     to either boundary point (depending on if this is being used as
@@ -1096,6 +1161,7 @@ class BetweenPosition(int, AbstractPosition):
                               length - self._right,
                               length - self._left)
 
+
 class BeforePosition(int, AbstractPosition):
     """Specify a position where the actual location occurs before it.
 
@@ -1158,6 +1224,7 @@ class BeforePosition(int, AbstractPosition):
     def _flip(self, length):
         return AfterPosition(length - int(self))
 
+
 class AfterPosition(int, AbstractPosition):
     """Specify a position where the actual location is found after it.
 
@@ -1286,7 +1353,8 @@ class OneOfPosition(int, AbstractPosition):
 
         position is an integer specifying the default behaviour.
         """
-        assert position in choices
+        assert position in choices, \
+            "OneOfPosition: %r should match one of %r" % (position, choices)
         obj = int.__new__(cls, position)
         obj.position_choices = choices
         return obj
@@ -1304,7 +1372,7 @@ class OneOfPosition(int, AbstractPosition):
 
     def __repr__(self):
         """String representation of the OneOfPosition location for debugging."""
-        return "%s(%i, choices=%r)" % (self.__class__.__name__, \
+        return "%s(%i, choices=%r)" % (self.__class__.__name__,
                                        int(self), self.position_choices)
 
     def __str__(self):
@@ -1335,36 +1403,12 @@ class PositionGap(object):
     def __repr__(self):
         """A string representation of the position gap for debugging."""
         return "%s(%s)" % (self.__class__.__name__, repr(self.gap_size))
-    
+
     def __str__(self):
         out = "gap(%s)" % self.gap_size
         return out
 
-def _test():
-    """Run the Bio.SeqFeature module's doctests (PRIVATE).
-
-    This will try and locate the unit tests directory, and run the doctests
-    from there in order that the relative paths used in the examples work.
-    """
-    import doctest
-    import os
-    if os.path.isdir(os.path.join("..","Tests")):
-        print "Runing doctests..."
-        cur_dir = os.path.abspath(os.curdir)
-        os.chdir(os.path.join("..","Tests"))
-        doctest.testmod()
-        os.chdir(cur_dir)
-        del cur_dir
-        print "Done"
-    elif os.path.isdir(os.path.join("Tests")) :
-        print "Runing doctests..."
-        cur_dir = os.path.abspath(os.curdir)
-        os.chdir(os.path.join("Tests"))
-        doctest.testmod()
-        os.chdir(cur_dir)
-        del cur_dir
-        print "Done"
-
 
 if __name__ == "__main__":
-    _test()
+    from Bio._utils import run_doctest
+    run_doctest()
