@@ -1,4 +1,4 @@
-# Copyright 2008-2009 by Peter Cock.  All rights reserved.
+# Copyright 2008-2010 by Peter Cock.  All rights reserved.
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
@@ -15,8 +15,8 @@ from Bio.Alphabet import single_letter_alphabet
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
 
-#This is a generator function!
-def IgIterator(handle, alphabet = single_letter_alphabet):
+
+def IgIterator(handle, alphabet=single_letter_alphabet):
     """Iterate over IntelliGenetics records (as SeqRecord objects).
 
     handle - input file
@@ -33,14 +33,16 @@ def IgIterator(handle, alphabet = single_letter_alphabet):
     #Skip any file header text before the first record (;; lines)
     while True:
         line = handle.readline()
-        if not line : break #Premature end of file, or just empty?
-        if not line.startswith(";;") : break
+        if not line:
+            break  # Premature end of file, or just empty?
+        if not line.startswith(";;"):
+            break
 
     while line:
         #Now iterate over the records
-        if line[0]!=";":
-            raise ValueError( \
-                  "Records should start with ';' and not:\n%s" % repr(line))
+        if line[0] != ";":
+            raise ValueError(
+                "Records should start with ';' and not:\n%s" % repr(line))
 
         #Try and agree with SeqRecord convention from the GenBank parser,
         #(and followed in the SwissProt parser) which stores the comments
@@ -57,29 +59,32 @@ def IgIterator(handle, alphabet = single_letter_alphabet):
         seq_lines = []
         while True:
             line = handle.readline()
-            if not line : break
-            if line[0] == ";": break
+            if not line:
+                break
+            if line[0] == ";":
+                break
             #Remove trailing whitespace, and any internal spaces
-            seq_lines.append(line.rstrip().replace(" ",""))
+            seq_lines.append(line.rstrip().replace(" ", ""))
         seq_str = "".join(seq_lines)
         if seq_str.endswith("1"):
             #Remove the optional terminator (digit one)
             seq_str = seq_str[:-1]
         if "1" in seq_str:
-            raise ValueError("Potential terminator digit one found within sequence.")
-                
+            raise ValueError(
+                "Potential terminator digit one found within sequence.")
+
         #Return the record and then continue...
-        record= SeqRecord(Seq(seq_str, alphabet),
-                          id = title, name = title)
+        record = SeqRecord(Seq(seq_str, alphabet),
+                           id=title, name=title)
         record.annotations['comment'] = "\n".join(comment_lines)
         yield record
-    
+
     #We should be at the end of the file now
     assert not line
 
 if __name__ == "__main__":
     print "Running quick self test"
-    
+
     import os
     path = "../../Tests/IntelliGenetics/"
     if os.path.isdir(path):
@@ -87,7 +92,7 @@ if __name__ == "__main__":
             if os.path.splitext(filename)[-1] == ".txt":
                 print
                 print filename
-                print "-"*len(filename)
+                print "-" * len(filename)
                 handle = open(os.path.join(path, filename))
                 for record in IgIterator(handle):
                     print record.id, len(record)
