@@ -2,14 +2,14 @@
 # Copyright 2008 by Michiel de Hoon.  All rights reserved.
 # Revisions copyright 2009 by Cymon J. Cox.  All rights reserved.
 # Revisions copyright 2009 by Peter Cock.  All rights reserved.
-# 
+#
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 """
 Parser for PHD files output by PHRED and used by PHRAP and CONSED.
 
-This module can be used used directly which will return Record objects
+This module can be used directly which will return Record objects
 which should contain all the original data in the file.
 
 Alternatively, using Bio.SeqIO with the "phd" format will call this module
@@ -19,11 +19,12 @@ internally.  This will give SeqRecord objects for each contig sequence.
 from Bio import Seq
 from Bio.Alphabet import generic_dna
 
-CKEYWORDS=['CHROMAT_FILE','ABI_THUMBPRINT','PHRED_VERSION','CALL_METHOD',\
-        'QUALITY_LEVELS','TIME','TRACE_ARRAY_MIN_INDEX','TRACE_ARRAY_MAX_INDEX',\
-        'TRIM','TRACE_PEAK_AREA_RATIO','CHEM','DYE']
+CKEYWORDS = ['CHROMAT_FILE', 'ABI_THUMBPRINT', 'PHRED_VERSION', 'CALL_METHOD',
+        'QUALITY_LEVELS', 'TIME', 'TRACE_ARRAY_MIN_INDEX', 'TRACE_ARRAY_MAX_INDEX',
+        'TRIM', 'TRACE_PEAK_AREA_RATIO', 'CHEM', 'DYE']
 
-class Record:
+
+class Record(object):
     """Hold information from a PHD file."""
     def __init__(self):
         self.file_name = ''
@@ -44,22 +45,22 @@ def read(handle):
     for line in handle:
         if line.startswith("BEGIN_SEQUENCE"):
             record = Record()
-            record.file_name = line[15:].rstrip() 
+            record.file_name = line[15:].rstrip()
             break
     else:
-        return # No record found
+        return  # No record found
 
     for line in handle:
         if line.startswith("BEGIN_COMMENT"):
             break
     else:
         raise ValueError("Failed to find BEGIN_COMMENT line")
-       
+
     for line in handle:
         line = line.strip()
         if not line:
             continue
-        if line=="END_COMMENT":
+        if line == "END_COMMENT":
             break
         keyword, value = line.split(":", 1)
         keyword = keyword.lower()
@@ -78,9 +79,9 @@ def read(handle):
                          'trace_array_min_index',
                          'trace_array_max_index'):
             record.comments[keyword] = int(value)
-        elif keyword=='trace_peak_area_ratio':
+        elif keyword == 'trace_peak_area_ratio':
             record.comments[keyword] = float(value)
-        elif keyword=='trim':
+        elif keyword == 'trim':
             first, last, prob = value.split()
             record.comments[keyword] = (int(first), int(last), float(prob))
     else:
@@ -100,7 +101,7 @@ def read(handle):
             # Peak location is optional according to
             # David Gordon (the Consed author)
             parts = line.split()
-            if len(parts) in [2,3]:
+            if len(parts) in [2, 3]:
                 record.sites.append(tuple(parts))
             else:
                 raise ValueError("DNA line must contain a base and quality "
@@ -119,6 +120,7 @@ def read(handle):
 
     return record
 
+
 def parse(handle):
     """Iterates over a file returning multiple PHD records.
 
