@@ -7,11 +7,11 @@
 # some of the models in the Wise2 package by Ewan Birney available from:
 # ftp://ftp.ebi.ac.uk/pub/software/unix/wise2/
 # http://www.ebi.ac.uk/Wise2/
-# 
+#
 # Bio.Wise.psw is for protein Smith-Waterman alignments
 # Bio.Wise.dnal is for Smith-Waterman DNA alignments
 
-__version__ = "$Revision: 1.16 $"
+__version__ = "$Revision: 1.17 $"
 
 import os
 import sys
@@ -21,12 +21,23 @@ from Bio import SeqIO
 
 
 def _build_align_cmdline(cmdline, pair, output_filename, kbyte=None, force_type=None, quiet=False):
-    """
+    """Helper function to build a command line string (PRIVATE).
+
     >>> os.environ["WISE_KBYTE"]="300000"
-    >>> _build_align_cmdline(["dnal"], ("seq1.fna", "seq2.fna"), "/tmp/output", kbyte=100000)
-    'dnal -kbyte 100000 seq1.fna seq2.fna > /tmp/output'
-    >>> _build_align_cmdline(["psw"], ("seq1.faa", "seq2.faa"), "/tmp/output_aa")
-    'psw -kbyte 300000 seq1.faa seq2.faa > /tmp/output_aa'
+    >>> if os.isatty(sys.stderr.fileno()):
+    ...    c = _build_align_cmdline(["dnal"], ("seq1.fna", "seq2.fna"),
+    ...                             "/tmp/output", kbyte=100000)
+    ...    assert c == 'dnal -kbyte 100000 seq1.fna seq2.fna > /tmp/output', c
+    ...    c = _build_align_cmdline(["psw"], ("seq1.faa", "seq2.faa"),
+    ...                             "/tmp/output_aa")
+    ...    assert c == 'psw -kbyte 300000 seq1.faa seq2.faa > /tmp/output_aa', c
+    ... else:
+    ...    c = _build_align_cmdline(["dnal"], ("seq1.fna", "seq2.fna"),
+    ...                             "/tmp/output", kbyte=100000)
+    ...    assert c == 'dnal -kbyte 100000 -quiet seq1.fna seq2.fna > /tmp/output', c
+    ...    c = _build_align_cmdline(["psw"], ("seq1.faa", "seq2.faa"),
+    ...                             "/tmp/output_aa")
+    ...    assert c == 'psw -kbyte 300000 -quiet seq1.faa seq2.faa > /tmp/output_aa', c
 
     """
     cmdline = cmdline[:]
@@ -52,12 +63,13 @@ def _build_align_cmdline(cmdline, pair, output_filename, kbyte=None, force_type=
 
     return cmdline_str
 
+
 def align(cmdline, pair, kbyte=None, force_type=None, dry_run=False, quiet=False, debug=False):
     """
     Returns a filehandle
     """
     assert len(pair) == 2
-    
+
     output_file = tempfile.NamedTemporaryFile(mode='r')
     input_files = tempfile.NamedTemporaryFile(mode="w"), tempfile.NamedTemporaryFile(mode="w")
 
@@ -97,10 +109,11 @@ def align(cmdline, pair, kbyte=None, force_type=None, dry_run=False, quiet=False
             print >>sys.stderr, "INFO trying again with the linear model"
             return align(cmdline, pair, 0, force_type, dry_run, quiet, debug)
         else:
-            raise OSError, "%s returned %s" % (" ".join(cmdline), status)
-    
+            raise OSError("%s returned %s" % (" ".join(cmdline), status))
+
     return output_file
 
+
 def all_pairs(singles):
     """
     Generate pairs list for all-against-all alignments
@@ -117,11 +130,13 @@ def all_pairs(singles):
 
     return pairs
 
+
 def main():
     pass
 
+
 def _test(*args, **keywds):
-    import doctest, sys
+    import doctest
     doctest.testmod(sys.modules[__name__], *args, **keywds)
 
 if __name__ == "__main__":
