@@ -7,17 +7,14 @@
 # some of the models in the Wise2 package by Ewan Birney available from:
 # ftp://ftp.ebi.ac.uk/pub/software/unix/wise2/
 # http://www.ebi.ac.uk/Wise2/
-# 
+#
 # Bio.Wise.psw is for protein Smith-Waterman alignments
 # Bio.Wise.dnal is for Smith-Waterman DNA alignments
 
-from __future__ import division
-
-__version__ = "$Revision: 1.11 $"
+__version__ = "$Revision: 1.12 $"
 
 import commands
 import itertools
-import os
 import re
 
 from Bio import Wise
@@ -29,6 +26,7 @@ _SCORE_GAP_EXTENSION = -1
 
 _CMDLINE_DNAL = ["dnal", "-alb", "-nopretty"]
 
+
 def _build_dnal_cmdline(match, mismatch, gap, extension):
     res = _CMDLINE_DNAL[:]
     res.extend(["-match", str(match)])
@@ -39,15 +37,20 @@ def _build_dnal_cmdline(match, mismatch, gap, extension):
     return res
 
 _CMDLINE_FGREP_COUNT = "fgrep -c '%s' %s"
+
+
 def _fgrep_count(pattern, file):
     return int(commands.getoutput(_CMDLINE_FGREP_COUNT % (pattern, file)))
 
 _re_alb_line2coords = re.compile(r"^\[([^:]+):[^\[]+\[([^:]+):")
+
+
 def _alb_line2coords(line):
     return tuple([int(coord)+1 # one-based -> zero-based
                   for coord
                   in _re_alb_line2coords.match(line).groups()])
 
+
 def _get_coords(filename):
     alb = file(filename)
 
@@ -63,13 +66,15 @@ def _get_coords(filename):
 
     if end_line is None: # sequence is too short
         return [(0, 0), (0, 0)]
-        
+
     return zip(*map(_alb_line2coords, [start_line, end_line])) # returns [(start0, end0), (start1, end1)]
 
+
 def _any(seq, pred=bool):
     "Returns True if pred(x) is True at least one element in the iterable"
     return True in itertools.imap(pred, seq)
 
+
 class Statistics(object):
     """
     Calculate statistics from an ALB report
@@ -83,7 +88,7 @@ class Statistics(object):
             self.extensions = 0
         else:
             self.extensions = _fgrep_count('"INSERT" %s' % extension, filename)
-            
+
         self.score = (match*self.matches +
                       mismatch*self.mismatches +
                       gap*self.gaps +
@@ -102,6 +107,7 @@ class Statistics(object):
     def __str__(self):
         return "\t".join([str(x) for x in (self.identity_fraction(), self.matches, self.mismatches, self.gaps, self.extensions)])
 
+
 def align(pair, match=_SCORE_MATCH, mismatch=_SCORE_MISMATCH, gap=_SCORE_GAP_START, extension=_SCORE_GAP_EXTENSION, **keywds):
     cmdline = _build_dnal_cmdline(match, mismatch, gap, extension)
     temp_file = Wise.align(cmdline, pair, **keywds)
@@ -114,6 +120,7 @@ def align(pair, match=_SCORE_MATCH, mismatch=_SCORE_MISMATCH, gap=_SCORE_GAP_STA
         except KeyError:
             raise
 
+
 def main():
     import sys
     stats = align(sys.argv[1:3])
@@ -123,8 +130,10 @@ def main():
     print "identity_fraction: %s" % stats.identity_fraction()
     print "coords: %s" % stats.coords
 
+
 def _test(*args, **keywds):
-    import doctest, sys
+    import doctest
+    import sys
     doctest.testmod(sys.modules[__name__], *args, **keywds)
 
 if __name__ == "__main__":
