@@ -7,7 +7,7 @@
 # some of the models in the Wise2 package by Ewan Birney available from:
 # ftp://ftp.ebi.ac.uk/pub/software/unix/wise2/
 # http://www.ebi.ac.uk/Wise2/
-# 
+#
 # Bio.Wise.psw is for protein Smith-Waterman alignments
 # Bio.Wise.dnal is for Smith-Waterman DNA alignments
 
@@ -24,9 +24,11 @@ _OPTION_GAP_START = "-g"
 _OPTION_GAP_EXTENSION = "-e"
 _OPTION_SCORES = "-m"
 
+
 class AlignmentColumnFullException(Exception):
     pass
 
+
 class Alignment(list):
     def append(self, column_unit):
         try:
@@ -36,6 +38,7 @@ class Alignment(list):
         except IndexError:
             list.append(self, AlignmentColumn(column_unit))
 
+
 class AlignmentColumn(list):
     def _set_kind(self, column_unit):
         if self.kind == "SEQUENCE":
@@ -57,7 +60,8 @@ class AlignmentColumn(list):
 
         self._set_kind(column_unit)
         self[1] = column_unit.column
-        
+
+
 class ColumnUnit(object):
     def __init__(self, unit, column, kind):
         self.unit = unit
@@ -70,6 +74,8 @@ class ColumnUnit(object):
     __repr__ = __str__
 
 _re_unit = re.compile(r"^Unit +([01])- \[ *(-?\d+)- *(-?\d+)\] \[(\w+)\]$")
+
+
 def parse_line(line):
     """
     >>> print parse_line("Column 0:")
@@ -85,7 +91,8 @@ def parse_line(line):
         return
 
     return ColumnUnit(int(match.group(1)), int(match.group(3)), match.group(4))
-    
+
+
 def parse(iterable):
     """
     format
@@ -104,19 +111,20 @@ def parse(iterable):
                 print line,
         except KeyError:
             pass
-            
+
         column_unit = parse_line(line)
         if column_unit:
             alignment.append(column_unit)
 
     return alignment
 
+
 def align(pair,
           scores=None,
           gap_start=None,
           gap_extension=None,
           *args, **keywds):
-    
+
     cmdline = _CMDLINE_PSW[:]
     if scores:
         cmdline.extend((_OPTION_SCORES, scores))
@@ -127,11 +135,13 @@ def align(pair,
     temp_file = Wise.align(cmdline, pair, *args, **keywds)
     return parse(temp_file)
 
+
 def main():
     print align(sys.argv[1:3])
 
+
 def _test(*args, **keywds):
-    import doctest, sys
+    import doctest
     doctest.testmod(sys.modules[__name__], *args, **keywds)
 
 if __name__ == "__main__":
