@@ -66,7 +66,6 @@ Some examples:
       Score=3
     <BLANKLINE>
 
-    
     # Same thing as before, but with a local alignment.
     >>> for a in pairwise2.align.localxx("ACCGT", "ACG"):
     ...     print format_alignment(*a)
@@ -80,7 +79,7 @@ Some examples:
     A-CG-
       Score=3
     <BLANKLINE>
-    
+
     # Do a global alignment.  Identical characters are given 2 points,
     # 1 point is deducted for each non-identical character.
     >>> for a in pairwise2.align.globalmx("ACCGT", "ACG", 2, -1):
@@ -111,7 +110,7 @@ Some examples:
       Score=5
     <BLANKLINE>
 
-The alignment function can also use known matrices already included in 
+The alignment function can also use known matrices already included in
 Biopython ( Bio.SubsMat -> MatrixInfo ).
 
     >>> from Bio.SubsMat import MatrixInfo as matlist
@@ -151,9 +150,10 @@ type help(pairwise2.align.localds) at the Python prompt.
 
 MAX_ALIGNMENTS = 1000   # maximum alignments recovered in traceback
 
+
 class align(object):
     """This class provides functions that do alignments."""
-    
+
     class alignment_function:
         """This class is callable impersonates an alignment function.
         The constructor takes the name of the function.  This class
@@ -163,27 +163,27 @@ class align(object):
         """
         # match code -> tuple of (parameters, docstring)
         match2args = {
-            'x' : ([], ''),
-            'm' : (['match', 'mismatch'],
+            'x': ([], ''),
+            'm': (['match', 'mismatch'],
 """match is the score to given to identical characters.  mismatch is
 the score given to non-identical ones."""),
-            'd' : (['match_dict'],
+            'd': (['match_dict'],
 """match_dict is a dictionary where the keys are tuples of pairs of
 characters and the values are the scores, e.g. ("A", "C") : 2.5."""),
-            'c' : (['match_fn'],
+            'c': (['match_fn'],
 """match_fn is a callback function that takes two characters and
 returns the score between them."""),
             }
         # penalty code -> tuple of (parameters, docstring)
         penalty2args = {
-            'x' : ([], ''),
-            's' : (['open', 'extend'],
+            'x': ([], ''),
+            's': (['open', 'extend'],
 """open and extend are the gap penalties when a gap is opened and
 extended.  They should be negative."""),
-            'd' : (['openA', 'extendA', 'openB', 'extendB'],
+            'd': (['openA', 'extendA', 'openB', 'extendB'],
 """openA and extendA are the gap penalties for sequenceA, and openB
 and extendB for sequeneB.  The penalties should be negative."""),
-            'c' : (['gap_A_fn', 'gap_B_fn'],
+            'c': (['gap_A_fn', 'gap_B_fn'],
 """gap_A_fn and gap_B_fn are callback functions that takes 1) the
 index where the gap is opened, and 2) the length of the gap.  They
 should return a gap penalty."""),
@@ -242,13 +242,13 @@ alignment occurs.
             # this function into forms appropriate for _align.
             keywds = keywds.copy()
             if len(args) != len(self.param_names):
-                raise TypeError("%s takes exactly %d argument (%d given)" \
+                raise TypeError("%s takes exactly %d argument (%d given)"
                     % (self.function_name, len(self.param_names), len(args)))
             i = 0
             while i < len(self.param_names):
                 if self.param_names[i] in [
-                    'sequenceA', 'sequenceB',
-                    'gap_A_fn', 'gap_B_fn', 'match_fn']:
+                   'sequenceA', 'sequenceB',
+                   'gap_A_fn', 'gap_B_fn', 'match_fn']:
                     keywds[self.param_names[i]] = args[i]
                     i += 1
                 elif self.param_names[i] == 'match':
@@ -274,7 +274,7 @@ alignment occurs.
                     keywds['gap_B_fn'] = affine_penalty(openB, extendB, pe)
                     i += 4
                 else:
-                    raise ValueError("unknown parameter %r" \
+                    raise ValueError("unknown parameter %r"
                                      % self.param_names[i])
 
             # Here are the default parameters for _align.  Assign
@@ -295,11 +295,11 @@ alignment occurs.
             for name, default in default_params:
                 keywds[name] = keywds.get(name, default)
             return keywds
-            
+
         def __call__(self, *args, **keywds):
             keywds = self.decode(*args, **keywds)
             return _align(**keywds)
-        
+
     def __getattr__(self, attr):
         return self.alignment_function(attr)
 align = align()
@@ -329,7 +329,7 @@ def _align(sequenceA, sequenceB, match_fn, gap_A_fn, gap_B_fn,
 
     #print "SCORE"; print_matrix(score_matrix)
     #print "TRACEBACK"; print_matrix(trace_matrix)
-         
+
     # Look for the proper starting point.  Get a list of all possible
     # starting points.
     starts = _find_start(
@@ -341,7 +341,7 @@ def _align(sequenceA, sequenceB, match_fn, gap_A_fn, gap_B_fn,
     # If they only want the score, then return it.
     if score_only:
         return best_score
-    
+
     tolerance = 0  # XXX do anything with this?
     # Now find all the positions within some tolerance of the best
     # score.
@@ -352,20 +352,21 @@ def _align(sequenceA, sequenceB, match_fn, gap_A_fn, gap_B_fn,
             del starts[i]
         else:
             i += 1
-    
+
     # Recover the alignments and return them.
     x = _recover_alignments(
         sequenceA, sequenceB, starts, score_matrix, trace_matrix,
         align_globally, penalize_end_gaps, gap_char, one_alignment_only)
     return x
 
+
 def _make_score_matrix_generic(
-    sequenceA, sequenceB, match_fn, gap_A_fn, gap_B_fn, 
-    penalize_extend_when_opening, penalize_end_gaps, align_globally,
-    score_only):
+        sequenceA, sequenceB, match_fn, gap_A_fn, gap_B_fn,
+        penalize_extend_when_opening, penalize_end_gaps, align_globally,
+        score_only):
     # This is an implementation of the Needleman-Wunsch dynamic
     # programming algorithm for aligning sequences.
-    
+
     # Create the score and traceback matrices.  These should be in the
     # shape:
     # sequenceA (down) x sequenceB (across)
@@ -413,7 +414,7 @@ def _make_score_matrix_generic(
             # character to align from, and thus a different length
             # gap.
             for i in range(0, col-1):
-                score = score_matrix[row-1][i] + gap_A_fn(i, col-1-i)
+                score = score_matrix[row-1][i] + gap_A_fn(row, col-1-i)
                 score_rint = rint(score)
                 if score_rint == best_score_rint:
                     best_score, best_score_rint = score, score_rint
@@ -421,10 +422,10 @@ def _make_score_matrix_generic(
                 elif score_rint > best_score_rint:
                     best_score, best_score_rint = score, score_rint
                     best_indexes = [(row-1, i)]
-            
+
             # Try to find a better score by opening gaps in sequenceB.
             for i in range(0, row-1):
-                score = score_matrix[i][col-1] + gap_B_fn(i, row-1-i)
+                score = score_matrix[i][col-1] + gap_B_fn(col, row-1-i)
                 score_rint = rint(score)
                 if score_rint == best_score_rint:
                     best_score, best_score_rint = score, score_rint
@@ -440,10 +441,11 @@ def _make_score_matrix_generic(
             trace_matrix[row][col] = best_indexes
     return score_matrix, trace_matrix
 
+
 def _make_score_matrix_fast(
-    sequenceA, sequenceB, match_fn, open_A, extend_A, open_B, extend_B,
-    penalize_extend_when_opening, penalize_end_gaps,
-    align_globally, score_only):
+        sequenceA, sequenceB, match_fn, open_A, extend_A, open_B, extend_B,
+        penalize_extend_when_opening, penalize_end_gaps,
+        align_globally, score_only):
     first_A_gap = calc_affine_penalty(1, open_A, extend_A,
                                       penalize_extend_when_opening)
     first_B_gap = calc_affine_penalty(1, open_B, extend_B,
@@ -501,14 +503,14 @@ def _make_score_matrix_fast(
     for i in range(lenB-1):
         col_cache_score[i] = score_matrix[0][i] + first_B_gap
         col_cache_index[i] = [(0, i)]
-        
+
     # Fill in the score_matrix.
     for row in range(1, lenA):
         for col in range(1, lenB):
             # Calculate the score that would occur by extending the
             # alignment without gaps.
             nogap_score = score_matrix[row-1][col-1]
-            
+
             # Check the score that would occur if there were a gap in
             # sequence A.
             if col > 1:
@@ -516,7 +518,7 @@ def _make_score_matrix_fast(
             else:
                 row_score = nogap_score - 1   # Make sure it's not the best.
             # Check the score that would occur if there were a gap in
-            # sequence B.  
+            # sequence B.
             if row > 1:
                 col_score = col_cache_score[col-1]
             else:
@@ -575,9 +577,10 @@ def _make_score_matrix_fast(
                 if (row-1, col-1) not in row_cache_index[row-1]:
                     row_cache_index[row-1] = row_cache_index[row-1] + \
                                              [(row-1, col-1)]
-                    
+
     return score_matrix, trace_matrix
-    
+
+
 def _recover_alignments(sequenceA, sequenceB, starts,
                         score_matrix, trace_matrix, align_globally,
                         penalize_end_gaps, gap_char, one_alignment_only):
@@ -623,7 +626,7 @@ def _recover_alignments(sequenceA, sequenceB, starts,
             seqB = sequenceB[:prevB] + seqB
             # add the rest of the gaps
             seqA, seqB = _lpad_until_equal(seqA, seqB, gap_char)
-            
+
             # Now make sure begin is set.
             if begin is None:
                 if align_globally:
@@ -650,9 +653,10 @@ def _recover_alignments(sequenceA, sequenceB, starts,
                         (seqA, seqB, score, begin, end, prev_pos, next_pos))
                     if one_alignment_only:
                         break
-                    
+
     return _clean_alignments(tracebacks)
 
+
 def _find_start(score_matrix, sequenceA, sequenceB, gap_A_fn, gap_B_fn,
                 penalize_end_gaps, align_globally):
     # Return a list of (score, (row, col)) indicating every possible
@@ -668,6 +672,7 @@ def _find_start(score_matrix, sequenceA, sequenceB, gap_A_fn, gap_B_fn,
         starts = _find_local_start(score_matrix)
     return starts
 
+
 def _find_global_start(sequenceA, sequenceB,
                        score_matrix, gap_A_fn, gap_B_fn, penalize_end_gaps):
     # The whole sequence should be aligned, so return the positions at
@@ -689,6 +694,7 @@ def _find_global_start(sequenceA, sequenceB,
         positions.append((score, (nrows-1, col)))
     return positions
 
+
 def _find_local_start(score_matrix):
     # Return every position in the matrix.
     positions = []
@@ -699,13 +705,14 @@ def _find_local_start(score_matrix):
             positions.append((score, (row, col)))
     return positions
 
+
 def _clean_alignments(alignments):
     # Take a list of alignments and return a cleaned version.  Remove
     # duplicates, make sure begin and end are set correctly, remove
     # empty alignments.
     unique_alignments = []
-    for align in alignments :
-        if align not in unique_alignments :
+    for align in alignments:
+        if align not in unique_alignments:
             unique_alignments.append(align)
     i = 0
     while i < len(unique_alignments):
@@ -723,6 +730,7 @@ def _clean_alignments(alignments):
         i += 1
     return unique_alignments
 
+
 def _pad_until_equal(s1, s2, char):
     # Add char to the end of s1 or s2 until they are equal length.
     ls1, ls2 = len(s1), len(s2)
@@ -732,6 +740,7 @@ def _pad_until_equal(s1, s2, char):
         s2 = _pad(s2, char, ls1-ls2)
     return s1, s2
 
+
 def _lpad_until_equal(s1, s2, char):
     # Add char to the beginning of s1 or s2 until they are equal
     # length.
@@ -742,18 +751,23 @@ def _lpad_until_equal(s1, s2, char):
         s2 = _lpad(s2, char, ls1-ls2)
     return s1, s2
 
+
 def _pad(s, char, n):
     # Append n chars to the end of s.
     return s + char*n
 
+
 def _lpad(s, char, n):
     # Prepend n chars to the beginning of s.
     return char*n + s
 
 _PRECISION = 1000
+
+
 def rint(x, precision=_PRECISION):
     return int(x * precision + 0.5)
 
+
 class identity_match:
     """identity_match([match][, mismatch]) -> match_fn
 
@@ -765,11 +779,13 @@ class identity_match:
     def __init__(self, match=1, mismatch=0):
         self.match = match
         self.mismatch = mismatch
+
     def __call__(self, charA, charB):
         if charA == charB:
             return self.match
         return self.mismatch
 
+
 class dictionary_match:
     """dictionary_match(score_dict[, symmetric]) -> match_fn
 
@@ -784,6 +800,7 @@ class dictionary_match:
     def __init__(self, score_dict, symmetric=1):
         self.score_dict = score_dict
         self.symmetric = symmetric
+
     def __call__(self, charA, charB):
         if self.symmetric and (charA, charB) not in self.score_dict:
             # If the score dictionary is symmetric, then look up the
@@ -791,6 +808,7 @@ class dictionary_match:
             charB, charA = charA, charB
         return self.score_dict[(charA, charB)]
 
+
 class affine_penalty:
     """affine_penalty(open, extend[, penalize_extend_when_opening]) -> gap_fn
 
@@ -802,10 +820,12 @@ class affine_penalty:
             raise ValueError("Gap penalties should be non-positive.")
         self.open, self.extend = open, extend
         self.penalize_extend_when_opening = penalize_extend_when_opening
+
     def __call__(self, index, length):
         return calc_affine_penalty(
             length, self.open, self.extend, self.penalize_extend_when_opening)
 
+
 def calc_affine_penalty(length, open, extend, penalize_extend_when_opening):
     if length <= 0:
         return 0
@@ -814,6 +834,7 @@ def calc_affine_penalty(length, open, extend, penalize_extend_when_opening):
         penalty -= extend
     return penalty
 
+
 def print_matrix(matrix):
     """print_matrix(matrix)
 
@@ -828,9 +849,10 @@ def print_matrix(matrix):
     ndigits = map(max, matrixT)
     for i in range(len(matrix)):
         #Using string formatting trick to add leading spaces,
-        print " ".join("%*s " % (ndigits[j], matrix[i][j]) \
+        print " ".join("%*s " % (ndigits[j], matrix[i][j])
                        for j in range(len(matrix[i])))
 
+
 def format_alignment(align1, align2, score, begin, end):
     """format_alignment(align1, align2, score, begin, end) -> string
 
@@ -855,7 +877,7 @@ except ImportError:
 
 def _test():
     """Run the module's doctests (PRIVATE)."""
-    print "Runing doctests..."
+    print "Running doctests..."
     import doctest
     doctest.testmod(optionflags=doctest.IGNORE_EXCEPTION_DETAIL)
     print "Done"
