@@ -26,6 +26,7 @@ from Bio.Seq import UnknownSeq
 
 from Bio._py3k import _is_int_or_long
 
+
 class DatabaseLoader:
     """Object used to load SeqRecord objects into a BioSQL database."""
     def __init__(self, adaptor, dbid, fetch_NCBI_taxonomy=False):
@@ -45,7 +46,7 @@ class DatabaseLoader:
         self.adaptor = adaptor
         self.dbid = dbid
         self.fetch_NCBI_taxonomy = fetch_NCBI_taxonomy
-    
+
     def load_seqrecord(self, record):
         """Load a Biopython SeqRecord into the database.
         """
@@ -81,7 +82,6 @@ class DatabaseLoader:
             (name, definition))
         return self.adaptor.last_id("ontology")
 
-    
     def _get_term_id(self,
                      name,
                      ontology_id=None,
@@ -107,7 +107,7 @@ class DatabaseLoader:
         id_results = self.adaptor.execute_and_fetchall(sql, fields)
         # something is wrong
         if len(id_results) > 1:
-            raise ValueError("Multiple term ids for %s: %r" % 
+            raise ValueError("Multiple term ids for %s: %r" %
                              (name, id_results))
         elif len(id_results) == 1:
             return id_results[0][0]
@@ -120,13 +120,13 @@ class DatabaseLoader:
             return self.adaptor.last_id("term")
 
     def _add_dbxref(self, dbname, accession, version):
-       """Insert a dbxref and return its id."""
-       
-       self.adaptor.execute(
-           "INSERT INTO dbxref(dbname, accession, version)" \
-           " VALUES (%s, %s, %s)", (dbname, accession, version))
-       return self.adaptor.last_id("dbxref")
-           
+        """Insert a dbxref and return its id."""
+
+        self.adaptor.execute(
+            "INSERT INTO dbxref(dbname, accession, version)"
+            " VALUES (%s, %s, %s)", (dbname, accession, version))
+        return self.adaptor.last_id("dbxref")
+
     def _get_taxon_id(self, record):
         """Get the taxon id for this record (PRIVATE).
 
@@ -135,7 +135,7 @@ class DatabaseLoader:
         This searches the taxon/taxon_name tables using the
         NCBI taxon ID, scientific name and common name to find
         the matching taxon table entry's id.
-        
+
         If the species isn't in the taxon table, and we have at
         least the NCBI taxon ID, scientific name or common name,
         at least a minimal stub entry is created in the table.
@@ -148,13 +148,13 @@ class DatabaseLoader:
         will populate and update the taxon/taxon_name tables
         with the latest information from the NCBI.
         """
-        
+
         # To find the NCBI taxid, first check for a top level annotation
         ncbi_taxon_id = None
         if "ncbi_taxid" in record.annotations:
             #Could be a list of IDs.
-            if isinstance(record.annotations["ncbi_taxid"],list):
-                if len(record.annotations["ncbi_taxid"])==1:
+            if isinstance(record.annotations["ncbi_taxid"], list):
+                if len(record.annotations["ncbi_taxid"]) == 1:
                     ncbi_taxon_id = record.annotations["ncbi_taxid"][0]
             else:
                 ncbi_taxon_id = record.annotations["ncbi_taxid"]
@@ -168,7 +168,8 @@ class DatabaseLoader:
                             if db_xref.startswith("taxon:"):
                                 ncbi_taxon_id = int(db_xref[6:])
                                 break
-                if ncbi_taxon_id: break
+                if ncbi_taxon_id:
+                    break
 
         try:
             scientific_name = record.annotations["organism"][:255]
@@ -182,7 +183,6 @@ class DatabaseLoader:
         # Cropping it now should help in getting a match when searching,
         # and avoids an error if we try and add these to the database.
 
-
         if ncbi_taxon_id:
             #Good, we have the NCBI taxon to go on - this is unambiguous :)
             #Note that the scientific name and common name will only be
@@ -190,7 +190,7 @@ class DatabaseLoader:
             return self._get_taxon_id_from_ncbi_taxon_id(ncbi_taxon_id,
                                                          scientific_name,
                                                          common_name)
-        
+
         if not common_name and not scientific_name:
             # Nothing to go on... and there is no point adding
             # a new entry to the database.  We'll just leave this
@@ -201,7 +201,7 @@ class DatabaseLoader:
         # (stored in GenBank files as the organism and/or the source).
         if scientific_name:
             taxa = self.adaptor.execute_and_fetch_col0(
-                "SELECT taxon_id FROM taxon_name" \
+                "SELECT taxon_id FROM taxon_name"
                 " WHERE name_class = 'scientific name' AND name = %s",
                 (scientific_name,))
             if taxa:
@@ -211,7 +211,7 @@ class DatabaseLoader:
         # Last chance...
         if common_name:
             taxa = self.adaptor.execute_and_fetch_col0(
-                "SELECT DISTINCT taxon_id FROM taxon_name" \
+                "SELECT DISTINCT taxon_id FROM taxon_name"
                 " WHERE name = %s",
                 (common_name,))
             #Its natural that several distinct taxa will have the same common
@@ -250,13 +250,13 @@ class DatabaseLoader:
             lineage.append([None, "varietas",
                             record.annotations["variant"]])
         lineage[-1][0] = ncbi_taxon_id
-        
+
         left_value = self.adaptor.execute_one(
             "SELECT MAX(left_value) FROM taxon")[0]
         if not left_value:
             left_value = 0
         left_value += 1
-        
+
         # XXX -- Brad: Fixing this for now in an ugly way because
         # I am getting overlaps for right_values. I need to dig into this
         # more to actually understand how it works. I'm not sure it is
@@ -270,8 +270,8 @@ class DatabaseLoader:
         parent_taxon_id = None
         for taxon in lineage:
             self.adaptor.execute(
-                "INSERT INTO taxon(parent_taxon_id, ncbi_taxon_id, node_rank,"\
-                " left_value, right_value)" \
+                "INSERT INTO taxon(parent_taxon_id, ncbi_taxon_id, node_rank,"
+                " left_value, right_value)"
                 " VALUES (%s, %s, %s, %s, %s)", (parent_taxon_id,
                                                  taxon[0],
                                                  taxon[1],
@@ -279,7 +279,7 @@ class DatabaseLoader:
                                                  right_value))
             taxon_id = self.adaptor.last_id("taxon")
             self.adaptor.execute(
-                "INSERT INTO taxon_name(taxon_id, name, name_class)" \
+                "INSERT INTO taxon_name(taxon_id, name, name_class)"
                 "VALUES (%s, %s, 'scientific name')", (taxon_id, taxon[2][:255]))
             #Note the name field is limited to 255, some SwissProt files
             #have a multi-species name which can be longer.  So truncate this.
@@ -288,7 +288,7 @@ class DatabaseLoader:
             parent_taxon_id = taxon_id
         if common_name:
             self.adaptor.execute(
-                "INSERT INTO taxon_name(taxon_id, name, name_class)" \
+                "INSERT INTO taxon_name(taxon_id, name, name_class)"
                 "VALUES (%s, %s, 'common name')", (
                 taxon_id, common_name))
 
@@ -299,7 +299,7 @@ class DatabaseLoader:
 
         We need to make this conversion to match the taxon_name.name_class
         values used by the BioSQL load_ncbi_taxonomy.pl script.
-        
+
         e.g.
         "ScientificName" -> "scientific name",
         "EquivalentName" -> "equivalent name",
@@ -315,8 +315,9 @@ class DatabaseLoader:
 
         #Try automatically by adding spaces before each capital
         def add_space(letter):
+            """Adds a space before a capital letter."""
             if letter.isupper():
-                return " "+letter.lower()
+                return " " + letter.lower()
             else:
                 return letter
         answer = "".join([add_space(letter) for letter in entrez_name]).strip()
@@ -324,17 +325,17 @@ class DatabaseLoader:
         return answer
 
     def _get_taxon_id_from_ncbi_taxon_id(self, ncbi_taxon_id,
-                                         scientific_name = None,
-                                         common_name = None):
+                                         scientific_name=None,
+                                         common_name=None):
         """Get the taxon id for this record from the NCBI taxon ID (PRIVATE).
 
         ncbi_taxon_id - string containing an NCBI taxon id
         scientific_name - string, used if a stub entry is recorded
         common_name - string, used if a stub entry is recorded
-        
+
         This searches the taxon table using ONLY the NCBI taxon ID
         to find the matching taxon table entry's ID (database key).
-        
+
         If the species isn't in the taxon table, and the fetch_NCBI_taxonomy
         flag is true, Biopython will attempt to go online using Bio.Entrez
         to fetch the official NCBI lineage, recursing up the tree until an
@@ -371,16 +372,16 @@ class DatabaseLoader:
             species_names.append(("scientific name", scientific_name))
         if common_name:
             species_names.append(("common name", common_name))
-        
+
         if self.fetch_NCBI_taxonomy:
             #Go online to get the parent taxon ID!
-            handle = Entrez.efetch(db="taxonomy",id=ncbi_taxon_id,retmode="XML")
+            handle = Entrez.efetch(db="taxonomy", id=ncbi_taxon_id, retmode="XML")
             taxonomic_record = Entrez.read(handle)
             if len(taxonomic_record) == 1:
                 assert taxonomic_record[0]["TaxId"] == str(ncbi_taxon_id), \
                        "%s versus %s" % (taxonomic_record[0]["TaxId"],
                                          ncbi_taxon_id)
-                parent_taxon_id = self._get_taxon_id_from_ncbi_lineage( \
+                parent_taxon_id = self._get_taxon_id_from_ncbi_lineage(
                                             taxonomic_record[0]["LineageEx"])
                 rank = taxonomic_record[0]["Rank"]
                 genetic_code = taxonomic_record[0]["GeneticCode"]["GCId"]
@@ -414,8 +415,8 @@ class DatabaseLoader:
             # know the NCBI taxon IDs for these parent nodes.
 
         self.adaptor.execute(
-            "INSERT INTO taxon(parent_taxon_id, ncbi_taxon_id, node_rank,"\
-            " genetic_code, mito_genetic_code, left_value, right_value)" \
+            "INSERT INTO taxon(parent_taxon_id, ncbi_taxon_id, node_rank,"
+            " genetic_code, mito_genetic_code, left_value, right_value)"
             " VALUES (%s, %s, %s, %s, %s, %s, %s)", (parent_taxon_id,
                                                      ncbi_taxon_id,
                                                      rank,
@@ -428,9 +429,9 @@ class DatabaseLoader:
         #Record the scientific name, common name, etc
         for name_class, name in species_names:
             self.adaptor.execute(
-                "INSERT INTO taxon_name(taxon_id, name, name_class)" \
-                " VALUES (%s, %s, %s)", (taxon_id, 
-                                         name[:255], 
+                "INSERT INTO taxon_name(taxon_id, name, name_class)"
+                " VALUES (%s, %s, %s)", (taxon_id,
+                                         name[:255],
                                          name_class))
         return taxon_id
 
@@ -446,20 +447,20 @@ class DatabaseLoader:
         - ScientificName (string)
         (and that is all at the time of writing)
 
-        This method will record all the lineage given, returning the the taxon id
+        This method will record all the lineage given, returning the taxon id
         (database key, not NCBI taxon id) of the final entry (the species).
         """
         ncbi_taxon_id = taxonomic_lineage[-1]["TaxId"]
 
         #Is this in the database already?  Check the taxon table...
         taxon_id = self.adaptor.execute_and_fetch_col0(
-            "SELECT taxon_id FROM taxon" \
+            "SELECT taxon_id FROM taxon"
             " WHERE ncbi_taxon_id=%s" % ncbi_taxon_id)
         if taxon_id:
             # we could verify that the Scientific Name etc in the database
             # is the same and update it or print a warning if not...
             if isinstance(taxon_id, list):
-                assert len(taxon_id)==1
+                assert len(taxon_id) == 1
                 return taxon_id[0]
             else:
                 return taxon_id
@@ -475,7 +476,7 @@ class DatabaseLoader:
         # INSERT new taxon
         rank = taxonomic_lineage[-1].get("Rank", None)
         self.adaptor.execute(
-                "INSERT INTO taxon(ncbi_taxon_id, parent_taxon_id, node_rank)"\
+                "INSERT INTO taxon(ncbi_taxon_id, parent_taxon_id, node_rank)"
                 " VALUES (%s, %s, %s)", (ncbi_taxon_id, parent_taxon_id, rank))
         taxon_id = self.adaptor.last_id("taxon")
         assert isinstance(taxon_id, int) or isinstance(taxon_id, long), repr(taxon_id)
@@ -483,20 +484,19 @@ class DatabaseLoader:
         scientific_name = taxonomic_lineage[-1].get("ScientificName", None)
         if scientific_name:
             self.adaptor.execute(
-                    "INSERT INTO taxon_name(taxon_id, name, name_class)" \
-                    " VALUES (%s, %s, 'scientific name')", (taxon_id, 
+                    "INSERT INTO taxon_name(taxon_id, name, name_class)"
+                    " VALUES (%s, %s, 'scientific name')", (taxon_id,
                                                             scientific_name[:255]))
         return taxon_id
 
-
     def _load_bioentry_table(self, record):
         """Fill the bioentry table with sequence information (PRIVATE).
 
         record - SeqRecord object to add to the database.
         """
         # get the pertinent info and insert it
-        
-        if record.id.count(".") == 1: # try to get a version from the id
+
+        if record.id.count(".") == 1:  # try to get a version from the id
             #This assumes the string is something like "XXXXXXXX.123"
             accession, version = record.id.split('.')
             try:
@@ -504,12 +504,12 @@ class DatabaseLoader:
             except ValueError:
                 accession = record.id
                 version = 0
-        else: # otherwise just use a version of 0
+        else:  # otherwise just use a version of 0
             accession = record.id
             version = 0
 
         if "accessions" in record.annotations \
-        and isinstance(record.annotations["accessions"],list) \
+        and isinstance(record.annotations["accessions"], list) \
         and record.annotations["accessions"]:
             #Take the first accession (one if there is more than one)
             accession = record.annotations["accessions"][0]
@@ -527,7 +527,7 @@ class DatabaseLoader:
         #Allow description and division to default to NULL as in BioPerl.
         description = getattr(record, 'description', None)
         division = record.annotations.get("data_file_division", None)
-        
+
         sql = """
         INSERT INTO bioentry (
          biodatabase_id,
@@ -551,7 +551,7 @@ class DatabaseLoader:
         #        division, description, version
         self.adaptor.execute(sql, (self.dbid,
                                    taxon_id,
-                                   record.name, 
+                                   record.name,
                                    accession,
                                    identifier,
                                    division,
@@ -572,12 +572,13 @@ class DatabaseLoader:
         # 14-SEP-2000
         date = record.annotations.get("date",
                                       strftime("%d-%b-%Y", gmtime()).upper())
-        if isinstance(date, list) : date = date[0]
+        if isinstance(date, list):
+            date = date[0]
         annotation_tags_id = self._get_ontology_id("Annotation Tags")
         date_id = self._get_term_id("date_changed", annotation_tags_id)
         sql = r"INSERT INTO bioentry_qualifier_value" \
               r" (bioentry_id, term_id, value, rank)" \
-              r" VALUES (%s, %s, %s, 1)" 
+              r" VALUES (%s, %s, %s, 1)"
         self.adaptor.execute(sql, (bioentry_id, date_id, date))
 
     def _load_biosequence(self, record, bioentry_id):
@@ -590,7 +591,7 @@ class DatabaseLoader:
             #The biosequence table entry is optional, so if we haven't
             #got a sequence, we don't need to write to the table.
             return
-        
+
         # determine the string representation of the alphabet
         if isinstance(record.seq.alphabet, Alphabet.DNAAlphabet):
             alphabet = "dna"
@@ -633,8 +634,8 @@ class DatabaseLoader:
             #the newlines, but we should check BioPerl etc to be consistent.
             sql = "INSERT INTO comment (bioentry_id, comment_text, rank)" \
                   " VALUES (%s, %s, %s)"
-            self.adaptor.execute(sql, (bioentry_id, comment, index+1))
-        
+            self.adaptor.execute(sql, (bioentry_id, comment, index + 1))
+
     def _load_annotations(self, record, bioentry_id):
         """Record a SeqRecord's misc annotations in the database (PRIVATE).
 
@@ -663,7 +664,7 @@ class DatabaseLoader:
                     if isinstance(entry, str) or isinstance(entry, int):
                         #Easy case
                         rank += 1
-                        self.adaptor.execute(many_sql, \
+                        self.adaptor.execute(many_sql,
                                      (bioentry_id, term_id, str(entry), rank))
                     else:
                         pass
@@ -671,14 +672,13 @@ class DatabaseLoader:
                         #      % (key, str(type(entry)))
             elif isinstance(value, str) or isinstance(value, int):
                 #Have a simple single entry, leave rank as the DB default
-                self.adaptor.execute(mono_sql, \
+                self.adaptor.execute(mono_sql,
                                      (bioentry_id, term_id, str(value)))
             else:
                 pass
                 #print "Ignoring annotation '%s' entry of type '%s'" \
                 #      % (key, type(value))
 
-
     def _load_reference(self, reference, rank, bioentry_id):
         """Record a SeqRecord's annotated references in the database (PRIVATE).
 
@@ -689,14 +689,14 @@ class DatabaseLoader:
         refs = None
         if reference.medline_id:
             refs = self.adaptor.execute_and_fetch_col0(
-                "SELECT reference_id" \
-                "  FROM reference JOIN dbxref USING (dbxref_id)" \
+                "SELECT reference_id"
+                "  FROM reference JOIN dbxref USING (dbxref_id)"
                 " WHERE dbname = 'MEDLINE' AND accession = %s",
                 (reference.medline_id,))
         if not refs and reference.pubmed_id:
             refs = self.adaptor.execute_and_fetch_col0(
-                "SELECT reference_id" \
-                "  FROM reference JOIN dbxref USING (dbxref_id)" \
+                "SELECT reference_id"
+                "  FROM reference JOIN dbxref USING (dbxref_id)"
                 " WHERE dbname = 'PUBMED' AND accession = %s",
                 (reference.pubmed_id,))
         if not refs:
@@ -705,8 +705,8 @@ class DatabaseLoader:
                 s.append(f or "<undef>")
             crc = crc64("".join(s))
             refs = self.adaptor.execute_and_fetch_col0(
-                "SELECT reference_id FROM reference" \
-                  r" WHERE crc = %s", (crc,))
+                "SELECT reference_id FROM reference"
+                    r" WHERE crc = %s", (crc,))
         if not refs:
             if reference.medline_id:
                 dbxref_id = self._add_dbxref("MEDLINE",
@@ -717,13 +717,13 @@ class DatabaseLoader:
             else:
                 dbxref_id = None
             authors = reference.authors or None
-            title =  reference.title or None
+            title = reference.title or None
             #The location/journal field cannot be Null, so default
             #to an empty string rather than None:
             journal = reference.journal or ""
             self.adaptor.execute(
-                "INSERT INTO reference (dbxref_id, location," \
-                " title, authors, crc)" \
+                "INSERT INTO reference (dbxref_id, location,"
+                " title, authors, crc)"
                 " VALUES (%s, %s, %s, %s, %s)",
                 (dbxref_id, journal, title,
                  authors, crc))
@@ -737,13 +737,13 @@ class DatabaseLoader:
         else:
             start = None
             end = None
-        
+
         sql = "INSERT INTO bioentry_reference (bioentry_id, reference_id," \
               " start_pos, end_pos, rank)" \
               " VALUES (%s, %s, %s, %s, %s)"
         self.adaptor.execute(sql, (bioentry_id, reference_id,
                                    start, end, rank + 1))
-        
+
     def _load_seqfeature(self, feature, feature_rank, bioentry_id):
         """Load a biopython SeqFeature into the database (PRIVATE).
         """
@@ -760,13 +760,13 @@ class DatabaseLoader:
         """
         ontology_id = self._get_ontology_id('SeqFeature Keys')
         seqfeature_key_id = self._get_term_id(feature_type,
-                                              ontology_id = ontology_id)
+                                              ontology_id=ontology_id)
         # XXX source is always EMBL/GenBank/SwissProt here; it should depend on
         # the record (how?)
         source_cat_id = self._get_ontology_id('SeqFeature Sources')
         source_term_id = self._get_term_id('EMBL/GenBank/SwissProt',
-                                      ontology_id = source_cat_id)
-        
+                                      ontology_id=source_cat_id)
+
         sql = r"INSERT INTO seqfeature (bioentry_id, type_term_id, " \
               r"source_term_id, rank) VALUES (%s, %s, %s, %s)"
         self.adaptor.execute(sql, (bioentry_id, seqfeature_key_id,
@@ -795,13 +795,14 @@ class DatabaseLoader:
             # e.g. order locations... we don't record "order" so it
             # will become a "join" on reloading. What does BioPerl do?
             import warnings
-            warnings.warn("%s location operators are not fully supported" \
-                          % feature.location_operator)
-        
+            from Bio import BiopythonWarning
+            warnings.warn("%s location operators are not fully supported"
+                          % feature.location_operator, BiopythonWarning)
+
         # two cases, a simple location or a split location
         if not feature.sub_features:    # simple location
             self._insert_seqfeature_location(feature, 1, seqfeature_id)
-        else: # split location
+        else:  # split location
             for rank, cur_feature in enumerate(feature.sub_features):
                 self._insert_seqfeature_location(cur_feature,
                                                  rank + 1,
@@ -832,7 +833,7 @@ class DatabaseLoader:
         if feature.ref:
             # sub_feature remote locations when they are in the same db as the current
             # record do not have a value for ref_db, which the SeqFeature object
-            # stores as None. BioSQL schema requires a varchar and is not NULL 
+            # stores as None. BioSQL schema requires a varchar and is not NULL
             dbxref_id = self._get_dbxref_id(feature.ref_db or "", feature.ref)
         else:
             dbxref_id = None
@@ -901,7 +902,6 @@ class DatabaseLoader:
                 self._load_seqfeature_dbxref(qualifiers[qualifier_key],
                                              seqfeature_id)
 
-
     def _load_seqfeature_dbxref(self, dbxrefs, seqfeature_id):
         """Add database crossreferences of a SeqFeature to the database (PRIVATE).
 
@@ -926,7 +926,7 @@ class DatabaseLoader:
             # Split the DB:accession format string at colons.  We have to
             # account for multiple-line and multiple-accession entries
             try:
-                dbxref_data = value.replace(' ','').replace('\n','').split(':')
+                dbxref_data = value.replace(' ', '').replace('\n', '').split(':')
                 db = dbxref_data[0]
                 accessions = dbxref_data[1:]
             except:
@@ -937,8 +937,8 @@ class DatabaseLoader:
                 # Get the dbxref_id value for the dbxref data
                 dbxref_id = self._get_dbxref_id(db, accession)
                 # Insert the seqfeature_dbxref data
-                self._get_seqfeature_dbxref(seqfeature_id, dbxref_id, rank+1)
-        
+                self._get_seqfeature_dbxref(seqfeature_id, dbxref_id, rank + 1)
+
     def _get_dbxref_id(self, db, accession):
         """ _get_dbxref_id(self, db, accession) -> Int
 
@@ -1000,9 +1000,9 @@ class DatabaseLoader:
             #
             # Annoyingly I have seen the NCBI use both the style
             # "GO:GO:123" and "GO:123" in different vintages.
-            assert value.count("\n")==0
+            assert value.count("\n") == 0
             try:
-                db, accession = value.split(':',1)
+                db, accession = value.split(':', 1)
                 db = db.strip()
                 accession = accession.strip()
             except:
@@ -1010,7 +1010,7 @@ class DatabaseLoader:
             # Get the dbxref_id value for the dbxref data
             dbxref_id = self._get_dbxref_id(db, accession)
             # Insert the bioentry_dbxref  data
-            self._get_bioentry_dbxref(bioentry_id, dbxref_id, rank+1)
+            self._get_bioentry_dbxref(bioentry_id, dbxref_id, rank + 1)
 
     def _get_bioentry_dbxref(self, bioentry_id, dbxref_id, rank):
         """ Check for a pre-existing bioentry_dbxref entry with the passed
@@ -1038,7 +1038,8 @@ class DatabaseLoader:
               '(%s, %s, %s)'
         self.adaptor.execute(sql, (bioentry_id, dbxref_id, rank))
         return (bioentry_id, dbxref_id)
-            
+
+
 class DatabaseRemover:
     """Complement the Loader functionality by fully removing a database.
 
@@ -1063,4 +1064,3 @@ class DatabaseRemover:
         self.adaptor.execute(sql, (self.dbid,))
         sql = r"DELETE FROM biodatabase WHERE biodatabase_id = %s"
         self.adaptor.execute(sql, (self.dbid,))
-
