@@ -9,32 +9,34 @@ sys.path.insert(0, '.')
 from Tkinter import *
 from FileDialog import SaveFileDialog
 
+
 class NotePad(Toplevel):
-    def __init__(self, master= None):
+    def __init__(self, master=None):
         Toplevel.__init__(self, master)
         self.menubar = Menu(self)
         self.filemenu = Menu(self.menubar)
-        self.filemenu.add_command(label = "Save", command = self.save)
+        self.filemenu.add_command(label="Save", command=self.save)
         self.filemenu.add_separator()
-        self.filemenu.add_command(label = "Dismiss", command = self.destroy)
-    
-        self.menubar.add_cascade(label="File", menu=self.filemenu)
-        self.configure(menu = self.menubar)
-        self.yscroll = Scrollbar(self,orient=VERTICAL)
-        self.tid = Text(self, yscrollcommand = self.yscroll.set)
-        self.yscroll.configure(command = self.tid.yview)
-        self.tid.pack(side = LEFT, fill = BOTH, expand = 1)
-        self.yscroll.pack(side = RIGHT, fill = Y)
-        
+        self.filemenu.add_command(label="Dismiss", command=self.destroy)
 
-    def text_id(self): return self.tid
-    def insert(self,start, txt):
+        self.menubar.add_cascade(label="File", menu=self.filemenu)
+        self.configure(menu=self.menubar)
+        self.yscroll = Scrollbar(self, orient=VERTICAL)
+        self.tid = Text(self, yscrollcommand=self.yscroll.set)
+        self.yscroll.configure(command=self.tid.yview)
+        self.tid.pack(side=LEFT, fill=BOTH, expand=1)
+        self.yscroll.pack(side=RIGHT, fill=Y)
+
+    def text_id(self):
+        return self.tid
+
+    def insert(self, start, txt):
         self.tid.insert(start, txt)
-        
+
     def save(self):
         fd = SaveFileDialog(self)
         file = fd.go(key="test")
         if file:
             fid = open(file, 'w')
-            fid.write(self.tid.get(0.0,END))
+            fid.write(self.tid.get(0.0, END))
             fid.close()
