@@ -6,17 +6,19 @@ from Bio.SeqUtils.CheckSum import seguid
 from Bio.SeqFeature import ExactPosition, FeatureLocation, SeqFeature
 from Bio.SeqRecord import SeqRecord
 
+
 def checksum_summary(record):
     if isinstance(record.seq, UnknownSeq):
         return repr(record.seq)
     if len(record.seq) < 25:
-        short = record.seq.tostring()
+        short = str(record.seq)
     else:
-        short = record.seq.tostring()[:19] \
-              + "..." + record.seq.tostring()[-3:]
+        short = str(record.seq)[:19] \
+              + "..." + str(record.seq)[-3:]
     return "%s [%s] len %i" \
            % (short, seguid(record.seq), len(record.seq))
 
+
 def compare_reference(old_r, new_r):
     """Compare two Reference objects
 
@@ -38,7 +40,7 @@ def compare_reference(old_r, new_r):
         #it seems that it will get either the MEDLINE or PUBMED,
         #but not both.  I *think* the current schema does not allow
         #us to store both... must confirm this.
-    
+
     #TODO - assert old_r.comment == new_r.comment
     #Looking at the tables, I *think* the current schema does not
     #allow us to store a reference comment.  Must confirm this.
@@ -49,7 +51,7 @@ def compare_reference(old_r, new_r):
     #Looking at the tables, I *think* the current schema does not
     #allow us to store a consortium.
     assert old_r.consrtm == new_r.consrtm or new_r.consrtm == ""
-    
+
     if len(old_r.location) == 0:
         assert len(new_r.location) == 0
     else:
@@ -62,14 +64,15 @@ def compare_reference(old_r, new_r):
 
     return True
 
+
 def compare_feature(old_f, new_f):
     """Compare two SeqFeature objects"""
     assert isinstance(old_f, SeqFeature)
     assert isinstance(new_f, SeqFeature)
 
     assert old_f.type == new_f.type, \
-        "%s -> %s" % (old_f.type, new_f.type) 
-    
+        "%s -> %s" % (old_f.type, new_f.type)
+
     assert old_f.strand == new_f.strand, \
         "%s -> %s" % (old_f.strand, new_f.strand)
 
@@ -79,42 +82,42 @@ def compare_feature(old_f, new_f):
     assert old_f.ref_db == new_f.ref_db, \
         "%s -> %s" % (old_f.ref_db, new_f.ref_db)
 
-    #TODO - BioSQL does not store/retrieve feature's id (Bug 2526)   
+    #TODO - BioSQL does not store/retrieve feature's id (Bug 2526)
     assert old_f.id == new_f.id or new_f.id == "<unknown id>"
 
     #TODO - Work out how the location_qualifier_value table should
     #be used, given BioPerl seems to ignore it (Bug 2766)
     #assert old_f.location_operator == new_f.location_operator, \
     #        "%s -> %s" % (old_f.location_operator, new_f.location_operator)
-    
+
     # We dont store fuzzy locations:
     try:
         assert str(old_f.location) == str(new_f.location), \
            "%s -> %s" % (str(old_f.location), str(new_f.location))
     except AssertionError, e:
         if isinstance(old_f.location.start, ExactPosition) and \
-            isinstance(old_f.location.end, ExactPosition):
-            # Its not a problem with fuzzy locations, re-raise 
+           isinstance(old_f.location.end, ExactPosition):
+            # Its not a problem with fuzzy locations, re-raise
             raise e
         else:
             assert old_f.location.nofuzzy_start == \
                     new_f.location.nofuzzy_start, \
-                    "%s -> %s" % (old_f.location.nofuzzy_start, \
+                    "%s -> %s" % (old_f.location.nofuzzy_start,
                                   new_f.location.nofuzzy_start)
             assert old_f.location.nofuzzy_end == \
                     new_f.location.nofuzzy_end, \
-                    "%s -> %s" % (old_f.location.nofuzzy_end, \
+                    "%s -> %s" % (old_f.location.nofuzzy_end,
                                   new_f.location.nofuzzy_end)
 
     assert len(old_f.sub_features) == len(new_f.sub_features), \
         "number of sub_features: %s -> %s" % \
         (len(old_f.sub_features), len(new_f.sub_features))
-    
+
     for old_sub, new_sub in zip(old_f.sub_features, new_f.sub_features):
-        
+
         assert old_sub.type == new_sub.type, \
             "%s -> %s" % (old_sub.type, new_sub.type)
-        
+
         assert old_sub.strand == new_sub.strand, \
             "%s -> %s" % (old_sub.strand, new_sub.strand)
 
@@ -130,7 +133,7 @@ def compare_feature(old_f, new_f):
         #    "%s -> %s" % (old_sub.location_operator, new_sub.location_operator)
 
         # Compare sub-feature Locations:
-        # 
+        #
         # BioSQL currently does not store fuzzy locations, but instead stores
         # them as FeatureLocation.nofuzzy_start FeatureLocation.nofuzzy_end.
         # The vast majority of cases will be comparisons of ExactPosition
@@ -141,21 +144,21 @@ def compare_feature(old_f, new_f):
                "%s -> %s" % (str(old_sub.location), str(new_sub.location))
         except AssertionError, e:
             if isinstance(old_sub.location.start, ExactPosition) and \
-                isinstance(old_sub.location.end, ExactPosition):
-                # Its not a problem with fuzzy locations, re-raise 
+               isinstance(old_sub.location.end, ExactPosition):
+                # Its not a problem with fuzzy locations, re-raise
                 raise e
             else:
                 #At least one of the locations is fuzzy
                 assert old_sub.location.nofuzzy_start == \
                        new_sub.location.nofuzzy_start, \
-                       "%s -> %s" % (old_sub.location.nofuzzy_start, \
+                       "%s -> %s" % (old_sub.location.nofuzzy_start,
                                      new_sub.location.nofuzzy_start)
                 assert old_sub.location.nofuzzy_end == \
                        new_sub.location.nofuzzy_end, \
-                       "%s -> %s" % (old_sub.location.nofuzzy_end, \
+                       "%s -> %s" % (old_sub.location.nofuzzy_end,
                                      new_sub.location.nofuzzy_end)
 
-    assert len(old_f.qualifiers) == len(new_f.qualifiers)    
+    assert len(old_f.qualifiers) == len(new_f.qualifiers)
     assert set(old_f.qualifiers) == set(new_f.qualifiers)
     for key in old_f.qualifiers:
         if isinstance(old_f.qualifiers[key], str):
@@ -175,10 +178,11 @@ def compare_feature(old_f, new_f):
                 "%s -> %s" % (old_f.qualifiers[key], new_f.qualifiers[key])
     return True
 
+
 def compare_sequence(old, new):
     """Compare two Seq or DBSeq objects"""
     assert len(old) == len(new), "%i vs %i" % (len(old), len(new))
-    assert old.tostring() == new.tostring()
+    assert str(old) == str(new)
 
     if isinstance(old, UnknownSeq):
         assert isinstance(new, UnknownSeq)
@@ -186,7 +190,7 @@ def compare_sequence(old, new):
         assert not isinstance(new, UnknownSeq)
 
     ln = len(old)
-    s = old.tostring()
+    s = str(old)
     assert isinstance(s, str)
 
     #Don't check every single element; for long sequences
@@ -198,43 +202,44 @@ def compare_sequence(old, new):
         #A selection of end cases, and the mid point
         indices = [-ln,-ln+1,-(ln//2),-1,0,1,ln//2,ln-2,ln-1]
 
-    #Test element access,    
+    #Test element access,
     for i in indices:
         expected = s[i]
         assert expected == old[i]
         assert expected == new[i]
 
     #Test slices
-    indices.append(ln) #check copes with overflows
-    indices.append(ln+1000) #check copes with overflows
+    indices.append(ln)  # check copes with overflows
+    indices.append(ln + 1000)  # check copes with overflows
     for i in indices:
         for j in indices:
             expected = s[i:j]
-            assert expected == old[i:j].tostring(), \
+            assert expected == str(old[i:j]), \
                    "Slice %s vs %s" % (repr(expected), repr(old[i:j]))
-            assert expected == new[i:j].tostring(), \
+            assert expected == str(new[i:j]), \
                    "Slice %s vs %s" % (repr(expected), repr(new[i:j]))
             #Slicing with step of 1 should make no difference.
             #Slicing with step 3 might be useful for codons.
             for step in [1,3]:
                 expected = s[i:j:step]
-                assert expected == old[i:j:step].tostring()
-                assert expected == new[i:j:step].tostring()
+                assert expected == str(old[i:j:step])
+                assert expected == str(new[i:j:step])
 
         #Check automatic end points
         expected = s[i:]
-        assert expected == old[i:].tostring()
-        assert expected == new[i:].tostring()
-                
+        assert expected == str(old[i:])
+        assert expected == str(new[i:])
+
         expected = s[:i]
-        assert expected == old[:i].tostring()
-        assert expected == new[:i].tostring()
+        assert expected == str(old[:i])
+        assert expected == str(new[:i])
 
     #Check "copy" splice
-    assert s == old[:].tostring()
-    assert s == new[:].tostring()
+    assert s == str(old[:])
+    assert s == str(new[:])
     return True
 
+
 def compare_features(old_list, new_list):
     assert isinstance(old_list, list)
     assert isinstance(new_list, list)
@@ -243,7 +248,8 @@ def compare_features(old_list, new_list):
         if not compare_feature(old_f, new_f):
             return False
     return True
-        
+
+
 def compare_record(old, new):
     """Compare two SeqRecord or DBSeqRecord objects"""
     assert isinstance(old, SeqRecord)
@@ -267,7 +273,7 @@ def compare_record(old, new):
     #'ncbi_taxon' and 'gi'.
     #TODO - address these, see Bug 2681?
     new_keys = set(new.annotations).difference(old.annotations)
-    new_keys = new_keys.difference(['cross_references', 'date', 
+    new_keys = new_keys.difference(['cross_references', 'date',
                                     'data_file_division', 'ncbi_taxid', 'gi'])
     assert not new_keys, "Unexpected new annotation keys: %s" \
            % ", ".join(new_keys)
@@ -276,7 +282,7 @@ def compare_record(old, new):
                                             ])
     assert not missing_keys, "Unexpectedly missing annotation keys: %s" \
            % ", ".join(missing_keys)
-    
+
     #In the short term, just compare any shared keys:
     for key in set(old.annotations).intersection(new.annotations):
         if key == "references":
@@ -325,6 +331,7 @@ def compare_record(old, new):
                 % (key, old.annotations[key], new.annotations[key])
     return True
 
+
 def compare_records(old_list, new_list):
     assert isinstance(old_list, list)
     assert isinstance(new_list, list)
