@@ -6,11 +6,11 @@
 # python unittest framework
 import unittest
 import copy
-import sys
 
 # modules to be tested
 from Bio.Crystal import Hetero, Chain, Crystal, CrystalError
 
+
 class ChainTestCase(unittest.TestCase):
 
     def setUp(self):
@@ -52,7 +52,6 @@ class ChainTestCase(unittest.TestCase):
         second = Chain(self.f)
         self.assertNotEqual(first, second)
 
-
     def testLen(self):
         chain = Chain(self.a)
         elements = self.a.strip().split()
@@ -69,7 +68,6 @@ class ChainTestCase(unittest.TestCase):
         num_elements = len(elements)
         self.assertEqual(len(chain), num_elements)
 
-
     def testAppend(self):
         chain = Chain(self.a[:])
         chain.append('U')
@@ -111,7 +109,6 @@ class ChainTestCase(unittest.TestCase):
         self.assertEqual('ser', last_element.data)
         self.assertEqual(len(chain), num_elements + 1)
 
-
     def testInsert(self):
         chain = Chain(self.a[:])
         i = 4
@@ -149,7 +146,6 @@ class ChainTestCase(unittest.TestCase):
         self.assertEqual('gln', target_element.data)
         self.assertEqual(len(chain), num_elements + 1)
 
-
     def testRemove(self):
 
         chain = Chain(self.a[:])
@@ -179,7 +175,6 @@ class ChainTestCase(unittest.TestCase):
         self.assertEqual(num_leu_remaining, num_leu - 1)
         self.assertEqual(len(chain), num_elements - 1)
 
-
     def testCount(self):
         chain = Chain(self.a[:])
         num_a = chain.data.count(Hetero('a'))
@@ -197,7 +192,6 @@ class ChainTestCase(unittest.TestCase):
         num_a = chain.data.count(Hetero('cys'))
         self.assertEqual(chain.count('cys'), num_a)
 
-
     def testIndex(self):
         chain = Chain(self.a[:])
         index_g = chain.data.index(Hetero('g'))
@@ -313,7 +307,6 @@ class ChainTestCase(unittest.TestCase):
         other = chain.data[:]
         self.assertEqual(slice.data, other)
 
-
         chain = Chain(self.a[:] )
         first = 0
         last = 4
@@ -348,7 +341,6 @@ class ChainTestCase(unittest.TestCase):
         other = chain.data[ first: last ]
         self.assertEqual(slice.data, other)
 
-
     def testSetSlice(self):
         chain = Chain(self.a[:] )
         slice = 'G T C A G 5NC G C A T G G'
@@ -356,7 +348,6 @@ class ChainTestCase(unittest.TestCase):
         other = Chain(slice[ 4: 7 ] )
         self.assertEqual(chain, other)
 
-
         chain = Chain(self.c[:] )
         old_chain = Chain(self.c[ : ])
         slice = 'MET ILE GLU ILE LYS ASP'
@@ -397,7 +388,6 @@ class ChainTestCase(unittest.TestCase):
         other = Chain(old_chain.data[ :9 ])
         self.assertEqual(chain, other)
 
-
     def testContains(self):
         chain = Chain(self.c[ : ])
         self.assertFalse('ser' in chain)
@@ -424,15 +414,13 @@ class ChainTestCase(unittest.TestCase):
         self.assertEqual(targete, targetb)
 
 
-
-
 class CrystalTestCase(unittest.TestCase):
 
     def setUp(self):
 
-        self.crystal = Crystal({ 'a' : 'T T G A C T C T C T T A A', \
-                             'b' : Chain('G A G A G T C A'), \
-                             'c' : 'T T G A C T C T C T T A A', \
+        self.crystal = Crystal({ 'a' : 'T T G A C T C T C T T A A',
+                             'b' : Chain('G A G A G T C A'),
+                             'c' : 'T T G A C T C T C T T A A',
                              'd' : Chain('G A G A G T C A')
                             })
 
@@ -517,4 +505,3 @@ class HeteroTestCase(unittest.TestCase):
 if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity = 2)
     unittest.main(testRunner=runner)
-
