@@ -6,7 +6,6 @@
 import os
 import sys
 import unittest
-import subprocess
 
 from Bio import MissingExternalDependencyError
 from Bio import AlignIO
@@ -22,7 +21,7 @@ os.environ['LANG'] = 'C'
 
 exes_wanted = ['fdnadist', 'fneighbor', 'fprotdist','fprotpars','fconsense',
                'fseqboot', 'ftreedist', 'fdnapars']
-exes = dict() #Dictionary mapping from names to exe locations
+exes = dict()  # Dictionary mapping from names to exe locations
 
 if "EMBOSS_ROOT" in os.environ:
     #Windows default installation path is C:\mEMBOSS which contains the exes.
@@ -44,29 +43,33 @@ if sys.platform!="win32":
     del name
 
 if len(exes) < len(exes_wanted):
-    raise MissingExternalDependencyError(\
-          "Install the Emboss package 'PhylipNew' if you want to use the "+\
+    raise MissingExternalDependencyError(
+          "Install the Emboss package 'PhylipNew' if you want to use the "+
           "Bio.Emboss.Applications wrappers for phylogenetic tools.")
 
  ###########################################################################
 
+
 # A few top level functions that are called repeatedly in the test cases
 def write_AlignIO_dna():
     """Convert opuntia.aln to a phylip file"""
     assert 1 == AlignIO.convert("Clustalw/opuntia.aln", "clustal",
                                 "Phylip/opuntia.phy", "phylip")
 
+
 def write_AlignIO_protein():
     """Convert hedgehog.aln to a phylip file"""
     assert 1 == AlignIO.convert("Clustalw/hedgehog.aln", "clustal",
                                 "Phylip/hedgehog.phy", "phylip")
 
+
 def clean_up():
     """Delete tests files (to be used as tearDown() function in test fixtures)"""
     for filename in ["test_file", "Phylip/opuntia.phy","Phylip/hedgehog.phy"]:
         if os.path.isfile(filename):
             os.remove(filename)
 
+
 def parse_trees(filename):
     """Helper function until we have Bio.Phylo on trunk."""
     data = open("test_file", "r").read()
@@ -74,6 +77,7 @@ def parse_trees(filename):
         if tree_str:
             yield Trees.Tree(tree_str+";")
 
+
 class DistanceTests(unittest.TestCase):
     """Tests for calculating distance based phylogenetic trees with phylip"""
 
@@ -83,12 +87,12 @@ class DistanceTests(unittest.TestCase):
     test_taxa = ['Archaeohip', 'Calippus', 'Hypohippus', 'M._secundu',
                  'Merychippu', 'Mesohippus', 'Nannipus', 'Neohippari',
                  'Parahippus', 'Pliohippus']
-    
+
     def distances_from_alignment(self, filename, DNA = True):
         """check we can make distance matrix from a given alignment"""
         self.assertTrue(os.path.isfile(filename), "Missing %s" % filename)
         if DNA:
-            cline =  FDNADistCommandline(exes["fdnadist"],
+            cline = FDNADistCommandline(exes["fdnadist"],
                                          method = 'j',
                                          sequence= filename,
                                          outfile = "test_file",
@@ -102,7 +106,7 @@ class DistanceTests(unittest.TestCase):
         stdout, strerr = cline()
         #biopython can't grok distance matrices, so we'll just check it exists
         self.assertTrue(os.path.isfile("test_file"))
-    
+
     def tree_from_distances(self, filename):
         """Check we can estimate a tree from a distance matrix"""
         self.assertTrue(os.path.isfile(filename), "Missing %s" % filename)
@@ -152,6 +156,7 @@ class DistanceTests(unittest.TestCase):
     #    """Estimate tree from bootstrapped distance matrix and parse it"""
     #    self.tree_from_distances("Phylip/bs_horses.fdnadist")
 
+
 class ParsimonyTests(unittest.TestCase):
     """Tests for estimating parsimony based phylogenetic trees with phylip"""
 
@@ -177,7 +182,7 @@ class ParsimonyTests(unittest.TestCase):
         for tree in parse_trees("test_file"):
             t_taxa = [t.replace(" ", "_") for t in tree.get_taxa()]
             self.assertEqual(sorted(a_taxa), sorted(t_taxa))
-    
+
     # fdnapars tests
     #def test_parsimony_tree_from_phylip_DNA(self):
     #    """Make a parsimony tree from a phylip DNA alignment"""
@@ -206,22 +211,23 @@ class ParsimonyTests(unittest.TestCase):
     #    """Make a parsimony tree from a phylip DNA alignment"""
     #    self.parsimony_tree("Phylip/bs_interlaced.phy", "phylip", DNA=False)
 
+
 class BootstrapTests(unittest.TestCase):
     """Tests for pseudosampling alignments with fseqboot"""
 
     def tearDown(self):
         clean_up()
-     
+
     def check_bootstrap(self, filename, format, align_type="d"):
         """Check we can use fseqboot to pseudosample an alignment
-        
+
         The align_type type argument is passed to the commandline object to
         set the output format to use (from [D]na,[p]rotein and [r]na )
         """
         self.assertTrue(os.path.isfile(filename), "Missing %s" % filename)
         cline = FSeqBootCommandline(exes["fseqboot"],
                                     sequence = filename,
-                                    outfile =  "test_file",
+                                    outfile = "test_file",
                                     seqtype = align_type,
                                     reps = 2,
                                     auto = True, filter = True)
@@ -254,6 +260,7 @@ class BootstrapTests(unittest.TestCase):
         write_AlignIO_protein()
         self.check_bootstrap("Phylip/hedgehog.phy", "phylip", "p")
 
+
 class TreeComparisonTests(unittest.TestCase):
     """Tests for comparing phylogenetic trees with phylip tools"""
 
