@@ -24,6 +24,15 @@ except ImportError:
     raise MissingPythonDependencyError(
             "Install reportlab if you want to use Bio.Graphics.")
 
+try:
+    import Image
+    from reportlab.graphics import renderPM
+except ImportError:
+    #This is an optional part of ReportLab, so may not be installed.
+    #We'll raise a missing dependency error if rendering to a
+    #bitmap format is attempted.
+    renderPM=None
+
 # Biopython core
 from Bio import SeqIO
 from Bio.SeqFeature import SeqFeature, FeatureLocation
@@ -38,6 +47,7 @@ from Bio.Graphics.GenomeDiagram import CrossLink
 from Bio.Graphics.GenomeDiagram._Graph import GraphData
 from Bio.Graphics.GenomeDiagram._Colors import ColorTranslator
 
+
 def fill_and_border(base_color, alpha=0.5):
     try:
         c = base_color.clone()
@@ -51,6 +61,8 @@ def fill_and_border(base_color, alpha=0.5):
 # Utility functions for graph plotting, originally in GenomeDiagram.Utilities #
 # See Bug 2705 for discussion on where to put these functions in Biopython... #
 ###############################################################################
+
+
 def apply_to_window(sequence, window_size, function, step=None):
     """ apply_to_window(sequence, window_size, function) -> [(int, float),(int, float),...]
 
@@ -99,12 +111,13 @@ def apply_to_window(sequence, window_size, function, step=None):
         # Apply function to sequence fragment
         value = function(fragment)
         results.append((middle, value)) # Add results to list
-        
+
     # Check on last sequence
     #print fragment
     #print seq[-100:]
     return results      # Return the list of (position, value) results
 
+
 def calc_gc_content(sequence):
     """ calc_gc_content(sequence)
 
@@ -117,7 +130,8 @@ def calc_gc_content(sequence):
         d[nt] = sequence.count(nt) + sequence.count(nt.lower())
     gc = d.get('G',0) + d.get('C',0)
 
-    if gc == 0: return 0
+    if gc == 0:
+        return 0
     #print gc*100.0/(d['A'] +d['T'] + gc)
     return gc*1./(d['A'] +d['T'] + gc)
 
@@ -134,7 +148,8 @@ def calc_at_content(sequence):
         d[nt] = sequence.count(nt) + sequence.count(nt.lower())
     at = d.get('A',0) + d.get('T',0)
 
-    if at == 0: return 0
+    if at == 0:
+        return 0
     return at*1./(d['G'] +d['G'] + at)
 
 
@@ -148,7 +163,7 @@ def calc_gc_skew(sequence):
     g = sequence.count('G') + sequence.count('g')
     c = sequence.count('C') + sequence.count('c')
     if g+c == 0:
-        return 0.0 #TODO - return NaN or None here?
+        return 0.0  # TODO - return NaN or None here?
     else:
         return (g-c)/float(g+c)
 
@@ -163,10 +178,11 @@ def calc_at_skew(sequence):
     a = sequence.count('A') + sequence.count('a')
     t = sequence.count('T') + sequence.count('t')
     if a+t == 0:
-        return 0.0 #TODO - return NaN or None here?
+        return 0.0  # TODO - return NaN or None here?
     else:
         return (a-t)/float(a+t)
 
+
 def calc_dinucleotide_counts(sequence):
     """Returns the total count of di-nucleotides repeats (e.g. "AA", "CC").
 
@@ -180,34 +196,35 @@ def calc_dinucleotide_counts(sequence):
     for letter in "ACTGUactgu":
         total += sequence.count(letter+letter)
     return total
-    
 
 ###############################################################################
 # End of utility functions for graph plotting                                 #
 ###############################################################################
 
+
 # Tests
 class TrackTest(unittest.TestCase):
     # TODO Bring code from Track.py, unsure about what test does
     pass
 
+
 class ColorsTest(unittest.TestCase):
     def test_color_conversions(self):
         """Test color translations.
         """
         translator = ColorTranslator()
-        
+
         # Does the translate method correctly convert the passed argument?
         assert translator.float1_color((0.5, 0.5, 0.5)) == translator.translate((0.5, 0.5, 0.5)), \
             "Did not correctly translate colour from floating point RGB tuple"
         assert translator.int255_color((1, 75, 240)) == translator.translate((1, 75, 240)), \
             "Did not correctly translate colour from integer RGB tuple"
         assert translator.artemis_color(7) == translator.translate(7), \
-            "Did not correctly translate colour from Artemis colour scheme"                        
+            "Did not correctly translate colour from Artemis colour scheme"
         assert translator.scheme_color(2) == translator.translate(2), \
             "Did not correctly translate colour from user-defined colour scheme"
 
-            
+
 class GraphTest(unittest.TestCase):
     def test_limits(self):
         """Check line graphs."""
@@ -217,7 +234,7 @@ class GraphTest(unittest.TestCase):
         data1 = [math.sin(x*scale) for x in range(points)]
         data2 = [math.cos(x*scale) for x in range(points)]
         data3 = [2*math.sin(2*x*scale) for x in range(points)]
-        
+
         gdd = Diagram('Test Diagram', circular=False,
                       y=0.01, yt=0.01, yb=0.01,
                       x=0.01, xl=0.01, xr=0.01)
@@ -240,16 +257,16 @@ class GraphTest(unittest.TestCase):
         #Circular diagram
         gdd.draw(tracklines=False,
                  pagesize=(15*cm,15*cm),
-                 circular=True, #Data designed to be periodic
+                 circular=True,  # Data designed to be periodic
                  start=0, end=points, circle_core=0.5)
         gdd.write(os.path.join('Graphics', "line_graph_c.pdf"), "pdf")
-        
+
     def test_slicing(self):
         """Check GraphData slicing."""
         gd = GraphData()
         gd.set_data([(1, 10), (5, 15), (20, 40)])
         gd.add_point((10, 20))
-        
+
         assert gd[4:16] == [(5, 15), (10, 20)], \
                 "Unable to insert and retrieve points correctly"
 
@@ -276,8 +293,20 @@ class LabelTest(unittest.TestCase):
                       fragments=1,
                       start=0, end=400)
         self.gdd.write(os.path.join('Graphics', name+".pdf"), "pdf")
-        #For the tutorial this might be useful:
-        #self.gdd.write(os.path.join('Graphics', name+".png"), "png")
+        global renderPM
+        if renderPM:
+            try:
+                #For the tutorial this is useful:
+                self.gdd.write(os.path.join('Graphics', name+".png"), "png")
+            except renderPM.RenderPMError:
+                #Probably a font problem, e.g.
+                #RenderPMError: Can't setFont(Times-Roman) missing the T1 files?
+                #Originally <type 'exceptions.TypeError'>: makeT1Font() argument 2 must be string, not None
+                renderPM = None
+            except IOError:
+                #Probably a library problem, e.g.
+                #IOError: encoder zip not available
+                renderPM = None
         if circular:
             #Circular diagram
             self.gdd.draw(tracklines=False,
@@ -286,7 +315,7 @@ class LabelTest(unittest.TestCase):
                           circle_core=0.5,
                           start=0, end=400)
             self.gdd.write(os.path.join('Graphics', name+"_c.pdf"), "pdf")
-    
+
     def add_track_with_sigils(self, **kwargs):
         self.gdt_features = self.gdd.new_track(1, greytrack=False)
         self.gds_features = self.gdt_features.new_set()
@@ -314,6 +343,7 @@ class LabelTest(unittest.TestCase):
         self.add_track_with_sigils()
         self.finish("labels_default")
 
+
 class SigilsTest(unittest.TestCase):
     """Check the different feature sigils.
 
@@ -323,9 +353,12 @@ class SigilsTest(unittest.TestCase):
                            y=0.01, yt=0.01, yb=0.01,
                            x=0.01, xl=0.01, xr=0.01)
 
-    def add_track_with_sigils(self, **kwargs):
+    def add_track_with_sigils(self, track_caption="", **kwargs):
         #Add a track of features,
-        self.gdt_features = self.gdd.new_track(1, greytrack=False)
+        self.gdt_features = self.gdd.new_track(1,
+                                               greytrack=(track_caption!=""),
+                                               name=track_caption,
+                                               greytrack_labels=1)
         #We'll just use one feature set for these features,
         self.gds_features = self.gdt_features.new_set()
         #Add three features to show the strand options,
@@ -351,8 +384,14 @@ class SigilsTest(unittest.TestCase):
                       fragments=1,
                       start=0, end=400)
         self.gdd.write(os.path.join('Graphics', name+".pdf"), "pdf")
-        #For the tutorial this might be useful:
-        #self.gdd.write(os.path.join('Graphics', name+".png"), "png")
+        global renderPM
+        if renderPM:
+            #For the tutorial this might be useful:
+            try:
+                self.gdd.write(os.path.join('Graphics', name+".png"), "png")
+            except renderPM.RenderPMError:
+                #Probably a font problem
+                renderPM = None
         if circular:
             #Circular diagram
             self.gdd.draw(tracklines=False,
@@ -362,6 +401,13 @@ class SigilsTest(unittest.TestCase):
                           start=0, end=400)
             self.gdd.write(os.path.join('Graphics', name+"_c.pdf"), "pdf")
 
+    def test_all_sigils(self):
+        """All sigils."""
+        for glyph in ["BOX", "OCTO", "JAGGY", "ARROW", "BIGARROW"]:
+            self.add_track_with_sigils(track_caption = '  sigil="%s"' % glyph,
+                                       sigil=glyph)
+        self.finish("GD_sigils")
+
     def test_labels(self):
         """Feature labels."""
         self.add_track_with_sigils(label=True)
@@ -386,7 +432,19 @@ class SigilsTest(unittest.TestCase):
         self.add_track_with_sigils(sigil="ARROW", color="darkgreen",
                                    arrowshaft_height=0.1)
         self.assertEqual(len(self.gdd.tracks), 4)
-        self.finish("GD_sigil_arrow_shafts")        
+        self.finish("GD_sigil_arrow_shafts")
+
+    def test_big_arrow_shafts(self):
+        """Feature big-arrow sigils, varying shafts."""
+        self.add_track_with_sigils(sigil="BIGARROW")
+        self.add_track_with_sigils(sigil="BIGARROW", color="orange",
+                                   arrowshaft_height=1.0)
+        self.add_track_with_sigils(sigil="BIGARROW", color="teal",
+                                   arrowshaft_height=0.2)
+        self.add_track_with_sigils(sigil="BIGARROW", color="green",
+                                   arrowshaft_height=0.1)
+        self.assertEqual(len(self.gdd.tracks), 4)
+        self.finish("GD_sigil_bigarrow_shafts")
 
     def test_arrow_heads(self):
         """Feature arrow sigils, varying heads."""
@@ -396,7 +454,7 @@ class SigilsTest(unittest.TestCase):
         self.add_track_with_sigils(sigil="ARROW", color="orange",
                                    arrowhead_length=1)
         self.add_track_with_sigils(sigil="ARROW", color="red",
-                                   arrowhead_length=10000) #Triangles
+                                   arrowhead_length=10000)  # Triangles
         self.assertEqual(len(self.gdd.tracks), 4)
         self.finish("GD_sigil_arrows")
 
@@ -445,19 +503,34 @@ class SigilsTest(unittest.TestCase):
                                       arrowhead_length=0.05)
         self.finish("GD_sigil_arrows_small")
 
-    def test_long_arrow_heads(self):
-        """Feature arrow sigil heads within bounding box."""
+    def long_sigils(self, glyph):
+        """Check feature sigils within bounding box."""
         #Add a track of features, bigger height to emphasise any sigil errors
         self.gdt_features = self.gdd.new_track(1, greytrack=True, height=3)
-        #We'll just use one feature set for these features,
+        #We'll just use one feature set for these features if strand specific
         self.gds_features = self.gdt_features.new_set()
-        feature = SeqFeature(FeatureLocation(25, 375), strand=+1)
-        self.gds_features.add_feature(feature, color="lightblue")
-        self.gds_features.add_feature(feature, name="Forward", sigil="ARROW",
+        if glyph in ["BIGARROW"]:
+            #These straddle the axis, so don't want to draw them on top of each other
+            feature = SeqFeature(FeatureLocation(25, 375), strand=None)
+            self.gds_features.add_feature(feature, color="lightblue")
+            feature = SeqFeature(FeatureLocation(25, 375), strand=+1)
+        else:
+            feature = SeqFeature(FeatureLocation(25, 375), strand=+1)
+            self.gds_features.add_feature(feature, color="lightblue")
+        self.gds_features.add_feature(feature, name="Forward", sigil=glyph,
                                       color="blue", arrowhead_length=2.0)
-        feature = SeqFeature(FeatureLocation(25, 375), strand=-1)
-        self.gds_features.add_feature(feature, color="pink")
-        self.gds_features.add_feature(feature, name="Reverse", sigil="ARROW",
+
+        if glyph in ["BIGARROW"]:
+            #These straddle the axis, so don't want to draw them on top of each other
+            self.gdt_features = self.gdd.new_track(1, greytrack=True, height=3)
+            self.gds_features = self.gdt_features.new_set()
+            feature = SeqFeature(FeatureLocation(25, 375), strand=None)
+            self.gds_features.add_feature(feature, color="pink")
+            feature = SeqFeature(FeatureLocation(25, 375), strand=-1)
+        else:
+            feature = SeqFeature(FeatureLocation(25, 375), strand=-1)
+            self.gds_features.add_feature(feature, color="pink")
+        self.gds_features.add_feature(feature, name="Reverse", sigil=glyph,
                                       color="red", arrowhead_length=2.0)
         #Add another track of features, bigger height to emphasise any sigil errors
         self.gdt_features = self.gdd.new_track(1, greytrack=True, height=3)
@@ -465,9 +538,26 @@ class SigilsTest(unittest.TestCase):
         self.gds_features = self.gdt_features.new_set()
         feature = SeqFeature(FeatureLocation(25, 375), strand=None)
         self.gds_features.add_feature(feature, color="lightgreen")
-        self.gds_features.add_feature(feature, name="Standless", sigil="ARROW",
+        self.gds_features.add_feature(feature, name="Standless", sigil=glyph,
                                       color="green", arrowhead_length=2.0)
-        self.finish("GD_sigil_arrows_long")
+        self.finish("GD_sigil_long_%s" % glyph)
+
+    def test_long_arrow_heads(self):
+        """Feature ARROW sigil heads within bounding box."""
+        self.long_sigils("ARROW")
+
+    def test_long_arrow_heads(self):
+        """Feature ARROW sigil heads within bounding box."""
+        self.long_sigils("BIGARROW")
+
+    def test_long_octo_heads(self):
+        """Feature OCTO sigil heads within bounding box."""
+        self.long_sigils("OCTO")
+
+    def test_long_jaggy(self):
+        """Feature JAGGY sigil heads within bounding box."""
+        self.long_sigils("JAGGY")
+
 
 class DiagramTest(unittest.TestCase):
     """Creating feature sets, graph sets, tracks etc individually for the diagram."""
@@ -480,7 +570,7 @@ class DiagramTest(unittest.TestCase):
     def test_write_arguments(self):
         """Check how the write methods respond to output format arguments."""
         gdd = Diagram('Test Diagram')
-        gdd.drawing = None #Hack - need the ReportLab drawing object to be created.
+        gdd.drawing = None  # Hack - need the ReportLab drawing object to be created.
         filename = os.path.join("Graphics","error.txt")
         #We (now) allow valid formats in any case.
         for output in ["XXX","xxx",None,123,5.9]:
@@ -504,7 +594,7 @@ class DiagramTest(unittest.TestCase):
         genbank_entry = self.record
         start = 6500
         end = 8750
-        
+
         gdd = Diagram('Test Diagram',
                       #For the circular diagram we don't want a closed cirle:
                       circular=False,
@@ -537,11 +627,11 @@ class DiagramTest(unittest.TestCase):
                       "?db=protein&id=%s" % feature.qualifiers["protein_id"][0]
             except KeyError :
                 url = None
-                
+
             #Note that I am using strings for color names, instead
             #of passing in color objects.  This should also work!
             if len(gds_features) % 2 == 0:
-                color = "white" #for testing the automatic black border!
+                color = "white"  # for testing the automatic black border!
             else:
                 color = "red"
             #Checking it can cope with the old UK spelling colour.
@@ -613,8 +703,9 @@ class DiagramTest(unittest.TestCase):
                                   ("GGATCC","BamHI","purple")]:
             index = 0
             while True:
-                index  = genbank_entry.seq.find(site, start=index)
-                if index == -1 : break
+                index = genbank_entry.seq.find(site, start=index)
+                if index == -1:
+                    break
                 feature = SeqFeature(FeatureLocation(index, index+6), strand=None)
 
                 #This URL should work in SVG output from recent versions
@@ -644,14 +735,14 @@ class DiagramTest(unittest.TestCase):
 
         step = len(genbank_entry)//200
         gds_at_gc.new_graph(apply_to_window(genbank_entry.seq, step, calc_gc_content, step),
-                        'GC content', style='line', 
+                        'GC content', style='line',
                         color=colors.lightgreen,
                         altcolor=colors.darkseagreen)
         gds_at_gc.new_graph(apply_to_window(genbank_entry.seq, step, calc_at_content, step),
-                        'AT content', style='line', 
+                        'AT content', style='line',
                         color=colors.orange,
                         altcolor=colors.red)
-        
+
         #Finally draw it in both formats,
         gdd.draw(format='linear', orientation='landscape',
              tracklines=0, pagesize='A4', fragments=3)
@@ -681,7 +772,6 @@ class DiagramTest(unittest.TestCase):
         gdfsA = FeatureSet(name='CDS backgrounds')
         gdfsB = FeatureSet(name='gene background')
 
-
         gdfs1 = FeatureSet(name='CDS features')
         gdfs2 = FeatureSet(name='gene features')
         gdfs3 = FeatureSet(name='misc_features')
@@ -755,7 +845,6 @@ class DiagramTest(unittest.TestCase):
         b = gdfsB.add_feature(SeqFeature(FeatureLocation(6275,6375)), color=f, border=c)
         gdd.cross_track_links.append(CrossLink(a, b, color=f, border=c, flip=True))
 
-
         cds_count = 0
         for feature in genbank_entry.features:
             if feature.type == 'CDS':
@@ -788,12 +877,12 @@ class DiagramTest(unittest.TestCase):
         #gdfs1.set_all_features('color', colors.red)
         gdfs2.set_all_features('color', colors.blue)
 
-        gdt1.add_set(gdfsA) #Before CDS so under them!
+        gdt1.add_set(gdfsA)  # Before CDS so under them!
         gdt1.add_set(gdfs1)
 
-        gdt2.add_set(gdfsB) #Before genes so under them!
+        gdt2.add_set(gdfsB)  # Before genes so under them!
         gdt2.add_set(gdfs2)
-                
+
         gdt3 = Track('misc features and repeats', greytrack=1,
                    scale_largetick_interval=1e4)
         gdt3.add_set(gdfs3)
@@ -805,52 +894,51 @@ class DiagramTest(unittest.TestCase):
         #between the bar and line graphs.
         step = len(genbank_entry)//200
         gdgs1 = GraphSet('GC skew')
-        
+
         graphdata1 = apply_to_window(genbank_entry.seq, step, calc_gc_skew, step)
         gdgs1.new_graph(graphdata1, 'GC Skew', style='bar',
                 color=colors.violet,
                 altcolor=colors.purple)
-        
-        gdt4 = Track(\
+
+        gdt4 = Track(
                 'GC Skew (bar)',
                 height=1.94, greytrack=1,
                 scale_largetick_interval=1e4)
         gdt4.add_set(gdgs1)
 
-
         gdgs2 = GraphSet('GC and AT Content')
         gdgs2.new_graph(apply_to_window(genbank_entry.seq, step, calc_gc_content, step),
-                        'GC content', style='line', 
+                        'GC content', style='line',
                         color=colors.lightgreen,
                         altcolor=colors.darkseagreen)
 
         gdgs2.new_graph(apply_to_window(genbank_entry.seq, step, calc_at_content, step),
-                        'AT content', style='line', 
+                        'AT content', style='line',
                         color=colors.orange,
-                        altcolor=colors.red)    
+                        altcolor=colors.red)
 
-        gdt5 = Track(\
+        gdt5 = Track(
                 'GC Content(green line), AT Content(red line)',
                 height=1.94, greytrack=1,
                 scale_largetick_interval=1e4)
         gdt5.add_set(gdgs2)
 
         gdgs3 = GraphSet('Di-nucleotide count')
-        step = len(genbank_entry)//400 #smaller step
+        step = len(genbank_entry) // 400  # smaller step
         gdgs3.new_graph(apply_to_window(genbank_entry.seq, step, calc_dinucleotide_counts, step),
-                        'Di-nucleotide count', style='heat', 
+                        'Di-nucleotide count', style='heat',
                         color=colors.red, altcolor=colors.orange)
         gdt6 = Track('Di-nucleotide count', height=0.5, greytrack=False, scale=False)
         gdt6.add_set(gdgs3)
 
         #Add the tracks (from both features and graphs)
         #Leave some white space in the middle/bottom
-        gdd.add_track(gdt4, 3) # GC skew
-        gdd.add_track(gdt5, 4) # GC and AT content
-        gdd.add_track(gdt1, 5) # CDS features
-        gdd.add_track(gdt2, 6) # Gene features
-        gdd.add_track(gdt3, 7) # Misc features and repeat feature
-        gdd.add_track(gdt6, 8) # Feature depth
+        gdd.add_track(gdt4, 3)  # GC skew
+        gdd.add_track(gdt5, 4)  # GC and AT content
+        gdd.add_track(gdt1, 5)  # CDS features
+        gdd.add_track(gdt2, 6)  # Gene features
+        gdd.add_track(gdt3, 7)  # Misc features and repeat feature
+        gdd.add_track(gdt6, 8)  # Feature depth
 
         #Finally draw it in both formats, and full view and partial
         gdd.draw(format='circular', orientation='landscape',
