@@ -4,10 +4,10 @@
 
 try:
     from numpy import array
-    from numpy import random #missing in PyPy's micronumpy
+    from numpy import random  # missing in PyPy's micronumpy
 except ImportError:
     from Bio import MissingPythonDependencyError
-    raise MissingPythonDependencyError(\
+    raise MissingPythonDependencyError(
         "Install NumPy if you want to use Bio.MarkovModel.")
 
 import unittest
