@@ -127,9 +127,10 @@ class PatternIOTest(unittest.TestCase):
                "Got back unexpected signatures %s, wanted %s" \
                % (read_sigs, signatures)
 
+
 class PatternRepositoryTest(unittest.TestCase):
     """Tests for retrieving info from a repository of patterns.
-    """ 
+    """
     def setUp(self):
         self.motifs = {"GATC" : 30,
                        "GGGG" : 10,
@@ -171,7 +172,7 @@ class PatternRepositoryTest(unittest.TestCase):
 
             for pattern in patterns:
                 assert pattern in self.motifs.keys(), \
-                       "Got unexpected pattern %s" % pattern      
+                       "Got unexpected pattern %s" % pattern
 
     def test_get_top(self):
         """Retrieve a certain number of the top patterns.
@@ -184,7 +185,7 @@ class PatternRepositoryTest(unittest.TestCase):
 
             for pattern in patterns:
                 assert pattern in self.motifs.keys(), \
-                       "Got unexpected pattern %s" % pattern       
+                       "Got unexpected pattern %s" % pattern
 
     def test_get_differing(self):
         """Retrieve patterns from both sides of the list (top and bottom).
@@ -200,7 +201,7 @@ class PatternRepositoryTest(unittest.TestCase):
         assert len(patterns) == 5, "Unexpected starting: %s" % patterns
 
         self.repository.remove_polyA()
-        
+
         patterns = self.repository.get_all()
         assert len(patterns) == 3, "Unexpected ending: %s" % patterns
         assert patterns == ["GATC", "GGGG", "GTAG"], \
@@ -217,6 +218,7 @@ class PatternRepositoryTest(unittest.TestCase):
         assert num_times == 0, \
                "Counted items not in repository: %s" % num_times
 
+
 # --- Tests for motifs
 
 class MotifFinderTest(unittest.TestCase):
@@ -272,6 +274,7 @@ class MotifFinderTest(unittest.TestCase):
         assert top == "TTGGAAAG", "Got unexpected top motif %s" % top
         assert bottom == "AATGGCAT", "Got unexpected bottom motif %s" % bottom
 
+
 class MotifCoderTest(unittest.TestCase):
     """Test the ability to encode sequences as a set of motifs.
     """
@@ -280,10 +283,9 @@ class MotifCoderTest(unittest.TestCase):
 
         self.match_strings = (("GATCGCC", [0.0, 1.0, 1.0, 0.0]),
                               ("GATGATCGAGCC", [.5, 1.0, .5, 0.0]))
-        
+
         self.coder = Motif.MotifCoder(motifs)
 
-        
     def test_representation(self):
         """Convert a sequence into its motif representation.
         """
@@ -295,6 +297,7 @@ class MotifCoderTest(unittest.TestCase):
                    "Did not match representation, expected %s, got %s" \
                    % (expected, matches)
 
+
 # --- Tests for schemas
 
 class SchemaTest(unittest.TestCase):
@@ -348,7 +351,7 @@ class SchemaTest(unittest.TestCase):
             assert found_positions == expected, \
                    "Expected %s, got %s for %s" % (expected, found_positions,
                                                    motif)
-        
+
     def test_num_ambiguous(self):
         """Find the number of ambiguous items in a sequence.
         """
@@ -369,8 +372,8 @@ class SchemaTest(unittest.TestCase):
 
         self.motif_coder.find_matches(test_motif, "GATCGATC")
 
-        assert self.motif_coder._motif_cache.has_key(test_motif), \
-               "Did not find motif cached properly."
+        self.assertTrue(test_motif in self.motif_coder._motif_cache,
+                     "Did not find motif cached properly.")
 
         # make sure we don't bomb out if we use the same motif twice
         self.motif_coder.find_matches(test_motif, "GATCGATC")
@@ -384,6 +387,7 @@ class SchemaTest(unittest.TestCase):
         assert found_unambig == expected, \
                "Got %s, expected %s" % (found_unambig, expected)
 
+
 class SchemaFinderTest(unittest.TestCase):
     """Test finding schemas from a set of sequences.
     """
@@ -429,7 +433,8 @@ class SchemaFinderTest(unittest.TestCase):
             schemas = repository.get_all()
 
             assert len(schemas) >= self.num_schemas, "Got too few schemas."
-        
+
+
 class SchemaCoderTest(unittest.TestCase):
     """Test encoding sequences as a grouping of motifs.
     """
@@ -459,13 +464,14 @@ class SchemaCoderTest(unittest.TestCase):
             found_rep = self.motif_coder.representation(match_seq)
             assert found_rep == expected, "Got %s, expected %s" % \
                    (found_rep, expected)
-    
+
+
 class SchemaMatchingTest(unittest.TestCase):
     """Matching schema to strings works correctly.
     """
     def shortDescription(self):
         return "%s:%s" % (self.__class__.__name__, self.__doc__)
-    
+
     def runTest(self):
         match = Schema.matches_schema("GATC", "AAAAA")
         assert match == 0, "Expected no match because of length differences"
@@ -482,6 +488,7 @@ class SchemaMatchingTest(unittest.TestCase):
         match = Schema.matches_schema("G*TC", "*TTC")
         assert match == 1, "Expected match because of ambiguity."
 
+
 class SchemaFactoryTest(unittest.TestCase):
     """Test the SchemaFactory for generating Schemas.
     """
@@ -490,7 +497,7 @@ class SchemaFactoryTest(unittest.TestCase):
 
         # a cached schema bank, so we don't have to load it multiple times
         self.schema_bank = None
-    
+
     def setUp(self):
         self.factory = Schema.SchemaFactory()
 
@@ -540,7 +547,7 @@ class SchemaFactoryTest(unittest.TestCase):
         # if we already have a cached repository, return it
         if self.schema_bank is not None:
             return self.schema_bank
-        
+
         # otherwise, we'll read in a new schema bank
 
         # read in the all of the motif records
@@ -554,7 +561,7 @@ class SchemaFactoryTest(unittest.TestCase):
         motif_size = 9
 
         motif_bank = motif_finder.find(seq_records, motif_size)
-        
+
         schema_bank = self.factory.from_motifs(motif_bank, .1, 2)
 
         # cache the repository
@@ -579,6 +586,7 @@ class SchemaFactoryTest(unittest.TestCase):
                 print "Schema values:", schema_values
         fasta_handle.close()
 
+
 # --- Tests for Signatures
 class SignatureFinderTest(unittest.TestCase):
     """Test the ability to find signatures in a set of sequences.
@@ -605,6 +613,7 @@ class SignatureFinderTest(unittest.TestCase):
         assert top_sig[0] == ('TTGGAA', 'TGGAAA'), \
                "Unexpected signature %s" % top_sig[0]
 
+
 class SignatureCoderTest(unittest.TestCase):
     """Test the ability to encode sequences as a set of signatures.
     """
