@@ -39,11 +39,13 @@ def _test_read_factory(source, count):
     phylogenies under the root.
     """
     fname = os.path.basename(source)
+
     def test_read(self):
         phx = PhyloXMLIO.read(source)
         self.assertTrue(phx)
         self.assertEqual(len(phx), count[0])
         self.assertEqual(len(phx.other), count[1])
+
     test_read.__doc__ = "Read %s to produce a phyloXML object." % fname
     return test_read
 
@@ -55,9 +57,11 @@ def _test_parse_factory(source, count):
     function and counts the total number of trees extracted.
     """
     fname = os.path.basename(source)
+
     def test_parse(self):
         trees = PhyloXMLIO.parse(source)
         self.assertEqual(len(list(trees)), count)
+
     test_parse.__doc__ = "Parse the phylogenies in %s." % fname
     return test_parse
 
@@ -69,6 +73,7 @@ def _test_shape_factory(source, shapes):
     clades deep.
     """
     fname = os.path.basename(source)
+
     def test_shape(self):
         trees = PhyloXMLIO.parse(source)
         for tree, shape_expect in zip(trees, shapes):
@@ -77,6 +82,7 @@ def _test_shape_factory(source, shapes):
                 self.assertEqual(len(clade), sub_expect[0])
                 for subclade, len_expect in zip(clade, sub_expect[1]):
                     self.assertEqual(len(subclade), len_expect)
+
     test_shape.__doc__ = "Check the branching structure of %s." % fname
     return test_shape
 
@@ -181,8 +187,8 @@ class TreeTests(unittest.TestCase):
         self.assertEqual(otr.namespace, 'http://example.org/align')
         self.assertEqual(len(otr.children), 3)
         for child, name, value in zip(otr, ('A', 'B', 'C'), (
-            'acgtcgcggcccgtggaagtcctctcct', 'aggtcgcggcctgtggaagtcctctcct',
-            'taaatcgc--cccgtgg-agtccc-cct')):
+          'acgtcgcggcccgtggaagtcctctcct', 'aggtcgcggcctgtggaagtcctctcct',
+          'taaatcgc--cccgtgg-agtccc-cct')):
             self.assertEqual(child.tag, 'seq')
             self.assertEqual(child.attributes['name'], name)
             self.assertEqual(child.value, value)
@@ -431,7 +437,7 @@ class TreeTests(unittest.TestCase):
                 ('ADHX', 'RT4I1', 'ADHB'),
                 ('P81431', 'Q54II4', 'Q04945'),
                 ('Alcohol dehydrogenase class-3',
-                 'Reticulon-4-interacting protein 1 homolog, ' \
+                 'Reticulon-4-interacting protein 1 homolog, '
                          'mitochondrial precursor',
                  'NADH-dependent butanol dehydrogenase B'),
                 ('TDATGKPIKCMAAIAWEAKKPLSIEEVEVAPPKSGEVRIKILHSGVCHTD',
@@ -499,7 +505,7 @@ class TreeTests(unittest.TestCase):
 
 class WriterTests(unittest.TestCase):
     """Tests for serialization of objects to phyloXML format.
-    
+
     Modifies the globally defined filenames in order to run the other parser
     tests on files (re)generated by PhyloXMLIO's own writer.
     """
