@@ -1,4 +1,6 @@
 # Copyright 2001 by Gavin E. Crooks.  All rights reserved.
+# Modifications Copyright 2010 Jeffrey Finkelstein. All rights reserved.
+#
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
@@ -11,8 +13,6 @@ import unittest
 from Bio.SCOP import Cla
 
 
-
-
 class ClaTests(unittest.TestCase):
 
     def setUp(self):
@@ -21,7 +21,7 @@ class ClaTests(unittest.TestCase):
     def testParse(self):
         """Test if all records in a CLA file are being read"""
         f=open(self.filename)
-        try: 
+        try:
             count = 0
             records = Cla.parse(f)
             for record in records:
@@ -29,17 +29,31 @@ class ClaTests(unittest.TestCase):
             self.assertEqual(count, 14)
         finally:
             f.close()
-    
+
     def testStr(self):
         """Test if we can convert each record to a string correctly"""
         f = open(self.filename)
-        try: 
+        try:
             for line in f:
                 record = Cla.Record(line)
+                # The SCOP Classification file format which can be found at
+                # http://scop.mrc-lmb.cam.ac.uk/scop/release-notes.html states
+                # that the list of classification hierarchy key-value pairs is
+                # unordered, therefore we need only check that they are all
+                # there, NOT that they are in the same order.
                 #End of line is platform dependent. Strip it off
-                self.assertEqual(str(record).rstrip(), line.rstrip())
+                expected_hierarchy = line.rstrip().split('\t')[5].split(',')
+                expected_hierarchy = dict(pair.split('=') for pair
+                                          in expected_hierarchy)
+                actual_hierarchy = str(record).rstrip().split('\t')[5].split(',')
+                actual_hierarchy = dict(pair.split('=') for pair
+                                        in actual_hierarchy)
+                self.assertEqual(len(actual_hierarchy),
+                                  len(expected_hierarchy))
+                for key, actual_value in actual_hierarchy.iteritems():
+                    self.assertEqual(actual_value, expected_hierarchy[key])
         finally:
-            f.close()        
+            f.close()
 
     def testError(self):
         """Test if a corrupt record raises the appropriate exception"""
@@ -56,18 +70,18 @@ class ClaTests(unittest.TestCase):
         self.assertEqual(record.residues.fragments, (('T','',''),('U','91','106')))
         self.assertEqual(record.sccs, 'b.1.2.1')
         self.assertEqual(record.sunid, 21953)
-        self.assertEqual(record.hierarchy, [['cl',48724],
-                                            ['cf',48725],
-                                            ['sf',49265],
-                                            ['fa',49266],
-                                            ['dm',49267],
-                                            ['sp',49268],
-                                            ['px',21953]])
+        self.assertEqual(record.hierarchy, {'cl' : 48724,
+                                            'cf' : 48725,
+                                            'sf' : 49265,
+                                            'fa' : 49266,
+                                            'dm' : 49267,
+                                            'sp' : 49268,
+                                            'px' : 21953})
 
     def testIndex(self):
         """Test CLA file indexing"""
         index = Cla.Index(self.filename)
-        
+
         self.assertEqual(len(index), 14)
         self.assertTrue('d4hbia_' in index)
 
@@ -75,7 +89,6 @@ class ClaTests(unittest.TestCase):
         self.assertEqual(rec.sunid, 14996)
 
 
-
 if __name__=='__main__':
     runner = unittest.TextTestRunner(verbosity = 2)
     unittest.main(testRunner=runner)
