@@ -14,8 +14,6 @@ import unittest
 from Bio.SCOP import Dom
 
 
-
-
 class DomTests(unittest.TestCase):
     def setUp(self):
         self.filename = './SCOP/testDom.txt'
@@ -23,22 +21,22 @@ class DomTests(unittest.TestCase):
     def testParse(self):
         """Test if all records in a DOM file are being read"""
         f = open(self.filename)
-        try: 
+        try:
             count = 0
             for record in Dom.parse(f):
                 count +=1
-            self.assertEquals(count,10)
+            self.assertEqual(count,10)
         finally:
             f.close()
-    
+
     def testStr(self):
         """Test if we can convert each record to a string correctly"""
         f = open(self.filename)
-        try: 
+        try:
             for line in f:
                 record = Dom.Record(line)
                 #End of line is platform dependent. Strip it off
-                self.assertEquals(str(record).rstrip(),line.rstrip())
+                self.assertEqual(str(record).rstrip(),line.rstrip())
         finally:
             f.close()
 
@@ -47,17 +45,15 @@ class DomTests(unittest.TestCase):
         corruptDom = "49xxx268\tsp\tb.1.2.1\t-\n"
         self.assertRaises(ValueError, Dom.Record, corruptDom)
 
-
     def testRecord(self):
         """Test one record in detail"""
         recLine = 'd7hbib_\t7hbi\tb:\t1.001.001.001.001.001'
 
         rec = Dom.Record(recLine)
-        self.assertEquals(rec.sid, 'd7hbib_')
-        self.assertEquals(rec.residues.pdbid,'7hbi')
-        self.assertEquals(rec.residues.fragments,(('b','',''),) )        
-        self.assertEquals(rec.hierarchy,'1.001.001.001.001.001')
-
+        self.assertEqual(rec.sid, 'd7hbib_')
+        self.assertEqual(rec.residues.pdbid,'7hbi')
+        self.assertEqual(rec.residues.fragments,(('b','',''),) )
+        self.assertEqual(rec.hierarchy,'1.001.001.001.001.001')
 
 
 if __name__ == '__main__':
