@@ -12,9 +12,9 @@ from Bio.Data.CodonTable import TranslationError
 
 
 if sys.version_info[0] == 3:
-   array_indicator = "u"
+    array_indicator = "u"
 else:
-   array_indicator = "c"
+    array_indicator = "c"
 
 print
 print "Testing Seq"
@@ -22,11 +22,11 @@ print "==========="
 
 s = Seq.Seq("TCAAAAGGATGCATCATG", IUPAC.unambiguous_dna)
 
-print s.tostring()
+print str(s)
 print len(s)
 print s[0]
 print s[-1]
-print s[3:5].tostring()
+print str(s[3:5])
 
 print "Reverse using -1 stride:", repr(s[::-1])
 
@@ -41,7 +41,7 @@ t = Seq.Seq("T", IUPAC.unambiguous_dna)
 u = s + t
 print str(u.alphabet)
 print len(u)
-assert s.tostring() + "T" == u.tostring()
+assert str(s) + "T" == str(u)
 
 t = Seq.Seq("T", IUPAC.protein)
 try:
@@ -70,13 +70,13 @@ converted_seq = s.tomutable()
 
 for test_seq in [string_seq]:
     print repr(test_seq)
-    print test_seq.tostring()
+    print str(test_seq)
     print len(test_seq)
     print repr(test_seq.toseq())
 
     print test_seq[0]
     print repr(test_seq[1:5])
-    
+
     test_seq[1:3] = "GAT"
     print "Set slice with string:", repr(test_seq)
     test_seq[1:3] = test_seq[5:7]
@@ -115,7 +115,6 @@ for test_seq in [string_seq]:
     print "Reversed Seq:", repr(test_seq)
 
     print "Reverse using -1 stride:", repr(test_seq[::-1])
-    
 
     test_seq.extend("GAT")
     test_seq.extend(MutableSeq("TTT", IUPAC.ambiguous_dna))
@@ -128,7 +127,7 @@ for test_seq in [string_seq]:
     print repr(test_seq[0::3])
     print repr(test_seq[1::3])
     print repr(test_seq[2::3])
-    
+
     print "Setting wobble codon to N (set slice with stride 3):"
     test_seq[2::3] = "N" * len(test_seq[2::3])
     print repr(test_seq)
@@ -222,12 +221,13 @@ print
 print "Testing Seq string methods"
 print "=========================="
 for a in dna + rna + nuc + protein:
-    if not isinstance(a, Seq.Seq) : continue
-    assert a.strip().tostring() == a.tostring().strip()
-    assert a.lstrip().tostring() == a.tostring().lstrip()
-    assert a.rstrip().tostring() == a.tostring().rstrip()
-    assert a.lower().tostring() == a.tostring().lower()
-    assert a.upper().tostring() == a.tostring().upper()
+    if not isinstance(a, Seq.Seq):
+        continue
+    assert str(a.strip()) == str(a).strip()
+    assert str(a.lstrip()) == str(a).lstrip()
+    assert str(a.rstrip()) == str(a).rstrip()
+    assert str(a.lower()) == str(a).lower()
+    assert str(a.upper()) == str(a).upper()
     test_chars = ["-", Seq.Seq("-"), Seq.Seq("*"), "-X@"]
     alpha = Alphabet._get_base_alphabet(a.alphabet)
     if isinstance(alpha, Alphabet.DNAAlphabet):
@@ -245,32 +245,32 @@ for a in dna + rna + nuc + protein:
     else:
         b = Seq.Seq("-", Alphabet.generic_protein)
     try:
-        print a.strip(b).tostring()
+        print str(a.strip(b))
         assert False, "Alphabet should have clashed!"
     except TypeError:
-        pass #Good!
-            
-    for chars in  test_chars:
+        pass  # Good!
+
+    for chars in test_chars:
         str_chars = str(chars)
-        assert a.strip(chars).tostring() == a.tostring().strip(str_chars)
-        assert a.lstrip(chars).tostring() == a.tostring().lstrip(str_chars)
-        assert a.rstrip(chars).tostring() == a.tostring().rstrip(str_chars)
-        assert a.find(chars) == a.tostring().find(str_chars)
-        assert a.find(chars,2,-2) == a.tostring().find(str_chars,2,-2)
-        assert a.rfind(chars) == a.tostring().rfind(str_chars)
-        assert a.rfind(chars,2,-2) == a.tostring().rfind(str_chars,2,-2)
-        assert a.count(chars) == a.tostring().count(str_chars)
-        assert a.count(chars,2,-2) == a.tostring().count(str_chars,2,-2)
+        assert str(a.strip(chars)) == str(a).strip(str_chars)
+        assert str(a.lstrip(chars)) == str(a).lstrip(str_chars)
+        assert str(a.rstrip(chars)) == str(a).rstrip(str_chars)
+        assert a.find(chars) == str(a).find(str_chars)
+        assert a.find(chars,2,-2) == str(a).find(str_chars,2,-2)
+        assert a.rfind(chars) == str(a).rfind(str_chars)
+        assert a.rfind(chars,2,-2) == str(a).rfind(str_chars,2,-2)
+        assert a.count(chars) == str(a).count(str_chars)
+        assert a.count(chars,2,-2) == str(a).count(str_chars,2,-2)
         #Now check splits
-        assert [x.tostring() for x in a.split(chars)] \
-               == a.tostring().split(str(chars))
-        assert [x.tostring() for x in a.rsplit(chars)] \
-               == a.tostring().rsplit(str(chars))
+        assert [str(x) for x in a.split(chars)] \
+               == str(a).split(str(chars))
+        assert [str(x) for x in a.rsplit(chars)] \
+               == str(a).rsplit(str(chars))
         for max_sep in [0,1,2,999]:
-            assert [x.tostring() for x in a.split(chars, max_sep)] \
-                   == a.tostring().split(str(chars), max_sep)
-            assert [x.tostring() for x in a.rsplit(chars, max_sep)] \
-                   == a.tostring().rsplit(str(chars), max_sep)
+            assert [str(x) for x in a.split(chars, max_sep)] \
+                   == str(a).split(str(chars), max_sep)
+            assert [str(x) for x in a.rsplit(chars, max_sep)] \
+                   == str(a).rsplit(str(chars), max_sep)
 del a, alpha, chars, str_chars, test_chars
 del dna, rna, nuc, protein
 ###########################################################################
@@ -282,14 +282,16 @@ print "=============================="
 assert "-" not in ambiguous_dna_values
 assert "?" not in ambiguous_dna_values
 
+
 def complement(sequence):
     #TODO - Add a complement function to Bio/Seq.py?
     #There is already a complement method on the Seq and MutableSeq objects.
     return Seq.reverse_complement(sequence)[::-1]
 
+
 def sorted_dict(d):
     """A sorted repr of a dictionary."""
-    return "{%s}" % ", ".join("%s: %s" % (repr(k),repr(v)) \
+    return "{%s}" % ", ".join("%s: %s" % (repr(k),repr(v))
                               for k,v in sorted(d.iteritems()))
 
 print
@@ -300,12 +302,12 @@ for ambig_char, values in sorted(ambiguous_dna_values.iteritems()):
     print "%s={%s} --> {%s}=%s" % \
         (ambig_char, values, compl_values, ambiguous_dna_complement[ambig_char])
     assert set(compl_values) == set(ambiguous_dna_values[ambiguous_dna_complement[ambig_char]])
-    
+
 print
 print "RNA Ambiguity mapping:", sorted_dict(ambiguous_rna_values)
 print "RNA Complement mapping:", sorted_dict(ambiguous_rna_complement)
 for ambig_char, values in sorted(ambiguous_rna_values.iteritems()):
-    compl_values = complement(values).replace("T","U") #need to help as no alphabet
+    compl_values = complement(values).replace("T","U")  # need to help as no alphabet
     print "%s={%s} --> {%s}=%s" % \
         (ambig_char, values, compl_values, ambiguous_rna_complement[ambig_char])
     assert set(compl_values) == set(ambiguous_rna_values[ambiguous_rna_complement[ambig_char]])
@@ -321,8 +323,8 @@ for sequence in [Seq.Seq("".join(sorted(ambiguous_rna_values))),
             Seq.Seq("AWGAARCKG")]:  # Note no U or T
         print "%s -> %s" \
               % (repr(sequence), repr(Seq.reverse_complement(sequence)))
-        assert sequence.tostring() \
-           == Seq.reverse_complement(Seq.reverse_complement(sequence)).tostring(), \
+        assert str(sequence) \
+           == str(Seq.reverse_complement(Seq.reverse_complement(sequence))), \
            "Dobule reverse complement didn't preserve the sequence!"
 print
 
@@ -340,17 +342,17 @@ test_seqs = [s,t,u,
              #Seq.Seq("".join(ambiguous_dna_values), Alphabet.generic_dna),
              #Seq.Seq("".join(ambiguous_rna_values), IUPAC.IUPACAmbiguousDNA()),
              #Seq.Seq("".join(ambiguous_dna_values), IUPAC.IUPACAmbiguousRNA()),
-             #Seq.Seq("AWGAARCKG", Alphabet.generic_dna), 
-             Seq.Seq("AUGAAACUG", Alphabet.generic_rna), 
-             Seq.Seq("ATGAAACTG", IUPAC.unambiguous_dna), 
+             #Seq.Seq("AWGAARCKG", Alphabet.generic_dna),
+             Seq.Seq("AUGAAACUG", Alphabet.generic_rna),
+             Seq.Seq("ATGAAACTG", IUPAC.unambiguous_dna),
              Seq.Seq("ATGAAA-CTG", Alphabet.Gapped(IUPAC.unambiguous_dna)),
-             Seq.Seq("ATGAAACTGWN", IUPAC.ambiguous_dna), 
-             Seq.Seq("AUGAAACUG", Alphabet.generic_rna), 
+             Seq.Seq("ATGAAACTGWN", IUPAC.ambiguous_dna),
+             Seq.Seq("AUGAAACUG", Alphabet.generic_rna),
              Seq.Seq("AUGAAA==CUG", Alphabet.Gapped(Alphabet.generic_rna,"=")),
              Seq.Seq("AUGAAACUG", IUPAC.unambiguous_rna),
              Seq.Seq("AUGAAACUGWN", IUPAC.ambiguous_rna),
              Seq.Seq("ATGAAACTG", Alphabet.generic_nucleotide),
-             Seq.Seq("AUGAAACTG", Alphabet.generic_nucleotide), #U and T
+             Seq.Seq("AUGAAACTG", Alphabet.generic_nucleotide),  # U and T
              Seq.MutableSeq("ATGAAACTG", Alphabet.generic_dna),
              Seq.MutableSeq("AUGaaaCUG", IUPAC.unambiguous_rna),
              Seq.Seq("ACTGTCGTCT", Alphabet.generic_protein)]
@@ -370,7 +372,6 @@ for nucleotide_seq in test_seqs:
             assert not isinstance(nucleotide_seq.alphabet, Alphabet.DNAAlphabet)
         if "T" in str(nucleotide_seq).upper():
             assert not isinstance(nucleotide_seq.alphabet, Alphabet.RNAAlphabet)
-            
 
 print
 print "Transcribe DNA into RNA"
@@ -398,7 +399,8 @@ for s in protein_seqs:
         assert False, "Transcription shouldn't work on a protein!"
     except ValueError:
         pass
-    if not isinstance(s, Seq.Seq) : continue #Only Seq has this method
+    if not isinstance(s, Seq.Seq):
+        continue  # Only Seq has this method
     try:
         print s.transcribe()
         assert False, "Transcription shouldn't work on a protein!"
@@ -424,20 +426,21 @@ for nucleotide_seq in test_seqs:
             assert repr(expected) == repr(nucleotide_seq.back_transcribe())
         except ValueError:
             assert expected is None
-            
+
 for s in protein_seqs:
     try:
         print Seq.back_transcribe(s)
         assert False, "Back transcription shouldn't work on a protein!"
     except ValueError:
         pass
-    if not isinstance(s, Seq.Seq) : continue #Only Seq has this method
+    if not isinstance(s, Seq.Seq):
+        continue  # Only Seq has this method
     try:
         print s.back_transcribe()
         assert False, "Back transcription shouldn't work on a protein!"
     except ValueError:
         pass
-        
+
 print
 print "Reverse Complement"
 print "=================="
@@ -476,7 +479,7 @@ for s in protein_seqs:
         assert False, "Reverse complement shouldn't work on a protein!"
     except ValueError:
         pass
-   
+
 print
 print "Translating"
 print "==========="
@@ -515,7 +518,8 @@ for s in protein_seqs:
         assert False, "Translation shouldn't work on a protein!"
     except ValueError:
         pass
-    if not isinstance(s, Seq.Seq) : continue #Only Seq has this method
+    if not isinstance(s, Seq.Seq):
+        continue  # Only Seq has this method
     try:
         print s.translate()
         assert False, "Translation shouldn't work on a protein!"
@@ -532,11 +536,11 @@ for nucleotide_seq in [misc_stops, Seq.Seq(misc_stops),
     assert "***RR" == str(Seq.translate(nucleotide_seq, table=1))
     assert "***RR" == str(Seq.translate(nucleotide_seq, table="SGC0"))
     assert "**W**" == str(Seq.translate(nucleotide_seq, table=2))
-    assert "**WRR" == str(Seq.translate(nucleotide_seq, \
+    assert "**WRR" == str(Seq.translate(nucleotide_seq,
                                         table='Yeast Mitochondrial'))
     assert "**WSS" == str(Seq.translate(nucleotide_seq, table=5))
     assert "**WSS" == str(Seq.translate(nucleotide_seq, table=9))
-    assert "**CRR" == str(Seq.translate(nucleotide_seq, \
+    assert "**CRR" == str(Seq.translate(nucleotide_seq,
                                         table='Euplotid Nuclear'))
     assert "***RR" == str(Seq.translate(nucleotide_seq, table=11))
     assert "***RR" == str(Seq.translate(nucleotide_seq, table='Bacterial'))
@@ -575,9 +579,9 @@ ambig = set(IUPAC.IUPACAmbiguousDNA.letters)
 for c1 in ambig:
     for c2 in ambig:
         for c3 in ambig:
-            values = set([Seq.translate(a+b+c, table=1) \
-                          for a in ambiguous_dna_values[c1] \
-                          for b in ambiguous_dna_values[c2] \
+            values = set([Seq.translate(a+b+c, table=1)
+                          for a in ambiguous_dna_values[c1]
+                          for b in ambiguous_dna_values[c2]
                           for c in ambiguous_dna_values[c3]])
             t = Seq.translate(c1+c2+c3)
             if t=="*":
@@ -606,13 +610,13 @@ for nucleotide_seq in test_seqs:
         try:
             print "%s -> %s" \
             % (repr(nucleotide_seq) , repr(nucleotide_seq.complement()))
-            assert nucleotide_seq.complement().tostring() \
-                == Seq.reverse_complement(nucleotide_seq).tostring()[::-1], \
+            assert str(nucleotide_seq.complement()) \
+                == str(Seq.reverse_complement(nucleotide_seq))[::-1], \
                 "Bio.Seq function and method disagree!"
         except ValueError, e:
             print "%s -> %s" \
             % (repr(nucleotide_seq) , str(e))
-        
+
 print
 print "Seq's .reverse_complement() method"
 print "=================================="
@@ -621,8 +625,8 @@ for nucleotide_seq in test_seqs:
         try:
             print "%s -> %s" \
             % (repr(nucleotide_seq) , repr(nucleotide_seq.reverse_complement()))
-            assert nucleotide_seq.reverse_complement().tostring() \
-                == Seq.reverse_complement(nucleotide_seq).tostring(), \
+            assert str(nucleotide_seq.reverse_complement()) \
+                == str(Seq.reverse_complement(nucleotide_seq)), \
                 "Bio.Seq function and method disagree!"
         except ValueError, e:
             print "%s -> %s" \
